/*==================================================
	
	project:       CEQ Bulgaria 
	Author:        Cabrera 
	E-email:       
	url:           
	Dependencies:  World Bank 
	Input files
	
	Ado files used
	- eurostatuse
	- wbopendata
	- sp_groupfunction
	
	** Due to updates in Eurostat, it is necessary to download mannualy some data 
	** It is necessary  to have installe 7zip in your system
	
	Output files:
	- BGR20_figtablesr.xlsx 
	
	----------------------------------------------------
	Creation Date:       30 Nov 2023
	Modification Date:   13  Dec 2023
	Do-file version:    1.5
	Track main changes: 
	
	References:          
	
	Robayo, Monica and Maynor Cabrera (2023)
	Reassessing Welfare Impacts of Bulgarian Fiscal Policy through a Child Poverty Perspective
	
==================================================*/

/*==================================================
0: Path==================================================*/

version 17
drop _all
set type double 
mat drop _all	
global path  "C:/Users/mynor/Dropbox (Personal)/zotros/BM/BGR20/"
if c(username)=="mcabrera1" global path  "E:/mcabrera/BGR20/"
global do    "${path}2.DOs/"
global raw   "${path}3.DATA/Original/raw/"
global tmp   "${path}3.DATA/MC/tmp/"
global proc  "${path}3.DATA/MC/proc/"
global log   "${path}3.DATA/MC/log/"
global outp   "${path}5.Output/"
global date  "DEC04"
adopath + "${do}ados"
cd "${tmp}"

cap program drop eulabels 
program define eulabels 
cap confim file "${tmp}geodata.dta" 
if _rc {
preserve
capture copy "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/codelist/ESTAT/GEO/?compressed=false&format=TSV&lang=en" geo.tsv, replace
insheet using "geo.tsv", clear 
rename v1 geo 
rename v2 geo_label
drop if substr(geo,4,3)=="CAP"
sort geo
save "${tmp}geodata.dta", replace 
restore 
}
merge m:1 geo using "${tmp}geodata.dta" 
drop if _merge==2
drop _merge

/* gen geo_label ="Austria"	if geo=="AT"
replace geo_label ="Belgium"  	if geo=="BE"
replace geo_label ="Bulgaria"	if geo=="BG"
replace geo_label ="Croatia"	if geo=="HR"
replace geo_label ="Cyprus"		if geo=="CY"
replace geo_label ="Czechia"	if geo=="CZ"
replace geo_label ="Denmark"	if geo=="DK"
replace geo_label ="Estonia"	if geo=="EE"
replace geo_label ="Finland"	if geo=="FI"
replace geo_label ="France"		if geo=="FR"
replace geo_label ="Germany"	if geo=="DE"
replace geo_label ="Greece"		if geo=="EL"
replace geo_label ="Hungary"	if geo=="HU"
replace geo_label ="Ireland"	if geo=="IE"
replace geo_label ="Italy"		 if geo=="IT"
replace geo_label ="Latvia"		 if geo=="LV"
replace geo_label ="Lithuania"	 if geo=="LT"
replace geo_label ="Luxembourg"	 if geo=="LU"
replace geo_label ="Malta"		 if geo=="MT"
replace geo_label ="Netherlands" if geo=="NL"
replace geo_label ="Poland"		 if geo=="PL"
replace geo_label ="Portugal"	 if geo=="PT"
replace geo_label ="Romania"	 if geo=="RO"
replace geo_label ="Slovakia"	 if geo=="SK"
replace geo_label ="Slovenia"	 if geo=="SI"
replace geo_label ="Spain"		 if geo=="ES"
replace geo_label ="Sweden"		 if geo=="SE"
replace geo_label ="Norway"	if geo=="NO"
replace geo_label ="Euro area – 20 countries (from 2023)" if geo=="EA20"
replace geo_label ="European Union" 		if geo=="EU27_2020"
replace geo_label ="Switzerland"			if geo=="CH"
replace geo_label ="Montenegro"				if geo=="ME"
replace geo_label ="Albania"				if geo=="AL"
replace geo_label ="Bosnia and Herzegovina"	if geo=="BA"
replace geo_label ="Moldova, Republic of"	if geo=="MD"
replace geo_label ="North Macedonia"		if geo=="MK"
replace geo_label ="Serbia"					if geo=="RS"
replace geo_label ="Turkey"					if geo=="TR"
replace geo_label ="Ukraine" 				if geo=="UA"
replace geo_label ="Iceland"					if geo=="IS"
replace geo_label ="Liechtenstein"			if geo=="LI"
replace geo_label ="European Free Trade Association" if geo=="EFTA"	
replace geo_label = "Euro area" if geo=="EA20"
replace geo_label = "Germany" if geo=="DE" */
end	

// ##### select Excel file 

//global xl_output "${path}3.DATA/MC/tmp/BGR20_figtables_dec2023r.xlsx"
// empty version use the first one to reproduce charts in paper 
global xl_output "${outp}BGR20_figtables_jan2023_clean.xlsx"
//global xl_output "${outp}BGR20_figtables_dec2023r.xlsx"
 global xl_sims   "${outp}BGR20_sim_Jan12_2023.xlsx"
//global xl_sims   "${outp}BGR20_sim_Nov07_2023.xlsx"

global e11_pc1 "MWB_PDI_PC_E11${date}.xlsx"
global e03_pc1 "MWB_PDI_PC_E3${date}.xlsx"
global e13_pc1 "MWB_PDI_PC_E13${date}.xlsx"
global e03_pa1 "MWB_PDI_PA_E3${date}.xlsx"
global e13_pa1 "MWB_PDI_PA_E13${date}.xlsx"

global e11_pc2 "MWB_PGT_PC_E11${date}.xlsx"
global e03_pc2 "MWB_PGT_PC_E3${date}.xlsx"
global e13_pc2 "MWB_PGT_PC_E13${date}.xlsx"
global e03_pa2 "MWB_PGT_PA_E3${date}.xlsx"
global e13_pa2 "MWB_PGT_PA_E13${date}.xlsx"
global bgr20_dt "${outp}BGR20WBN_childp_Aug9_2023.dta"
global bgr19_dt "${outp}BGR19WBN_final_Dec_2023.dta"

/*==================================================
	0: Select figures and tables 
==================================================*/

local f1  = 1  // figure 1  error 410 
local f2  = 0  // figure 2
local f3  = 0 // figure 3
local f4  = 0 // figure 4
local f5  = 0 // figure 5
local f6  = 0  // figure 6
local f7  = 0 // figure 7
local f8  = 0 // figure 8
local f9  = 0 // figure 9
local f10 = 0 // figure 10
local f11 = 0 // figure 11
local f12 = 0 // figure 12
local f13 = 0 // figure 13
local f14 = 0 // figure 14 
local f15_f17 = 0  // figure 15 & 17
local f16 = 0  // figure 16
local f18_f20 =  0  // Figures 18, 19, 20 

local t2  = 0   // Table 2 
local t3  = 0  // Table 3
local A1  = 0   // Annex 1

local run_all = 1
if `run_all' == 1 {
	forval i = 1(1)14 { 
		local f`i'=1
	}	
	local f16=1
	local f15_f17 = 1
	local f18_f20 = 1
	local t2=1
	local t3=1
	local A1=1
}


/*==================================================
	1: Figures
==================================================*/

if `f1' == 1 {
	
	*----------1: Figure 1. Bulgaria Poverty and Inequality Trends and EU Comparison
	
	// a.Income-based poverty rate, upper-middle income (UMI) poverty line ($6.85 per day, 2017 PPP), Bulgaria, 2006-2020, Percent
	
	wbopendata, country(BGR) indicator(SI.POV.UMIC) long clear
	
	keep if inrange(year,2006,2020)  // 2021 not available 
	
	mkmat year si_pov_umic, matrix(fig1a)  
	
	wbopendata,  indicator(SI.POV.UMIC) long clear latest 
	
	keep if inlist(countrycode, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK") | ///
	inlist(countrycode, "EST", "FIN", "GRC", "HUN" ) | ///
	inlist(countrycode, "LVA", "LTU", "LUX", "MLT", "NLD","NOR") | ///
	inlist(countrycode, "PRT", "ROU", "SVK", "SVN", "ESP", "SWE")
	
	sort si countryname
	keep countryname si 
	preserve 
	
	//eurostatuse ilc_di12, clear geo(EU27_2020) keepdim() start(2010) end(2022) long 
	
	insheet using "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/ilc_di12/?format=SDMX-CSV&compressed=false", clear 
	keep if geo=="EU27_2020" 
	capture keep if inrange(time_period,2010,2022)
	rename obs_value ilc_di12
	rename time_period time 
	
	mkmat time ilc_di12
	local tot=_N
	forval i=1(1)`tot' {
		local desc = "`desc'"+ strofreal(time[`i'],"%4.0f") + " "
	}
	mat eu_gini = ilc_di12 
	mat rownames eu_gini = `desc'
	mat drop ilc_di12
	
	// eurostatuse ilc_di12, clear geo(BG) keepdim() start(2010) end(2022) long 
	insheet using "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/ilc_di12/?format=SDMX-CSV&compressed=false", clear 
	keep if geo=="BG" 
	capture keep if inrange(time_period,2010,2022)
	rename obs_value ilc_di12
	rename time_period time 		
	mkmat  ilc_di12	
	mat fig1b = (time, eu_gini, ilc_di12)
	mat drop ilc_di12 eu_gini time 
	
	// eurostatuse ilc_di12, clear geo() keepdim() start(2022) end(2022) long 
	insheet using "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/ilc_di12/?format=SDMX-CSV&compressed=false", clear 
	rename obs_value ilc_di12
	capture keep if inrange(time_period,2022,2022)
	rename time_period time 		
	sort ilc 
	drop if ilc==.
	eulabels
	replace geo_label = "European Union" if geo=="EU27_2020"
	replace geo_label = "Euro area" if geo=="EA20"
	drop if inlist(geo,"EA18","EA19","TR","AL","RS","ME","MK","CH","NO") 
	drop if inlist(geo,"EA") 	
	keep geo_label  ilc 	
	sort ilc 
	export excel geo_label ilc using "$xl_output", sheet("F1") ///
	sheetmodify firstrow(varlabels) cell(Q21)
	
	restore 
	
	export excel countryname si using "$xl_output", sheet("F1") ///
	sheetmodify firstrow(varlabels) cell(F21)
	
	putexcel set "$xl_output", modify  sheet("F1")
	putexcel B21 = mat(fig1a) L21=mat(fig1b)
	putexcel clear 
}

if `f2' == 1 {
	
	*----------2: Figure 2. Child Poverty, Evolution, and EU Comparison
	
	
	
	// eurostatuse ilc_li22, clear geo(BG) keepdim() start() end() long 
	insheet using "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/ilc_li22/?format=SDMX-CSV&compressed=false", clear 
	keep if geo=="BG"
	keep if sex=="T"
	keep if unit=="PC"
	keep if inlist(age,"TOTAL","Y_LT18", "Y18-64","Y_GE65")
	gen age_label = "Total" if age=="TOTAL"
	replace age_label = "65 years or over" if age == "Y_GE65"
	replace age_label = "From 18 to 64 years" if age == "Y18-64"
	replace age_label = "Less than 18 years" if age == "Y_LT18"
	
	drop sex* indic* age unit* geo* obs_flag* dataflow lastupdate freq
	rename obs_value /* ilc_li22 */ y_
	reshape wide y_, i(age_label) j(time)
	
	preserve 
	// eurostatuse ilc_li02, clear geo() keepdim() start() end() long 
	capture copy  "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/ilc_li02/?format=SDMX-CSV&compressed=true" ilc_li02.tsv.gz, replace
	shell "C:\Program Files\7-Zip\7zG.exe" x -y ilc_li02.tsv.gz
	insheet using "ilc_li02.tsv", clear 
	keep if time==2022
	keep if sex=="T"
	keep if unit=="PC"
	keep if inlist(age,"Y_LT18", "Y_GE18")
	gen age_label = "Total" if age=="TOTAL"
	replace age_label = "65 years or over" if age == "Y_GE65"
	replace age_label = "From 18 to 64 years" if age == "Y18-64"
	replace age_label = "Less than 18 years" if age == "Y_LT18"
	drop if inlist(indic_il,"LI_R_M40","LI_R_M50", "LI_R_MD40","LI_R_MD50", ///
	"LI_R_MD70","LI_R_M60")		
	drop sex* indic* age_label unit* time* obs_flag* 
	eulabels
	replace geo_label = "European Union" if geo=="EU27_2020"
	replace geo_label = "Euro area" if geo=="EA20"
	rename obs_value y_
	encode age, gen(age2)
	drop age
	reshape wide y_, i(geo_label) j(age2) 
	drop if y_1==.
	sort y_1
	drop if inlist(geo,"TR","EA19","EA20","ME","CH","NO")
	gen lgeo = ustrlen(geo)
	gsort -lgeo -y_2
	
	export excel geo_label y_2 y_1 using "$xl_output", sheet("F2") ///
	sheetmodify firstrow(varlabels) cell(L18)
	
	restore
	
	export excel age_label y_* using "$xl_output", sheet("F2") ///
	sheetmodify firstrow(varlabels) cell(B18)
	
}

use "${bgr20_dt}", clear 


if `f3' == 1 {
	
	*----------3: Poverty Changes, Pre vs. Post Fiscal Incomes, by CEQ income concept 
	
	// Panel a. Percentage Change in Poverty rate due to Fiscal Policy using AROP (at-risk of poverty) and UMI (Upper-Middle Income) Poverty Lines, 2018 vs. 2020.
	// Panel b. Poverty Rates by CEQ Income Concepts using the AROP Poverty Line (equivalent to US$20.5 2017 PPP per day in 2020).
	apoverty yp_ae yc_ae yd_ae [w=weight], varpl(pline_mod)
	
	mat fig3a = J(2,2,.)
	mat fig3b = J(2,3,.)
	
	mat fig3a[2,1] = 2.2 // From CEQ 2018 (Vaughn & Cabrera, 2020)
	mat fig3a[2,2] = round((real(r(head_2))-real(r(head_1))),0.1)
	mat fig3b[1,1] = round(real(r(head_1)),0.1)
	mat fig3b[1,3] = round(real(r(head_2)),0.1)
	mat fig3b[1,2] = round(real(r(head_3)),0.1)
	mat fig3b[2,1] = 25.4 // From CEQ 2018 (Vaughn & Cabrera, 2020)
	mat fig3b[2,2] = 23.1  // From CEQ 2018 (Vaughn & Cabrera, 2020)
	mat fig3b[2,3] = 27.6  // From CEQ 2018 (Vaughn & Cabrera, 2020)
	
	apoverty yp_pc yc_pc [w=weight], varpl(pline_685)
	mat fig3a[1,1] = -2.3 // From CEQ 2018 (Vaughn & Cabrera, 2020)
	mat fig3a[1,2] = round((real(r(head_2))-real(r(head_1))),0.1)
	
	matlist fig3a 
	matlist fig3b 
	
	putexcel set "$xl_output", modify  sheet("F3")
	putexcel B21 = mat(fig3a) L21=mat(fig3b)
	putexcel clear 
	
}




if `f4' == 1 {
	
	*----------Figure 4. Inequality Changes, Pre vs. Post Fiscal Incomes, by CEQ income concept 
	
	
	// Panel a. Panel a. Change in Inequality due to Fiscal Policy using Gini Coefficient, 2018 vs. 2020
	
	ainequal yp_pc yd_pc yc_pc yf_pc [w=weight]
	
	mat fig4a = J(2,4,.)
	
	mat fig4a[2,1] = round(real(r(gini_1)),0.001)
	mat fig4a[2,2] = round(real(r(gini_2)),0.001)
	mat fig4a[2,3] = round(real(r(gini_3)),0.001)
	mat fig4a[2,4] = round(real(r(gini_4)),0.001)
	mat fig4a[1,1] = 0.452
	mat fig4a[1,2] = 0.408
	mat fig4a[1,3] = 0.385
	mat fig4a[1,4] = 0.325
	
	mat rownames fig4a = 2018 2020
	mat colnames fig4a = mypp disp cons final
	matlist fig4a 
	
	putexcel set "$xl_output", modify  sheet("F4")
	putexcel B21 = mat(fig4a) 
	putexcel (M21:M50), overwritefmt nformat("#0.00")
	putexcel clear 
	
	// Panel b. Change in Gini coefficient due to Direct Taxes and Transfers*2020, EU countries
	
	// Source EUROMOD 
		// https://euromod-web.jrc.ec.europa.eu/sites/default/files/2023-06/EM_statistics_I5.0%2B.xlsx
	// Data for year 2020
	
	import excel using ///
	"https://euromod-web.jrc.ec.europa.eu/sites/default/files/2023-06/EM_statistics_I5.0%2B.xlsx", ///
	clear sheet(Gini) cellrange(A4:I116) firstrow
	
	gen gini_chg = DisposableincomeDPI - OriginalIncomepluspensions
	rename A country 
	rename B year 
	local tot = _N 
	forval i = 2(1)`tot' {
		local j = `i'-1
		local descr = country[`j']
		replace country = "`descr'" if _n==`i' & country==""
	}
	keep if year==2020
	keep country  gini_chg 
	// replace gini_chg = round(gini_chg,0.01)
	replace country = "Bulgaria (EUROMOD)" if country =="Bulgaria"
	set obs 30
	replace country = "Bulgaria 2018 (CEQ)" in 29
	replace country = "Bulgaria 2020 (CEQ)" in 30
	replace gini_chg = -0.041 in 29
	replace gini_chg = -0.050 in 30
	sort gini_chg 
	
	export excel country gini_chg using "${xl_output}", sheet("F4") sheetmodify cell(L21) keepcellfmt		
}

cd "${tmp}"		
if c(filename)!="${bgr20_dt}" {
	use "${bgr20_dt}", clear 	
}

quantiles yp_pc [w=weight], gen(quintilp) n(5) k(hhid)


/*======================================================================================
	Data from MWB 
======================================================================================*/	

if `f5'==1 | `f6'==1 | `f7'==1 | `f8'==1 | `f9'==1 {
	cd "${tmp}"		
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}
	cap confirm "$e11_pc1"
	if _rc shell copy "MWB2018_E11_March29_2018.xlsx"  "$e11_pc1"
	ceqfiscal [pw=weight]  using  "$e11_pc1",   ///
	hhid(hhid) psu(psu) m(ym_pc) mp(yp_pc) 	 ///	
	dtransfers(dtr*pc) dtax(dtx*pc) contribs(con*pc)  ///
	subs(sub*pc) indtaxes(itx*pc)  educ(edu*pc) health(hlt*pc) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   
	
	cap confirm "$e11_pc2"
	if _rc shell copy "MWB2018_E11_March29_2018.xlsx"  "$e11_pc2"
	ceqfiscal [pw=weight]  using  "$e11_pc2",   ///
	hhid(hhid) psu(psu) m(ym_pc) mp(yp_pc) 	 ///	
	dtransfers(dtr*pc) dtax(dtx*pc) contribs(con*pc)  ///
	subs(sub*pc) indtaxes(itx*pc)  educ(edu*pc) health(hlt*pc) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   
	
	cap confirm "$e13_pa1"
	if _rc shell copy "MWB2018_E13_March29_2018.xlsx"  "$e13_pa1"
	ceqmarg  [pw=weight]  using  "$e13_pa1",   ///
	hhid(hhid) psu(psu) c(yc_ae) f(yf_ae) 	 ///	
	dtransfers(dtr*ae) dtax(dtx*ae) contribs(con*ae)  ///
	subs(sub*ae) indtaxes(itx*ae)  educ(edu*ae) health(hlt*ae) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   ///
	pl1(2.15) pl2(3.65) pl3(6.85)    ///
	nationalm(pline_mod) ignoremissing negatives
	
	cap confirm "$e13_pc1"
	if _rc shell copy "MWB2018_E13_March29_2018.xlsx"  "$e13_pc1"
	ceqmarg  [pw=weight]  using  "$e13_pc1",   ///
	hhid(hhid) psu(psu) c(yc_pc) f(yf_pc) 	 ///	
	dtransfers(dtr*pc) dtax(dtx*pc) contribs(con*pc)  ///
	subs(sub*pc) indtaxes(itx*pc)  educ(edu*pc) health(hlt*pc) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   ///
	pl1(2.15) pl2(3.65) pl3(6.85)    ///		
	nationalm(pline_mod) ignoremissing negatives
	
	cap confirm "$e13_pa2"
	if _rc shell copy "MWB2018_E13_March29_2018.xlsx"  "$e13_pa2"
	ceqmarg  [pw=weight]  using  "$e13_pa2",   ///
	hhid(hhid) psu(psu) c(yc_ae) f(yf_ae) 	 ///	
	dtransfers(dtr*ae) dtax(dtx*ae) contribs(cpn*ae con*ae)  ///
	pen(pen*ae) subs(sub*ae) indtaxes(itx*ae)  educ(edu*ae) health(hlt*ae) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   ///
	pl1(2.15) pl2(3.65) pl3(6.85)    ///
	nationalm(pline_mod) ignoremissing negatives
	
	cap confirm "$e13_pc2"
	if _rc shell copy "MWB2018_E13_March29_2018.xlsx"  "$e13_pc2"
	ceqmarg  [pw=weight]  using  "$e13_pc2",   ///
	hhid(hhid) psu(psu) c(yc_pc) f(yf_pc) 	 ///	
	dtransfers(dtr*pc) dtax(dtx*pc) contribs(cpn*pc con*pc)  ///
	pen(pen*pc) subs(sub*pc) indtaxes(itx*pc)  educ(edu*pc) health(hlt*pc) ///
	ppp(0.38042116) cpibase(107.93615)   cpisurvey(116.33197) 	/// 
	cut1(2.15) cut2(3.65) cut3(6.85) nocentile nobin   ///
	pl1(2.15) pl2(3.65) pl3(6.85)    ///
	nationalm(pline_mod) ignoremissing negatives		 
	
	import excel using "$e11_pc1", sheet("E11.m+p FiscalInterventions") ///
	cellrange("C8:BM26") firstrow clear 
	preserve 
	keep in 5	
	list 
	save "pc_pdi_kakwani.dta", replace 
	restore 	
	keep in 8/17
	list 
	save "pc_pdi_detail.dta", replace 
	
	import excel using "$e13_pa1", sheet("E13.c Marg. Contrib.") ///
	cellrange("B8:BJ45") firstrow clear 	
	keep if B=="National Moderate PL"	
	save "pa_pdi_margcontc.dta", replace 
	
	import excel using "$e13_pc1", sheet("E13.c Marg. Contrib.") ///
	cellrange("B8:BJ45") firstrow clear 	
	keep if B=="6.85"	
	save "pc_pdi_margcontc.dta", replace
	
	import excel using "$e13_pc1", sheet("E13.c Marg. Contrib.") ///
	cellrange("B8:BJ48") firstrow clear 
	keep if C=="Marginal Contribution to Redistributive Effect"
	list 
	save "pc_pdi_margeffc.dta", replace 
	
	import excel using "$e13_pc1", sheet("E13.f Marg. Contrib.") ///
	cellrange("B8:BJ48") firstrow clear 
	keep if C=="Marginal Contribution to Redistributive Effect"
	keep InKindhealthbenefitsSocial-Neteducationtransfers
	list 
	save "pc_pdi_margefff.dta", replace 
	
	
}

/*
	// PGT 
	import excel using "$e11_pc2", sheet("E11.m FiscalInterventions") ///
	cellrange("C8:BM26") firstrow clear 
	preserve 
	keep in 5	
	list 
	save "pc_pgt_kakwani.dta", replace 
	restore 	
	keep in 8/17
	list 
	save "pc_pgt_detail.dta", replace 
*/

if `f5' == 1 {		
	
	use "pc_pdi_detail.dta", clear 
	keep C MarketIncomePensions DirtransferPregnancychildb-DirecttransfersotherPercap 
	rename C decile 
	destring decile, replace 
	destring Market, replace 
	mkmat DirtransferPregnancychildb-DirecttransfersotherPercap , mat(fig5)	
	mata: a=st_matrix("fig5"):/colsum(st_matrix("fig5")):*100
	mata: b=(colsum(a[1::2,]) \ colsum(a[3::4,]) \ colsum(a[5::6,]) \ colsum(a[7::8,]) \ colsum(a[9::10,]))
	mata: st_matrix("fig5a",b)
	descr DirtransferPregnancychildb-DirecttransfersotherPercap , varlist 
	mat colnames fig5a = `r(varlist)'
	mat rownames fig5a = 1 2 3 4 5
	matlist fig5a'
	mkmat Market, mat(mypp)
	mata: st_matrix("fig5b",colsum(st_matrix("fig5")):/colsum(st_matrix("mypp")))
	
	use "pa_pdi_margcontc.dta", clear 
	drop B-C
	keep DirtransferPregnancychildb-DirecttransfersotherAdulte
	mkmat DirtransferPregnancychildb-DirecttransfersotherAdulte, mat(fig5b1)	
	mata: st_matrix("fig5b1", st_matrix("fig5b1"):*100)
	mat fig5b = (fig5b \ fig5b1)
	descr DirtransferPregnancychildb-DirecttransfersotherAdulte, varlist 
	mat colnames fig5b = `r(varlist)'
	
	use "pc_pdi_kakwani.dta", clear 
	mkmat DirtransferPregnancychildb-DirecttransfersotherPercap, mat(fig5c1)	
	
	use "pc_pdi_margeffc.dta", clear 
	mkmat DirtransferPregnancychildb- DirecttransfersotherPercap, mat(fig5c2)	
	mat fig5c = (fig5c1 \ fig5c2)
	putexcel set "$xl_output", modify  sheet("F5")
	putexcel C21=mat(fig5a')  L21=mat(fig5b') Y21=mat(fig5c'), names
	putexcel clear 
	
	
}	

if `f6' == 1 {		
	
	use "pc_pdi_kakwani.dta", clear 
	local inkind InKindhealthbenefitsSocial-In_kindhealthbenefitsPublic InKindeducationbenefitsPre-InKindeducationbenefitsTert
	mkmat `inkind', mat(fig6a1)		
	use "pc_pdi_margefff.dta", clear 
	mkmat `inkind', mat(fig6a2)	
	mat fig6a = (fig6a1 \ fig6a2)
	
	mat colnames fig6a = Social_Security Public_Health Pre_School Primary LowSec UppSec Tertiary
	mat rownames fig6a = Kakwani MargEff
	
	putexcel set "$xl_output", modify  sheet("F6")
	putexcel C21=mat(fig6a'), names
	putexcel clear 
	
	
}	

if `f7' == 1 {		
	
	use "pc_pdi_detail.dta", clear 
	
	rename C decile 
	destring decile, replace 
	destring Market, replace 
	egen  SIC_non_pension = rsum(ContributionsGralSicknessMa- ContributionsHealthselfemploy)
	egen Excises= rsum(IndirecttaxesOilderivatesdi-IndirecttaxesExciseTobacco)
	local taxes Alldirecttaxesandcontributio Alldirecttaxes SIC Allindirecttaxes ///
	IndirecttaxesVATPercapita Excises IndirecttaxesCarbonPercapi
	
	mkmat `taxes' , mat(fig7)	
	mata: a=st_matrix("fig7"):/colsum(st_matrix("fig7")):*100
	mata: b=(colsum(a[1::2,]) \ colsum(a[3::4,]) \ colsum(a[5::6,]) \ colsum(a[7::8,]) \ colsum(a[9::10,]))
	mata: st_matrix("fig7a",b)
	descr `taxes' , varlist 
	mat colnames fig7a = `r(varlist)'
	mat rownames fig7a = Poorest Q2 Q3 Q4 Richest
	matlist fig7a'
	local taxes2 IndirecttaxesVATPercapita  SIC Alldirecttaxes ///
	IndirecttaxesOilderivatesin IndirecttaxesExciseTobacco IndirecttaxesOilderivatesdi ///
	IndirecttaxesCarbonPercapi IndirecttaxesExciseAlcoholic
	
	mkmat `taxes2' , mat(fig07)	
	mkmat Market, mat(mypp)
	mata: st_matrix("fig7b",colsum(st_matrix("fig07")):/colsum(st_matrix("mypp")))
	
	use "pa_pdi_margcontc.dta", clear 
	egen  SIC_non_pension = rsum(ContributionsGralSicknessMa- ContributionsHealthselfemploy)	
	local taxesa IndirecttaxesVATAdultequiv  SIC  Alldirecttaxes ///
	IndirecttaxesOilderivatesin IndirecttaxesExciseTobacco IndirecttaxesOilderivatesdi ///
	IndirecttaxesCarbonAdulteq	IndirecttaxesExciseAlcoholic		 
	mkmat `taxesa', mat(fig7b1)	
	mata: st_matrix("fig7b1", st_matrix("fig7b1"):*100)
	mat fig7b = (fig7b \ fig7b1)
	descr `taxesa', varlist 
	mat colnames fig7b = `r(varlist)'
	
	use "pc_pdi_kakwani.dta", clear 
	local taxes1 IndirecttaxesVATPercapita  IndirecttaxesOilderivatesdi ///
	IndirecttaxesOilderivatesin IndirecttaxesExciseAlcoholic ///
	IndirecttaxesExciseTobacco IndirecttaxesCarbonPercapi ///
	ContributionsGralSicknessMa 
	local taxes2 ContributionsHealthemployeeP ///
	ContributionsHealthselfemploy ContributionsUnemploymentFund ///
	ContributionsWorkInjuryOccu PersonalIncomeTaxinterest ///
	PersonalIncomeTaxPercapita		 
	
	mkmat `taxes1' AI `taxes2', mat(fig7c1)	
	
	use "pc_pdi_margeffc.dta", clear 
	mkmat `taxes1' AF `taxes2', mat(fig7c2)	
	mat fig7c = (fig7c1 \ fig7c2)
	putexcel set "$xl_output", modify  sheet("F7")
	putexcel C21=mat(fig7a')  L21=mat(fig7b') Y21=mat(fig7c'), names
	putexcel (D21:H28), nformat("#0")  overwritefmt 
	putexcel (Z21:Z35), nformat("#0.00") overwritefmt 	 
	putexcel (AA21:AA35), nformat("#0.000") overwritefmt 	 
	putexcel clear 
	
	
}	

if `f8' == 1 {		
	
	use "pc_pdi_detail.dta", clear 
	
	rename C decile 
	destring decile, replace 
	destring Market, replace 	
	local dtr DirtransferPregnancychildb-DirecttransfersotherPercap 
	local subs IndirectsubsidiesElectricity- IndirectsubsidiesGasindirect
	rename AO subs_electricity_ind
	mkmat `dtr' `subs' , mat(fig8)	
	mkmat Market, mat(mypp)
	mata: st_matrix("fig8a",colsum(st_matrix("fig8")):/colsum(st_matrix("mypp")):*100)
	qui descr `dtr' `subs' , varlist 
	mat colnames fig8a  = `r(varlist)'
	
	mkmat `subs' , mat(fig8b)	
	mata: st_matrix("fig8b",colsum(st_matrix("fig8b")):/colsum(st_matrix("mypp")))
	
	use "pa_pdi_margcontc.dta", clear 
	rename AL subs_electricity_ind
	mkmat `subs', mat(fig8b1)	
	mata: st_matrix("fig8b1", st_matrix("fig8b1"):*100)
	mat fig8b = (fig8b \ fig8b1)
	descr `subs', varlist 
	mat colnames fig8b = `r(varlist)'
	
	use "pc_pdi_kakwani.dta", clear 
	descr `dtr' `subs', varlist 
	mkmat `dtr' `subs' , mat(fig8a1)
	mat colnames fig8a1 = `r(varlist)'
	descr `subs', varlist 
	mkmat  `subs' , mat(fig8c1)	
	mat colnames fig8c1 = `r(varlist)'
	
	use "pc_pdi_margeffc.dta", clear 
	mkmat `subs', mat(fig8c2)	
	mat fig8c = (fig8c1 \ fig8c2)
	mat fig8a = (fig8a \  fig8a1)
	
	putexcel set "$xl_output", modify  sheet("F8")
	putexcel C21=mat(fig8a')  L21=mat(fig8b') Y21=mat(fig8c'), names
	putexcel (D21:E42) (Z22:Z25), nformat("#0.00")  overwritefmt 	
	putexcel (AA22:AA25), nformat("#0.000") overwritefmt 	 
	putexcel clear 	
	
}	


if `f9' == 1 {	
	
	use "pc_pdi_detail.dta", clear 
	keep C MarketIncomePensions Alldirecttransfersexclcontri Alldirecttaxes Allcontributions ///
	Allindirectsubsidies Allindirecttaxes Nethealthtransfers Neteducationtransfers
	
	local ivars decyp yp_pc _totdtr_pc _totdtx_pc _totcon_pc _totsub_pc _totitx_pc  _tothlt_pc _totedu_pc 
	tokenize "`ivars'"
	local i=1 
	foreach var of varlist * {
		rename `var' ``i''
		local ++i
	}
	descr 
	destring decyp, replace
	destring yp_pc, replace
	
	egen double net_cash_pc=rsum(_totdtx_pc _totcon_pc _totitx_pc _totdtr_pc _totsub_pc )
	egen double net_fisc_pc=rsum(_totdtx_pc _totcon_pc _totitx_pc _totdtr_pc ///
	_totsub_pc _totedu_pc _tothlt_pc)
	
	tabstat _totdtr_pc _totdtx_pc _totcon_pc _totsub_pc _totitx_pc  _tothlt_pc ///
	_totedu_pc  net_cash_pc net_fisc_pc yp_pc , stat(sum) ///
	format(%18.2fc) by(decyp) save 		
	tabstatmat lcu_net 
	local cols = colsof(lcu_net)
	local col1 = `cols'-1
	mata: st_matrix("fig9", st_matrix("lcu_net")[,1::`col1']:/st_matrix("lcu_net")[,`cols']:*100)
	mat colnames fig9 = dir_transf dir_taxes ssc ind_taxes subs educ hlt netcash fiscalp
	mat rownames fig9 = 1 2 3 4 5 6 7 8 9 10 Total 
	matlist fig9, format(%6.1fc)
	
	putexcel set "$xl_output", modify  sheet("F9")
	putexcel C26=mat(fig9) , nformat("#0.00")  overwritefmt 	
	putexcel clear 
	
}

set scheme tab2
graph set window fontface "Calibri"


cap program drop chart01ch
program define chart01ch   // poverty charts  
preserve 	 
sp_groupfunction [w=weight], poverty(yp_ae yd_ae yc_ae) povertyline(pline_mod) by(`1')
keep if measure=="fgt0"
drop reference _* measure
rename value y1_ 
replace y1_=round(y1_*100,0.001)
reshape wide y1_, i(`1') j(variable) string
rename y1_y* y*
label val `1' `1'
label var yp_ae "Market income plus pensions"
label var yd_ae "Disposable income"
label var yc_ae "Consumable income"
format y*ae %6.1fc
graph bar (mean) yp_ae (mean) yd_ae (mean) yc_ae, over(`1', label(`5' labsize(`4'))) ///
blabel(bar, format(%3.`3'fc)) title(Bulgaria 2020)  ///
subtitle($title1)  ///
caption(Source: Author estimations based on EU-SILC 2021 and HBS 2021 using CEQ methodology, size(small)) ///
legend(order(1 "Market Income plus pensions" 2 "Disposable Income" 3 "Consumable Income") size(small))

graph export "${outp}fig_`2'.png", as(png) replace width(800) height(600)

restore 
end 	

if `f10' == 1 {	
	use "${bgr20_dt}", clear 
	preserve  
	global title1 = "Child poverty (AROP)"
	keep if child_==1
	chart01ch  child_   child00  1 small nolabel 
	apoverty yp_ae yd_ae yc_ae [w=weight], varpl(pline_mod)
	mat define fig10 = J(1,3,.)
	mat fig10[1,1]  = round(real(r(head_1)),0.1)
	mat fig10[1,2]  = round(real(r(head_2)),0.1)
	mat fig10[1,3]  = round(real(r(head_3)),0.1)
	
	mat colnames fig10 = mypp disp consumable 
	mat rownames fig10 = headcount_poverty 	
	
	putexcel set "$xl_output", modify  sheet("F10")
	putexcel b21=mat(fig10) , names
	putexcel b2=image("${outp}fig_child00.png")
	putexcel clear 
	restore 
}

if `f11' == 1 {	
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}	
	global title1 = "Headcount poverty (AROP) by children age "
	chart01ch  ceq_child04   child4  1 small
	mat define fig11 = J(5,3,.)	
	qui forval i=1(1)5 {
		apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child04==`i', varpl(pline_mod)
		mat fig11[`i',1]  = round(real(r(head_1)),0.1)
		mat fig11[`i',2]  = round(real(r(head_2)),0.1)
		mat fig11[`i',3]  = round(real(r(head_3)),0.1)
	}
	
	mat colnames fig11 = mypp disp consumable 
	mat rownames fig11 = 0_2 3_5 6_9 10_13 14_17
	
	putexcel set "$xl_output", modify  sheet("F11")
	putexcel b21=mat(fig11) , names
	putexcel b2=image("${outp}fig_child4.png")
	putexcel clear 
	
}

if `f13' == 1 {	
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}	
	// parents 
	global title1 = "Headcount poverty (AROP) by household w/child category"
	chart01ch  ceq_child01   child13a  1 
	
	
	mat define fig13a = J(2,3,.)	
	
	mat define fig13b = J(4,3,.)
	
	qui forval ij=1(1)2 {
		local j= `ij'-1
		apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child01==`j', varpl(pline_mod)
		mat fig13a[`ij',1]  = round(real(r(head_1)),0.1)
		mat fig13a[`ij',2]  = round(real(r(head_2)),0.1)
		mat fig13a[`ij',3]  = round(real(r(head_3)),0.1)
	}
	
	qui forval ij=1(1)4 {
		local j= `ij'-1
		apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child01a==`j', varpl(pline_mod)
		mat fig13b[`ij',1]  = round(real(r(head_1)),0.1)
		mat fig13b[`ij',2]  = round(real(r(head_2)),0.1)
		mat fig13b[`ij',3]  = round(real(r(head_3)),0.1)
	}
	mat colnames fig13a = mypp disp consumable 
	mat rownames fig13a = nochild child
	
	mat colnames fig13b = mypp disp consumable 
	mat rownames fig13b = nochd_noeld  nochd_eld chd_noeld chd_eld 
	
	
	chart01ch  ceq_child01a  child13b 1 small
	
	
	putexcel set "$xl_output", modify  sheet("F13")
	putexcel b28=mat(fig13a) l28=mat(fig13b), names
	putexcel b1=image("${outp}fig_child13a.png") ///
	l1=image("${outp}fig_child13b.png")	
	putexcel clear 
	
}

if `f14' == 1 {	
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}	
	global title1 = "Headcount poverty (AROP) by household category"
	chart01ch  ceq_child02   child2  0 small 
	mat define fig14 = J(4,3,.)	
	forval i=1(1)4 {
		local j=`i'-1
		apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child02==`j', varpl(pline_mod)
		mat fig14[`i',1]  = round(real(r(head_1)),0.1)
		mat fig14[`i',2]  = round(real(r(head_2)),0.1)
		mat fig14[`i',3]  = round(real(r(head_3)),0.1)
	}
	
	mat colnames fig14 = mypp disp consumable 
	mat rownames fig14 = no_child 1_chd 2_chd 3+child
	
	putexcel set "$xl_output", modify  sheet("F14")
	putexcel b28=mat(fig14) , names
	putexcel b1=image("${outp}fig_child2.png")
	putexcel clear 
	
}


if `f16' == 1 {	
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}	
	global title1 = "Headcount poverty (AROP) by household w/child category"
	chart01ch  ceq_child03   child3  1 
	chart01ch  ceq_child03a  child3a 0 small
	
	mat define fig16a = J(2,3,.)	
	mat define fig16b = J(3,3,.)	
	
	forval i=1(1)2 {
		local j=`i'-1
		apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child03==`j', varpl(pline_mod)
		mat fig16a[`i',1]  = round(real(r(head_1)),0.1)
		mat fig16a[`i',2]  = round(real(r(head_2)),0.1)
		mat fig16a[`i',3]  = round(real(r(head_3)),0.1)
	}
	
	apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child03a==0, varpl(pline_mod)
	mat fig16b[1,1]  = round(real(r(head_1)),0.1)
	mat fig16b[1,2]  = round(real(r(head_2)),0.1)
	mat fig16b[1,3]  = round(real(r(head_3)),0.1)
	
	apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child03a==2, varpl(pline_mod)
	mat fig16b[2,1]  = round(real(r(head_1)),0.1)
	mat fig16b[2,2]  = round(real(r(head_2)),0.1)
	mat fig16b[2,3]  = round(real(r(head_3)),0.1)
	
	apoverty yp_ae yd_ae yc_ae [w=weight] if ceq_child03a==3, varpl(pline_mod)
	mat fig16b[3,1]  = round(real(r(head_1)),0.1)
	mat fig16b[3,2]  = round(real(r(head_2)),0.1)
	mat fig16b[3,3]  = round(real(r(head_3)),0.1)	
	
	
	mat colnames fig16a = mypp disp consumable 
	mat colnames fig16b = mypp disp consumable 
	mat rownames fig16a = both_parents_or_2_breadwinner lone_parents
	mat rownames fig16b = both_parents_or_2_breadwinner lone_male_parent lone_female_parent
	
	
	putexcel set "$xl_output", modify  sheet("F16")
	putexcel b28=mat(fig16a) l28=mat(fig16b), names
	putexcel b1=image("${outp}fig_child3.png") l1=image("${outp}fig_child3a.png")
	putexcel clear 
	
}



if `f15_f17' == 1 {	
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}		
	
	egen dtr_fncx_pc = rsum(dtr_fnc*_pc)
	label var dtr_fncx_pc "Family & child contributory"
	egen dtr_fnnx_pc = rsum(dtr_fnn*_pc)
	label var dtr_fnnx_pc "Family & child non-mean tested"
	egen dtr_fmnx_pc = rsum(dtr_fmn*_pc)
	label var dtr_fmnx_pc "Family & child mean-tested"
	
	clonevar ceq_child03c = ceq_child03a
	replace ceq_child03c = 4 if ceq_child03c==.
	cap label drop ceq_child03c
	label copy ceq_child03a ceq_child03c
	label define ceq_child03c 4 "No child", add 
	tabstat dtr_f*x_pc dtr_disb_pc dtr_oldb_pc dtr_unem_pc dtr_gmis_pc dtr_hais_pc dtr_othr_pc [w=weight]  ///
	, stat(sum) save by(ceq_child03c)
	tabstatmat fnc  
	
	mata: a=st_matrix("fnc")[1::4,]
	mata: b=colsum(a)
	mata: st_matrix("fnc1",a:/b:*100)
	matlist fnc1, format(%6.1fc)	
	cap drop fnc1a*
	
	svmat fnc1, name(fnc1a)
	cap drop num1
	
	gen num1 = _n 
	
	label val ceq_child03c ceq_child03c
	
	graph bar (mean) fnc1a1 (mean) fnc1a2 (mean) fnc1a3 (mean) fnc1a4 (mean) fnc1a5  ///
	(mean) fnc1a6 (mean) fnc1a7 (mean) fnc1a8 ///		
	if num1<5, over(num1, relabel(1 "Both parents" 2 "Male lone parent" ///
	3 "Female lone parent" 4 "No children") label(labsize(small))) ///
	bar(1, color(black) fcolor("179 0 0") lwidth(vthin)) bar(2, color(black) fcolor("124 17 88") lwidth(vthin))  ///
	bar(3, color(black) fcolor("68 33 175") lwidth(vthin)) bar(4, color(black) fcolor("26 83 255")  lwidth(vthin))   ///
	bar(5, color(black) fcolor("13 136 230")lwidth(vthin)) bar(6, color(black) fcolor("0 183 199") lwidth(vthin))  ///
	bar(7, color(black) fcolor("90 212 90") lwidth(vthin)) bar(8, color(black) fcolor("139 224 78") lwidth(vthin))  ///
	ytitle(fdasu) ytitle(, size(small) margin(sides)) ylabel(, labsize(small)) ///
	b1title("Household type", size(small))  ///
	ytitle("Percent of total direct transfers (%)" , size(small))  ///
	legend(size(vsmall) rows(3) order( ///
	1 "Family contributory" ///
	2 "Family non-means tested" ///
	3 "Family mean-tested" ///
	4 "Disability" ///
	5 "Old age" ///
	6 "Unemployment" ///
	7 "Social Assistance" ///
	8 "Heath allowance" ) ) graphregion(color(white)) bgcolor(white)
	
	graph export "${outp}fig_B1.png", as(png) replace width(800) height(600)			
	
	// by household size 
	
	tabstat dtr_f*x_pc dtr_disb_pc dtr_oldb_pc dtr_unem_pc dtr_gmis_pc dtr_hais_pc dtr_othr_pc [w=weight]  ///
	, stat(sum) save by(ceq_child02)
	tabstatmat fnc  
	
	mata: a=st_matrix("fnc")[1::4,]
	mata: b=colsum(a)
	mata: st_matrix("fnc2",a:/b:*100)
	matlist fnc2
	
	cap drop fnc2a*	
	
	svmat fnc2, name(fnc2a)
	cap drop num1 
	gen num1 = _n 	
	
	graph bar (mean) fnc2a1 (mean) fnc2a2 (mean) fnc2a3 (mean) fnc2a4 (mean) fnc2a5  ///
	(mean) fnc2a6 (mean) fnc2a7 (mean) fnc2a8 ///		
	if num1<5, over(num1, relabel(1 "No children" 2 "1 child" ///
	3 "2 children" 4 "3+children") label(labsize(small))) ///
	bar(1, color(black) fcolor("179 0 0") lwidth(vthin)) bar(2, color(black) fcolor("124 17 88") lwidth(vthin))  ///
	bar(3, color(black) fcolor("68 33 175") lwidth(vthin)) bar(4, color(black) fcolor("26 83 255")  lwidth(vthin))   ///
	bar(5, color(black) fcolor("13 136 230")lwidth(vthin)) bar(6, color(black) fcolor("0 183 199") lwidth(vthin))  ///
	bar(7, color(black) fcolor("90 212 90") lwidth(vthin)) bar(8, color(black) fcolor("139 224 78") lwidth(vthin))  ///
	/*blabel(bar, size(small) format(%4.0f)) */ ///
	ytitle(fdasu) ytitle(, size(small) margin(sides)) ylabel(, labsize(small)) ///
	b1title("Household type", size(small))  ///
	ytitle("Percent of total direct transfers (%)" , size(small))  ///
	legend(size(vsmall) rows(3) order( ///
	1 "Family contributory" ///
	2 "Family non-means tested" ///
	3 "Family mean-tested" ///
	4 "Disability" ///
	5 "Old age" ///
	6 "Unemployment" ///
	7 "Social Assistance" ///
	8 "Heath allowance" ) ) graphregion(color(white)) bgcolor(white)		
	
	graph export "${outp}fig_B2.png", as(png) replace width(800) height(600)
	
	
	putexcel set "$xl_output", modify  sheet("F15_F17")
	putexcel b28=mat(fnc1) L28=mat(fnc2), names
	putexcel b1=image("${outp}fig_B1.png") L1=image("${outp}fig_B2.png")
	putexcel clear 	
	clear 
	
}

if `f12' == 1 {
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}		
	
	cap program drop marg_contch
	program define marg_contch  // marginal contributions to child poverty 
	syntax , def1(string asis) pline(string) fig1(string) wb(string) sh(string) [ord(string)]
	local d1 = "`def1'"
	local p1 = "`pline'"
	if "`ord'"=="" local ord = "1"
	
	preserve 
	foreach var of varlist dtr*`d1' sub*`d1' {
		local vardtr = substr("`var'",1,8)
		gen yc_`d1'_`vardtr' =  yc_`d1' - `var'	
	}	
	
	foreach var of varlist itx*`d1' dtx*`d1' con*`d1' {
		local vardtr = substr("`var'",1,8)
		gen yc_`d1'_`vardtr' =  yc_`d1' + `var'	
	}	
	
	apoverty yc_`d1' yc_`d1'_dtr_fncb [w=weight], varpl(`p1')
	tab child_
	
	sp_groupfunction [w=weight], poverty(yc_`d1'*) povertyline(`p1') by(child_)
	keep if measure=="fgt0"
	drop reference _* measure
	rename value y1_ 
	replace y1_=round(y1_*100,0.001)
	list 
	
	reshape wide y1_, i(child_) j(variable) string
	rename y1_y* y*
	format yc* %2.1fc
	list 
	descr 
	foreach var of varlist yc_`d1'_dtr_disb-yc_`d1'_sub_gasi {
		local vardtr = substr("`var'",7,8)
		gen d_`vardtr' = `var' - yc_`d1' 	 
	}	
	
	keep child d_*		
	reshape long d_ , i(child_) j(fisc) string 		
	keep if child_==1
	format d_ %2.1fc 
	merge m:1 fisc using "${tmp}varnames1.dta", 
	drop child_ _m 
	if "`ord'"=="1" gsort -d_
	if "`ord'"=="2" sort fisc
	order varlab  d_ 
	list 
	
	replace varlab = regexr(varlab,"Dir.[T|t]ran[s|f][e|f][e|r][r|s](s*)","Direct Transfer")
	replace varlab = regexr(varlab,"Direct [t|T]ranfers","Direct Transfer")	
	replace varlab = subinstr(varlab,"N-NMT","non means-tested",1)	
	replace varlab = subinstr(varlab,"N-NM","non means-tested",1)	
	gen tmp1 = regexm(varlab,"non means-tested")
	replace varlab = subinstr(varlab,"non means-tested","",1) if tmp1==1
	replace varlab = varlab + "(non means-tested)" if tmp1==1
	gen tmp2 = regexm(varlab,"N-MT")
	replace varlab = subinstr(varlab,"N-MT","",1) if tmp2==1
	replace varlab = varlab + "(means-tested)" if tmp2==1
	replace varlab = subinstr(varlab,"old-age nc","non-contributory pensions",1) 
	replace varlab = subinstr(varlab,"achild","a child",1) 
	replace varlab = subinstr(varlab,"Family  ","Family ",1) 
	drop tmp2 tmp1 
	
	drop if inlist(fisc,"itx_car2","itx_carb")	
	list 
	
	encode varlab, gen(fiscal_intervention)
	table fiscal_intervention, stat(mean d_) nformat(%2.1fc) nototal 
	
	graph hbar (mean) d_ if substr(fisc,1,3)=="dtr", over(fiscal_intervention, sort(d_) descending  ///
	label(labsize(vsmall)) axis(lcolor(maroon) outergap(2))) stack ///
	blabel(bar, format(%3.1f)) ///
	ytitle(`"Marginal contribution to child poverty reduction"') ///
	ytitle(, size(small)) yscale(fextend) ylabel(-7(1)6, labsize(tiny)) 
	graph export "`fig1'.png", as(png) replace width(800) height(600)			
	
	label var d_ "Marginal contribution to child poverty reduction" 
	replace d_ = 0 if d_==.
	label var varlab "Fiscal intervention"
	list varlab d_
	if "`ord'"=="1" sort d_ varlab 
	if "`ord'"=="2" {
		tempvar fisc3 
		gen `fisc3'=substr(fisc,1,3)
		gsort /*`fisc3'*/ d_ varlab 
	}	
	drop if substr(fisc,1,3)=="con"
	export excel varlab d_ using "`wb'", sheet(`sh',modify) firstrow(varlabels) 
	format %6.1f d_
	restore 
	
	end 
	
	cd "${tmp}"
	
	marg_contch, def1(ae) pline(pline_mod) fig1(fig1a) wb("$xl_output") sh(F12) ord(1)
	
	
	mata: b = xl()
	mata: b.load_book("$xl_output")
	mata: b.set_sheet("F12")
	mata: rows = (2,39)
	mata: cols = (2,2)
	mata: b.set_number_format(rows,cols,"#0.0")
	mata: b.set_column_width(1,1,40)
	mata: b.close_book()
	
}

if `f18_f20' == 1 {
	
	/*  
		Primary info is produced by 10_BGR20_sim_table3_Nov07_2023.do
		Populates BGR20_sim_Nov07_2023.xlsx
		This section only collect info from the previous Excel file 
	*/
	
	putexcel set "$xl_sims", modify  sheet("F18")
	putexcel O1="Baseline" p1="PIT reform (2022)" q1="PIT reform (2022) conditional" ///
	V1 = formula(o1) w1 = formula(p1) x1 = formula(q1)  ///
	P18 = "National" Q18="Child"  o19= "Poverty" o20="Poverty gap" ///
	o21 = "Inequality (Gini points)" w17= "Tax collection" ///
	x17 = "Child tax reform" V18=formula(W1) V19=formula(X1) ///
	P19 = formula(pit_2!C66) P20 = formula(pit_2!C67) P21 = formula(pit_2!C68*100) ///
	Q19 = formula(pit_2!F66) Q20 = formula(pit_2!F67) ///
	W18 = formula(pit!D27/1000000) X18 = formula(pit!E27/1000000) ///
	W19 = formula(pit_2!D27/1000000) X19 = formula(pit_2!E27/1000000)	 ///
	O2=formula(pit!B35) P2=formula(pit!C35) Q2=formula(pit_2!C35) ///
	N2=formula(pit!a17) U2=formula(pit!a17)
	
	
	forval ij = 3(1)11 {
		local k = `ij'+33
		local l = `ij'+15
		local m = `ij'-1
		local bf18 = "`bf18'  O`ij'=formula(pit!B`k'+O`m')" + ///
		" P`ij'=formula(pit!C`k'+P`m')" + ///
		" Q`ij'=formula(pit_2!C`k'+Q`m') N`ij'=formula(pit!A`l')" + ///
		" U`ij'=formula(pit!A`l')"
		local k = `ij'+48
		local bf182 = "`bf182' V`ij'=formula(pit!B`k') W`ij'=formula(pit!C`k')" + ///
		" X`ij'=formula(pit_2!C`k')" 	
		
	}	
	
	putexcel `bf18' `bf182'
	putexcel (O2:Q11) (V2:X11) (P19:Q21), nformat("##0.0") overwritefmt
	putexcel (W18:X19), nformat("#,###") overwritefmt
	
	putexcel clear 	
	
	putexcel set "$xl_sims", modify  sheet("F19")
	putexcel Q1="Baseline" R1="Child allowance reform" P2=0 Q2=0 R2=0 ///
	U2="Baseline" V2="Child allowance reform" ///		
	P18 = "National" Q18="Child"  o19= "Poverty" o20="Poverty gap" ///
	o21 = "Inequality (Gini points)" ///
	w17= "Baseline" x17 = "Child allowance reform" ///
	V18=formula(Q1) ///
	P19 = formula(child!C66) P20 = formula(child!C67)  P21 = formula(child!C68*100) ///
	Q19 = formula(child!F66) Q20 = formula(child!F67) ///
	W18 = formula(child!D27/1000000) X18 = formula(child!E27/1000000) 
	
	forval ij = 3(1)12 {
		local k = `ij'+32		
		local km = (`ij'-2)*10
		local m = (`ij'-1)
		local bf19 = "`bf19' P`ij'= `km' Q`ij'=formula(child!B`k' + Q`m')" + ///
		" R`ij'=formula(child!C`k' + R`m')" 		
		local k = `ij'+47
		local im = `ij'-2
		local bf192 = "`bf192' U`ij'=formula(child!B`k') V`ij'=formula(child!C`k')" + ///
		" T`ij'= formula(child!A`k')"
	}	
	
	putexcel `bf19' `bf192'
	putexcel (Q2:R12) (U3:V12) (P19:Q21), nformat("##0.0") overwritefmt
	putexcel (W18:X19), nformat("#,###") overwritefmt
	
	putexcel clear 	
	
	putexcel set "$xl_sims", modify  sheet("F20")
	putexcel U2="Baseline" V2="Child allowance + PIT reform" ///		
	P18 = "National" Q18="Child"  o19= "Poverty" o20="Poverty gap" ///
	o21 = "Inequality (Gini points)" ///
	v17 = "Fiscal cost" w17= formula(U1) x17=formula(V2) /// 
	v18 = "Tax collection" v19 = "Expenditure" ///
	z17 = "Additional cost" ///
	w17 = formula(U2) x17=formula(V2) ///
	P19 = formula(child_asp!C66) P20 = formula(child_asp!C67)  ///
	P21 = formula(child_asp!C68*100) ///
	Q19 = formula(child_asp!F66) Q20 = formula(child_asp!F67) ///
	W18 = formula(pit_2!D27/1000000) X18 = formula(pit_2!E27/1000000) ///
	W19 = formula(child_asp!D27/1000000) X19 = formula(child_asp!E27/1000000) ///
	Z18 = formula(W18-X18) Z19 = formula(X19-W19) 		
	
	forval ij = 3(1)12 {
		local m = `ij'+32				
		local k = `ij'+47
		local bf20 = "`bf20' U`ij'=formula(child!B`k')" + ///
		" V`ij'=formula(child_asp!C`k'+pit_2!B`k'-pit_2!C`k')" +  ///
		" T`ij'=formula(child_asp!A`m')"
	}	
	
	putexcel `bf20'
	putexcel  (U3:V12) (P19:Q21), nformat("##0.0") overwritefmt
	putexcel (W18:Z19), nformat("#,###") overwritefmt
	putexcel A2 = image("${outp}pov_childa.png")
	
	putexcel clear 	
	
	local b00 = subinstr("${xl_sims}","${outp}","",1)
	di "`b00'"
	
	putexcel set "$xl_output", modify  sheet("F18")
	forval i=1(1)11 {
		local b  = "`b' N`i' = formula('[`b00']F18'!N`i')" + ///
		" O`i' = formula('[`b00']F18'!O`i')" + ///
		" P`i' = formula('[`b00']F18'!P`i')" + ///
		" Q`i' = formula('[`b00']F18'!Q`i')" + ///
		" U`i' = formula('[`b00']F18'!U`i')" + ///
		" V`i' = formula('[`b00']F18'!V`i')" + ///
		" W`i' = formula('[`b00']F18'!W`i')" + ///
		" X`i' = formula('[`b00']F18'!X`i')" 
	}		
	
	
	forval i=18(1)21 {
		local c = "`c' O`i' = formula('[`b00']F18'!O`i')" + ///
		" P`i' = formula('[`b00']F18'!P`i')" +  ///
		" Q`i' = formula('[`b00']F18'!Q`i')" 
	}
	
	forval i=17(1)19 {
		local d = "`d' V`i' = formula('[`b00']F18'!V`i')" + ///
		" W`i' = formula('[`b00']F18'!W`i')" + ///
		" X`i' = formula('[`b00']F18'!X`i')" 
	}
	
	putexcel `b' , nformat("##0.0") overwritefmt
	putexcel `c' `d' , nformat("##0.0") overwritefmt
	**putexcel (O2:Q11) (V2:V11) (P19:Q21), nformat("##0.0") overwritefmt
	
	putexcel clear 
	
	putexcel set "$xl_output", modify  sheet("F19")
	forval i=1(1)12 {
		local b19 = "`b19' P`i' = formula('[`b00']F19'!P`i')" + ///
		" Q`i' = formula('[`b00']F19'!Q`i')"+ ///
		" R`i' = formula('[`b00']F19'!R`i')"+ ///
		" T`i' = formula('[`b00']F19'!T`i')"+ ///
		" U`i' = formula('[`b00']F19'!U`i')"+ ///
		" V`i' = formula('[`b00']F19'!V`i')" 
	}
	
	forval i=18(1)21 {
		local c19 = "`c19'  O`i' = formula('[`b00']F19'!O`i')" + ///
		" P`i' = formula('[`b00']F19'!P`i')" + ///
		" Q`i' = formula('[`b00']F19'!Q`i')" 
	}
	forval i=17(1)18 {
		local d19 = "`d19' V`i' = formula('[`b00']F19'!V`i')" + ///
		" W`i' = formula('[`b00']F19'!W`i')" + ///
		" X`i' = formula('[`b00']F19'!X`i')" 
	}	
	
	putexcel `b19' `c19' `d19', nformat("##0.0") overwritefmt
	
	putexcel clear 
	
	putexcel set "$xl_output", modify  sheet("F20")
	forval i=2(1)12 {
		local b20 = "`b20' T`i' = formula('[`b00']F20'!T`i')" + ///
		" U`i' = formula('[`b00']F20'!U`i')" + ///
		" V`i' = formula('[`b00']F20'!V`i')" 
	}
	
	forval i=18(1)21 {
		local c20 = "`c20' O`i' = formula('[`b00']F20'!O`i')" + ///
		" P`i' = formula('[`b00']F20'!P`i')" + ///
		" Q`i' = formula('[`b00']F20'!Q`i')" 
	}
	forval i=17(1)19 {
		local d20 = "`d20' V`i' = formula('[`b00']F20'!V`i')" + ///
		" W`i' = formula('[`b00']F20'!W`i')" + ///
		" X`i' = formula('[`b00']F20'!X`i')" + ///
		" Z`i' = formula('[`b00']F20'!Z`i')" 
	}	
	
	putexcel `b20' `c20', nformat("##0.0") overwritefmt
	putexcel `d20', nformat("##0.0") overwritefmt
	
	putexcel clear 
	
}




/*==================================================
	2: Tables
==================================================*/

*----------Table 1. Fiscal interventions included in the CEQ and child poverty analysis and child-relevant budgets

// Detailed sources are included in tab Table1b_B3_SOURCE

*----------Table 2. Bulgaria 2020: Self-defined economic status, 18+ years, by household type, percentages 

if `t2'==1 {
	
	if c(filename)!="${bgr20_dt}" {
		use "${bgr20_dt}", clear 	
	}
	table () ceq_child03a if age>=18 [w=weight], stat(fvpercent pl032) nformat(%5.1fc)
	collect style header pl032, title(hide)
collect export  "$xl_output", sheet("T2") cell(B2) modify 

}

*----------Table 3. Summary of child poverty and inequality effects
if `t3'==1 {
	
	
	
	use "${bgr20_dt}", clear 	
	
	
	cap program drop marg_contch2
	program define marg_contch2  // marginal contributions to child poverty 
	syntax , pline(string) fig1(string) wb(string) sh(string) [ord(string)]
	
	local p1 = "`pline'"
	if "`ord'"=="" local ord = "1"
	
	preserve 
	
	foreach var of varlist dtr*_ae sub*_ae {
		local vardtr = substr("`var'",1,8)
		gen yc_ae_`vardtr' =  yc_ae - `var'	
	}	
	
	foreach var of varlist itx*_ae  {
		local vardtr = substr("`var'",1,8)
		gen yc_ae_`vardtr' =  yc_ae + `var'	
	}	
	keep if child_==1
	descr yc_ae_*
	sp_groupfunction [w=weight], poverty(yc_ae*) povertyline(`p1') by(child_)
	keep if measure=="fgt0"
	drop reference _* measure
	rename value y1_ 
	replace y1_=round(y1_*100,0.001)
	drop if child_==0
	
	summ y1_ if variable=="yc_ae"
	gen base = r(mean) 
	gen marg = y1_-base
	drop if inlist(variable,"yc_ae_itx_car2","yc_ae")
	keep variable marg 
	replace variable = subinstr(variable,"yc_ae_","", 1)
	list 
	export excel variable marg  using "`wb'", sheet(`sh',modify) ///
	firstrow(varlabels) cell(B100) 
	
	restore 
	end 
	
	
	marg_contch2, pline(pline_mod) fig1(fig1a) wb("$xl_output") sh(T3) ord(1)
	
	/* use "pa_pdi_margcontc.dta", clear 
		drop All* Net*
		drop PersonalIncomeTaxinterest- ContributionsHealthselfemploy 
		drop itx_car2* IndirecttaxesCarbon*
		rename AL subs_electricity_ind
		descr DirtransferPregnancychildb- InKindeducationbenefitsTert, varlist
		di "`r(varlist)'"
		mkmat DirtransferPregnancychildb- InKindeducationbenefitsTert, mat(tab3a)
		mata: st_matrix("tab3a",st_matrix("tab3a"):*100)
	*/
	
	use "pc_pdi_margeffc.dta", clear 
	drop All* Net*
	drop PersonalIncomeTaxinterest- ContributionsHealthselfemploy 
	drop itx_car2* IndirecttaxesCarbon*
	rename AL subs_electricity_ind
	foreach var of varlist DirtransferPregnancychildb- InKindeducationbenefitsTert {
		replace `var'=`var'*100 
	}
	descr DirtransferPregnancychildb- IndirecttaxesExciseTobacco, varlist
	mkmat DirtransferPregnancychildb- IndirecttaxesExciseTobacco, mat(tab3b)
	mat colnames tab3b = `r(varlist)'
	
	use "pc_pdi_margefff.dta", clear 
	cap drop All* 
	cap drop Net*
	cap drop PersonalIncomeTaxinterest- ContributionsHealthselfemploy 
	cap drop itx_car2* IndirecttaxesCarbon*
	foreach var of varlist InKindhealthbenefitsSocial- InKindeducationbenefitsTert {
		replace `var'=`var'*100 
	}
	descr InKindhealthbenefitsSocial- InKindeducationbenefitsTert, varlist
	mkmat InKindhealthbenefitsSocial- InKindeducationbenefitsTert, mat(tab3b2)
	mat colnames tab3b2 = `r(varlist)'
	mat tab3b = (tab3b, tab3b2)
	
	
	
	use "pc_pdi_kakwani.dta", replace 
	drop All* Net*
	drop PersonalIncomeTaxinterest- ContributionsHealthselfemploy 
	drop itx_car2* IndirecttaxesCarbon*
	rename AO subs_electricity_ind
	descr DirtransferPregnancychildb- InKindeducationbenefitsTert, varlist
	local nn = "`r(varlist)'"
	mkmat DirtransferPregnancychildb- InKindeducationbenefitsTert, mat(tab3c)
	/* mat colnames tab3a = `nn' */
	mat colnames tab3c = `nn'
	
	
	putexcel set "$xl_output", modify  sheet("T3")
	putexcel B54=mat(tab3b') , names
	putexcel D55=mat(tab3c') 
	putexcel D54="Kakwani" C54= "Marginal contribution to redistributive effect"
	
	putexcel clear 		
	
	mata: b = xl()
	mata: b.load_book("$xl_output")
	mata: b.set_sheet("T3")
	mata: rows = (55,95)
	mata: cols = (3,3)
	mata: b.set_number_format(rows,cols,"#0.0")
	mata: rows = (55,95)
	mata: cols = (4,5)
	mata: b.set_number_format(rows,cols,"#0.000")
	mata: b.set_column_width(2,2,40)
	mata: b.close_book()
	
}

if  `A1'== 1 {
	// annex 1 
	
	use "${bgr19_dt}", clear 	
	
	ainequal yp_pc yn_pc yd_pc yc_pc yf_pc [w=weight]	
	mat an1_1_19 = (real(r(gini_1))\real(r(gini_2))\real(r(gini_3))\ real(r(gini_4))\real(r(gini_5))) 
	
	apoverty yp_ae yn_ae yd_ae yc_ae  [w=weight], varpl(pline_mod)
	mat an1_2_19 = (real(r(head_1))\real(r(head_2))\real(r(head_3))\ real(r(head_4)))
	
	gen pline_685 = 6.85*.38042116*(114.41839/110.93615)*365	
	apoverty yp_pc yn_pc yd_pc yc_pc  [w=weight], varpl(pline_685)
	mat an1_3_19 = (real(r(head_1))\real(r(head_2))\real(r(head_3))\ real(r(head_4)))
	
	putexcel set "$xl_output", modify  sheet("A1")
	putexcel E65=mat(an1_1_19) F65=mat(an1_2_19) G65=mat(an1_3_19)
	putexcel clear 		
	
	
	use "${bgr20_dt}", clear 	
	ainequal yp_pc yn_pc yd_pc yc_pc yf_pc [w=weight]	
	mat an1_1 = (real(r(gini_1))\real(r(gini_2))\real(r(gini_3))\ real(r(gini_4))\real(r(gini_5))) 
	
	apoverty yp_ae yn_ae yd_ae yc_ae  [w=weight], varpl(pline_mod)
	mat an1_2 = (real(r(head_1))\real(r(head_2))\real(r(head_3))\ real(r(head_4)))
	
	apoverty yp_pc yn_pc yd_pc yc_pc  [w=weight], varpl(pline_685)
	mat an1_3 = (real(r(head_1))\real(r(head_2))\real(r(head_3))\ real(r(head_4)))
	
	putexcel set "$xl_output", modify  sheet("A1")
	putexcel B65=mat(an1_1) C65=mat(an1_2) D65=mat(an1_3)
	putexcel clear 		
	
	preserve 
	
	use "pc_pdi_detail.dta", clear 
	
	drop C- PopulationShare Allnetinkindtransfers- Allnettransfersandsubsidies itx_car2_pc
	gen one=1
	destring MarketIncomePensions, replace 
	collapse (sum) MarketIncomePensions- Neteducationtransfers, by(one)
	
	qui foreach var of varlist DirtransferPregnancychildb- Neteducationtransfers {
		replace `var' = (`var' / MarketIncomePensions)*100
		local a: variable label `var'
		local b = subinstr("`a'","(sum) ","",1)
		label variable `var' "`b'"
	}	
	drop ContributionsGralSicknessMa- ContributionsHealthselfemploy Alldirecttransfersinclcontri
	rename AO subs_electricity_ind
	
	order Alldirecttransfersexclcontri DirtranfersFamilyNNMmother  ///
		DirtranfersFamilyNNMchild DirtransferBenefitforraisin              ///
		DirtranfersFamilyNNMTBirth DirtranfersSchoolchildrenen             ///
		DirecttransfersoldagencPe DirecttransferSocialMonthly              ///
		DirtransferBenefitforbring DirtransfersFamilyNNMOther              ///
		DirtransferPregnancychildb DirecttransferHeatingallowan            ///
		DirecttransfersotherPercap OtherFamilyContributorytransf           ///
		DirTransferMonthlychildallo Directtransfersunemployment            ///
		DirecttransfersdisabilityPe DirTransferFamilyNMTOther              ///
		Allindirectsubsidies IndirectsubsidiesGasdirecte subs_electricity_ind                ///
		IndirectsubsidiesGasindirect IndirectsubsidiesElectricity          ///
		Nethealthtransfers InKindhealthbenefitsSocial                      ///
		In_kindhealthbenefitsPublic Neteducationtransfers                  ///
		InKindeducationbenefitsPre In_kindeducationbenefitsprima           ///
		InKindeducationbenefitsLowe  InKindeducationbenefitsUppe           ///
		InKindeducationbenefitsTert 	///
		Allindirecttaxes IndirecttaxesVATPercapita ///
		IndirecttaxesOilderivatesdi IndirecttaxesOilderivatesin ///
		IndirecttaxesExciseAlcoholic IndirecttaxesExciseTobacco ///
		Allcontributions Alldirecttaxes
	cap drop one 
	drop MarketIncomePensions- Alltaxesandcontributions
	
	mkmat *, mat(a)
	mat b= a'
	describe, replace clear
	svmat b	
	rename varlab intervention
	rename b1     size
	export excel size ///
	using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(C71)	
	
	use "pc_pdi_kakwani.dta", clear 
	drop C-MarketIncomePensions
	drop ContributionsGralSicknessMa- ContributionsHealthselfemploy Alldirecttransfersinclcontri
	drop itx_car2_pc Alltaxes Alltaxesandcontributions 
	rename AO subs_electricity_ind
	order Alldirecttransfersexclcontri DirtranfersFamilyNNMmother  ///
		DirtranfersFamilyNNMchild DirtransferBenefitforraisin              ///
		DirtranfersFamilyNNMTBirth DirtranfersSchoolchildrenen             ///
		DirecttransfersoldagencPe DirecttransferSocialMonthly              ///
		DirtransferBenefitforbring DirtransfersFamilyNNMOther              ///
		DirtransferPregnancychildb DirecttransferHeatingallowan            ///
		DirecttransfersotherPercap OtherFamilyContributorytransf           ///
		DirTransferMonthlychildallo Directtransfersunemployment            ///
		DirecttransfersdisabilityPe DirTransferFamilyNMTOther              ///
		Allindirectsubsidies IndirectsubsidiesGasdirecte subs_electricity_ind                ///
		IndirectsubsidiesGasindirect IndirectsubsidiesElectricity          ///
		Nethealthtransfers InKindhealthbenefitsSocial                      ///
		In_kindhealthbenefitsPublic Neteducationtransfers                  ///
		InKindeducationbenefitsPre In_kindeducationbenefitsprima           ///
		InKindeducationbenefitsLowe  InKindeducationbenefitsUppe           ///
		InKindeducationbenefitsTert 	///
		Allindirecttaxes IndirecttaxesVATPercapita ///
		IndirecttaxesOilderivatesdi IndirecttaxesOilderivatesin ///
		IndirecttaxesExciseAlcoholic IndirecttaxesExciseTobacco ///
		Allcontributions Alldirecttaxes
	
	drop PersonalIncomeTaxinterest- Allnettransfersandsubsidies
	
	mkmat *, mat(a)
	mat b= a'
	describe, replace clear
	svmat b
	rename b1 kakwani
	export excel kakwani using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(d71)
	export excel varlab	 using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(B71)
	
	// Redistributive effect 
	use "pc_pdi_margeffc.dta", clear 
	drop B C
	drop ContributionsGralSicknessMa- ContributionsHealthselfemploy Alldirecttransfersinclcontri
	drop itx_car2_pc Alltaxes Alltaxesandcontributions 
	drop InKindhealthbenefitsSocial- Allnettransfersandsubsidies
	rename AL subs_electricity_ind
	append using "pc_pdi_margefff.dta"
	foreach var of varlist * {
		qui summ `var', meanonly
		replace `var' = r(mean)
	}
	keep in 1/1	
	order Alldirecttransfersexclcontri DirtranfersFamilyNNMmother  ///
		DirtranfersFamilyNNMchild DirtransferBenefitforraisin              ///
		DirtranfersFamilyNNMTBirth DirtranfersSchoolchildrenen             ///
		DirecttransfersoldagencPe DirecttransferSocialMonthly              ///
		DirtransferBenefitforbring DirtransfersFamilyNNMOther              ///
		DirtransferPregnancychildb DirecttransferHeatingallowan            ///
		DirecttransfersotherPercap OtherFamilyContributorytransf           ///
		DirTransferMonthlychildallo Directtransfersunemployment            ///
		DirecttransfersdisabilityPe DirTransferFamilyNMTOther              ///
		Allindirectsubsidies IndirectsubsidiesGasdirecte subs_electricity_ind                ///
		IndirectsubsidiesGasindirect IndirectsubsidiesElectricity          ///
		Nethealthtransfers InKindhealthbenefitsSocial                      ///
		In_kindhealthbenefitsPublic Neteducationtransfers                  ///
		InKindeducationbenefitsPre In_kindeducationbenefitsprima           ///
		InKindeducationbenefitsLowe  InKindeducationbenefitsUppe           ///
		InKindeducationbenefitsTert  ///
		Allindirecttaxes IndirecttaxesVATPercapita ///
		IndirecttaxesOilderivatesdi IndirecttaxesOilderivatesin ///
		IndirecttaxesExciseAlcoholic IndirecttaxesExciseTobacco ///
		Allcontributions Alldirecttaxes
	drop PersonalIncomeTaxinterest- IndirecttaxesCarbonPercapi	
	mkmat *, mat(a)
	mat b= a'
	describe, replace clear
	svmat b
	rename b1 RE
	export excel RE using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(E71)
	
	// AROP
	use "pa_pdi_margcontc", clear 
	drop B C 
	drop ContributionsGralSicknessMa- ContributionsHealthselfemploy Alldirecttaxesandcontributio
	drop itx_car2_ae Alltaxes Alltaxesandcontributions InKindhealthbenefitsSocial- Allnettransfersandsubsidies
	rename AL subs_electricity_ind
	order Alldirecttransfersexclcontri DirtranfersFamilyNNMmother  ///
		DirtranfersFamilyNNMchild DirtransferBenefitforraisin              ///
		DirtranfersFamilyNNMTBirth DirtranfersSchoolchildrenen             ///
		DirecttransfersoldagencAd DirecttransferSocialMonthly              ///
		DirtransferBenefitforbring DirtransfersFamilyNNMOther              ///
		DirtransferPregnancychildb DirecttransferHeatingallowan            ///
		DirecttransfersotherAdulte OtherFamilyContributorytransf           ///
		DirTransferMonthlychildallo Directtransfersunemployment            ///
		DirecttransfersdisabilityAd DirTransferFamilyNMTOther              ///
		Allindirectsubsidies IndirectsubsidiesGasdirecte subs_electricity_ind   ///
		IndirectsubsidiesGasindirect IndirectsubsidiesElectricity   ///
		Allindirecttaxes IndirecttaxesVATAdultequiv ///
		IndirecttaxesOilderivatesdi IndirecttaxesOilderivatesin ///
		IndirecttaxesExciseAlcoholic IndirecttaxesExciseTobacco ///
		Allcontributions Alldirecttaxes   
	drop Alldirecttransfersinclcontri- IndirecttaxesCarbonAdulteq	
	mkmat *, mat(a)
	mat b= a'
	describe, replace clear
	svmat b
	rename b1 PR_6_85
	replace PR_6_85= PR_6_85*100
	export excel PR_6_85 using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(G71)

// 6.85
	use "pc_pdi_margcontc", clear 
	drop B C 
	drop ContributionsGralSicknessMa- ContributionsHealthselfemploy
	drop  Alldirecttaxesandcontributio
	drop itx_car2_pc Alltaxes Alltaxesandcontributions InKindhealthbenefitsSocial- Allnettransfersandsubsidies
	rename AL subs_electricity_ind
	order Alldirecttransfersexclcontri DirtranfersFamilyNNMmother  ///
		DirtranfersFamilyNNMchild DirtransferBenefitforraisin              ///
		DirtranfersFamilyNNMTBirth DirtranfersSchoolchildrenen             ///
		DirecttransfersoldagencPe DirecttransferSocialMonthly              ///
		DirtransferBenefitforbring DirtransfersFamilyNNMOther              ///
		DirtransferPregnancychildb DirecttransferHeatingallowan            ///
		DirecttransfersotherPercap OtherFamilyContributorytransf           ///
		DirTransferMonthlychildallo Directtransfersunemployment            ///
		DirecttransfersdisabilityPe DirTransferFamilyNMTOther              ///
		Allindirectsubsidies IndirectsubsidiesGasdirecte subs_electricity_ind   ///
		IndirectsubsidiesGasindirect IndirectsubsidiesElectricity ///
		Allindirecttaxes IndirecttaxesVATPercapita ///
		IndirecttaxesOilderivatesdi IndirecttaxesOilderivatesin ///
		IndirecttaxesExciseAlcoholic IndirecttaxesExciseTobacco ///
		Allcontributions Alldirecttaxes
	drop Alldirecttransfersinclcontri- IndirecttaxesCarbonPercapi
	mkmat *, mat(a)
	mat b= a'
	describe, replace clear
	svmat b
	rename b1 PR_AROP
	replace PR_AROP= PR_AROP*100
	export excel PR_AROP using "$xl_output", sheet("A1",modify) firstrow(varlabels) cell(F71)
	
	putexcel set "$xl_output", modify sheet("A1")
	putexcel B1 = "Table A.1. Poverty and inequality indicators, by CEQ income concept, 2018 vs. 2020" ///
	b4 = "Income Concept" C4 = "Gini" D3 ="2020" F3="2018" ///
	D4 = "National Poverty (AROP)" E4 = "International Poverty" E5 = "($6.85 PPP 2017)" ///
	F4 = "National Poverty (AROP)" G4 = "International Poverty" G5 = "($6.85 PPP 2017)" ///	
	B6 = "Market Income Pensions" b7="Net Market Income" B8 = "Disposable Income" ///
	b9 = "Consumable Income" B10 = "Final Income" ///	
	B12  = "Table A.2. Impact of direct transfers, subsidies, and in-kind transfers on poverty and inequality, 2020" ///
	C15 = "Size" c16= "(% of MYPP)" D15 = "Kakwani"  E14 = "Marginal contribution" ///		
	E15 = "Redistributive effect"	F15 = "Poverty reduction" G15 =	"Poverty reduction"  ///
	F16 = "(US$ 6.85 2017 PPP)"	G16 = "(AROP poverty line)" ///
	B17 = "Direct transfers" B18="Family NC NMT Mothers In Tertiary Education" ///
	B19 = "Family NC NMT Child Benefit For Twins"  ///
	B20 = "Benefit For Raising a Child Under 1 NC Mt" ///
	B21 = "Family NC NMT Birth Child Grant" B22 = "School Children Enrolled In 1st Grade NC Mt" ///
	B23 = "Old Age NC" B24 = "Social Monthly Assistance GMI" ///
	B25 = "Benefit For Bring Up Child with Up to 2 years" B26 = "Family NC NMT Other" ///
	B27 = "Pregnancy Childbirth Benefit" B28 = "Heating Allowance" ///
	B29 = "Other" B30 = "Family NC NMT Other" B31 = "Monthly Child Allowance NC Mt" ///
	B32 = "Unemployment" B33 = "Disability" B34 = "Family NC MT Other" ///
	B35 = "Subsidies" B36 = "Gas Direct Effects" B37 = "Electricity Indirect Effects" ///
	B38 = "Gas Indirect Effects" B39 = "Electricity Direct Effects" ///
	B40 = "Health" B41 = "Social Security" B42 = "Public Health" ///
	B43 = "Education" B44 = "Pre School" B45 = "Primary Level" ///
	B46 = "Lower Secondary"  B47 = "Upper Secondary" B48 = "Tertiary" ///
	B51 = "Table A.3. Impacts of direct taxes, SIC, and indirect taxes on poverty and inequality, 2020" ///
	C54 = "Size" C55= "(% of MYPP)" D54 = "Kakwani"  E53 = "Marginal contribution" ///		
	E54 = "Redistributive effect"	F54 = "Poverty increasing" G54 = "Poverty increasing"  ///
	F55 = "(US$ 6.85 2017 PPP)"	G55 = "(AROP poverty line)" ///
	B56 = "Indirect taxes" B62 = "SIC" B63 = "Direct taxes", bold 
	
	putexcel B57 = "VAT" B58 = "Oil derivates direct effect" ///
	B59 ="Oil derivates indirect effect" B60 = "Excises alcohol" B61 = "Excises tobacco"
	
	local an01 ""
	
	
	forval i =65(1) 68 {
	    local j = `i'-59 		
		local an01 = "`an01' C`j' = formula(B`i')" + ///
		" D`j' = formula(C`i')" + ///
		" E`j' = formula(D`i')" + ///
		" F`j' = formula(F`i')" + ///
		" G`j' = formula(G`i')" 
	}
	local an01 = "`an01'  C10 = formula(B69)"
	
	local an02 ""
	forval i =72(1) 103 {
	local j = `i'-55 	
	local k = `i'-16
		local an02 = "`an02' C`j' = formula(C`i')" + ///
		" D`j' = formula(D`i')" + ///
		" E`j' = formula(E`i')" 		
	}
	
	forval i =72(1) 94 {
		local j = `i'-55 	
		local k = `i'-16
		local an02 = "`an02' F`j' = formula(F`i')" + ///
		" G`j' = formula(G`i')"  		
	}
	
	forval i =104(1)111 {		
		local k = `i'-48
		local l = `i'-9
		local an02 = "`an02'  C`k' = formula(C`i'*-1)" + ///
		" D`k' = formula(D`i')" + ///
		" E`k' = formula(E`i')" 
		local an02 = "`an02' F`k' = formula(F`l'*-1)" + ///
		" G`k' = formula(G`l'*-1)" 
	}
	
	putexcel `an01' `an02' 
	putexcel F41 = "n/a" F42 = "n/a" F44 = "n/a" F45 = "n/a" F46 = "n/a" f47="n/a" ///
		F48 = "n/a" G41 = "n/a" G42 = "n/a" G44 = "n/a" G45 = "n/a" G46 = "n/a" ///
		G47="n/a" G48 = "n/a" 
	
	putexcel clear 


	

}		

