/*==================================================
project:       CEQ Bulgaria 
Author:        Cabrera 
E-email:       
url:           
Dependencies:  World Bank 
Input files 
- EU-SILC/UDB_BG_d19.dta
- EU-SILC/UDB_BG_h19.dta
- EU-SILC/UDB_BG_p19.dta

Output files:
- BGR_mkt_inc.dta

----------------------------------------------------
Creation Date:       10 Dec 2021
Modification Date:   26 Apr 2024
Do-file version:    2.1
Track main changes: 

References:          
- EU-SILC methodological manual 
Output:             
Questions
==================================================*/


	
*************************************************************************************	
*************************************************************************************		
	/*============================================================
		1: Extract info from CSV files 
==================================================================*/
	
	
	import excel "${raw}SILC_2021/dict_silc21.xlsx", clear firstrow sheet(d) cellrange(A2:B21)
	labeldatasyntax, saving("${do}label_d.do") replace
	
	import excel "${raw}SILC_2021/dict_silc21.xlsx", clear firstrow sheet(h) cellrange(A2:D243)
	labeldatasyntax, saving("${do}label_h.do") replace
	
	import excel "${raw}SILC_2021/dict_silc21.xlsx", clear firstrow sheet(r) cellrange(A2:D147)
	labeldatasyntax, saving("${do}label_r.do") replace
	
	import excel "${raw}SILC_2021/dict_silc21.xlsx", clear firstrow sheet(p) cellrange(A2:D369)
	labeldatasyntax, saving("${do}label_p.do") replace

	*----------1.1: Open EU-SILC BGR 2019 survey 
	cap drop _*
	*----------1.1.1: Household register
	
	import delimited "${raw}SILC_2021/UDB_cBG21D_NUTS3.csv", clear 
	include "${do}label_d.do"
	
	rename db030  hhid 
	recast double hhid 
	rename db010  year 
	rename db060  psu 
	rename db062  ssu 
		
	drop if hhid==.		
	count 
	// 7551
	
	
	save "${tmp}udb_cb21d.dta", replace 
	
	*----------1.1.2: Household data
	
	import delimited "${raw}SILC_2021/UDB_cBG21H.csv", clear 
	include "${do}label_h.do"
	*"
	rename hb030 hhid 
	recast double hhid 
	rename hb060 year 
	drop if hhid==.
	save "${tmp}udb_c21h.dta", replace 
	count 
	// 7551
	
	save "${tmp}udb_cb21h", replace 	
		
	merge 1:1 hhid using "${tmp}udb_cb21d.dta"
	
	drop _merge
	
	label var hx010 "change rate"
	label var hx010 "Change rate"
	label var hx040 "Household size"
	label var hx050 "Equivalised household size"
	label var hx060 "Household type"
	label var hx070 "Tenure status"
	label var hx080 "Poverty indicator"
	label var hx090 "Equivalised disposable income"
	label var hx120 "Overcrowded household (0=not overcrowded, 1=overcrowded,.=N/A)"
	
	// individual weight 
	gen weight = hx040*db090	
	gen uno=1 
	tab uno [w=round(weight)]
	
	// 6,922,967 survey 
	// 6.951.482 Eurostat 2020// 6.951.482 Eurostat 2020
	
	gen yd_hh = hy020 
	gen hsize = hx040	
	gen yd_pc = hy020 /hsize 
	gen yd_ae = hx090
	
	ainequal yd_pc [w=round(weight)]
	
	/*
	
	---------------------------------------
       Inequality measures |      yd_pc
	---------------------------+-----------
          Gini coefficient |    0.40524
	Theil index (GE(a), a = 1) |    0.35436
	---------------------------------------
	*/

	*----------1.2: Poverty Internationl 

	** 1.9 .... 0.25  // 2011 (update to 2017)
	** 3.2 .... 1.36
	** 5.5 .... 3.62
	** National 22.1 
	** Gini....41.28

	
	tempvar yd_pc_lcu yd_ae_lcu 
	gen `yd_pc_lcu' = (yd_pc*EXR)  // EU SILC in Euros --> YD in BGN 
									// Bulgarian Lev 
	gen `yd_ae_lcu' = (yd_ae*EXR)  // EU SILC in Euros --> YD in BGN 								
	
	qui summ `yd_ae_lcu' [w=weight], detail 
	di %18.2fc (r(p50)*.6)/12
	
	
	/*
	Warning: change units to LCU 
	ceqppp, country(BGR) base(2011) survey(2019) locals
	
	scalar PL190 = `ppp'*(`cpisurvey'/`cpibase')*1.90*360
	scalar PL320 = `ppp'*(`cpisurvey'/`cpibase')*3.20*360
	scalar PL550 = `ppp'*(`cpisurvey'/`cpibase')*5.50*360
	*/
	
	// ppp source  
		
	summ `yd_ae_lcu' [w=weight], detail 
	di r(p50)*.6 
	
	local ppp    = .89976352  // base 2011
	local mpline = 504.33
	
	scalar PL190 = `ppp'*1.90*365
	scalar PL320 = `ppp'*3.20*365
	scalar PL550 = `ppp'*5.50*365
	scalar PNATM =  (`mpline'*12)
	
	povcc `yd_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")   ppof(0.25) 
	povcc `yd_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")   ppof(1.36) 
	povcc `yd_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")   ppof(3.62) 
	povcc `yd_ae_lcu' [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	
		
	/*
	ppp Povcal 		 0.8453243
	Data bank figures 0.884967
	
.         povcc `yd_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
ppp 1.9:  0.25, official:  0.25

.         povcc `yd_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
ppp 3.2:  1.36, official:  1.36

.         povcc `yd_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62) 
ppp 5.5:  3.67, official:  3.62

.         povcc `yd_ae_lcu' [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 
National: 22.14, official: 22.10



	OK! only an small difference in PPP 5.5 2011 
	To check PPP 2017	
	
	
	*/


gen one=1
	
	tab one if `yd_ae_lcu'<PNATM  [fw=round(weight)]
	

/*
        one |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |  1,532,838      100.00      100.00
------------+-----------------------------------
      Total |  1,532,838      100.00



vrs 1532 thousand in 2021
    1660 thousand in 2020
*/

	summ y*_pc 
	
	*----------1.3: National Poverty Line Bulgaria 
	
// AROP 	
	
					
	save "${tmp}bgr_hhd.dta", replace 
	
	
	*---------1.4 R19 DATA 
	
	import delimited "${raw}SILC_2021/UDB_cBG21R_Ethnos.csv", clear 
	count 
	
*    17,249
	destring rx060, replace 
	include "${do}label_r.do"
	label var rx030 "Household identification number"	

	rename rx030 hhid 
	recast double hhid 
	rename rb010 year 
	rename rb030 hhin 
	recast double hhin 

	drop if hhid==.
	count 
	* 17,249
	
	label var rx010 "Age at the time of interview"
	label var rx020 "Age at the end of income reference period"
	
	label var rx040 "Work intensity (new definition)"
	label var rx050 "Low work intensity status (new definition) (0=no lwi, 1=lwi, 2=N/A)"
	label var rx060 "Severely materially and socially deprived (0=not deprived, 1=deprived)"
	label var rx070 "At risk of poverty or social exclusion (new definition)" 
	notes rx070: (1st digit= at risk of	poverty, 2nd digit= Severely materially deprived, 3rd digit= Low work intensity (0 when LWI in (0,2) 1 when LWI=1)
	
	tempfile bgr_ethnos
	save `bgr_ethnos.dta', replace 
	
	
	/*
		==================================================
		2: Market Income PGT
		==================================================
	*/
	
	
	*----------2.1: Disposable Income composition 
	
	/*
	- HY010: Total household gross income
	- The sum for all household members of gross personal income components
    - Gross employee cash or near cash income (PY010G)
    - Company car (PY021G)
    - Gross cash benefits or losses from self-employment (including royalties) (PY050G),
    - Pensions received from individual private plans (other than those covered under ESSPROS) (PY080G)
    - Unemployment benefits (PY090G)
    - Old-age benefits (PY100G)
    - Survivor' benefits (PY110G)
    - Sickness benefits (PY120G)
    - Disability benefits (PY130G)
    - Education-related allowances (PY140G)
	- Plus gross income components at household level
    - Income from rental of a property or land (HY040G)
    - Regular inter-household cash transfers received (HY080G)
    - NOT INCLUDED imputed rent (HY030G
    - Interests, dividends, profit from capital investments in unincorporated business (HY090G)
    - Income received by people aged under 16 (HY110G
    - Family/children related allowances (HY050G)
    - Social exclusion not elsewhere classified (HY060G)
    - Housing allowances (HY070G)

	## Household disposable Income

	```r
	HY020 <- HY010 – HY120G – HY130G – HY140G
	```

	- Household Gross Income +
	- Minus
		- Regular taxes on wealth (HY120G)
		- Regular inter-household cash transfer paid (HY130G)
		- Tax on income and social insurance contributions (HY140G)	
		
		
	*/
	
	import delimited "${raw}SILC_2021/UDB_cBG21P.csv", clear 
	count  
	* 15,221
	
	encode pl111a, gen(pl111a2)
	tab pl111a2
	label drop pl111a2
	drop pl111a 
	rename pl111a2 pl111a
	
	include "${do}label_p.do"
	
	rename px030 hhid
	recast double hhid
	rename pb010 year 
	rename pb030 hhin
	recast double hhin 

	drop if hhid==.
	count 
	* 15,221
	
	merge m:m hhin using `bgr_ethnos.dta'
	
	/*
	    Result                      Number of obs
    -----------------------------------------
    Not matched                         2,028
        from master                         0  (_merge==1)
        from using                      2,028  (_merge==2)

    Matched                            15,221  (_merge==3)
    -----------------------------------------
	*/
	
	count 	
	
	// 17,249
	
	drop _merge 
	
	merge m:1 hhid using "${tmp}bgr_hhd.dta"
	
	/*
	    Result                      Number of obs
    -----------------------------------------
    Not matched                             0
    Matched                            17,249  (_merge==3)
    -----------------------------------------
	*/
			
	cap drop weight 
	
	gen weight = db090
	tab uno [w=round(weight)]
	
	/*
	        uno |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |  6,922,933      100.00      100.00
------------+-----------------------------------
      Total |  6,922,933      100.00

	*/
	
	
	*----------2.2: Labor Income 
	
label var hhid "Household identification number"	
label var   hy010 "Total hh gross income"	                                                                       
label var   hy020 "Total disposable hh income"	                                                                   
label var   hy022 "Total disposable hh income before social transfers other than old-age and survivors benefits" 
label var   hy023 "Total disposable hh income before all social transfers"	                                       

label var py010g "Cash or near-cash employee income"	               
label var py020g "Other non-cash employee income"	                   
label var py021g "Income from private use of company car"	           
label var py030g "Employers social insurance contributions"	       
label var py035g "Contributions to individual private pension plans"  
label var py050g "Cash profits or losses from self-employment"	       
	
	egen double my_labor_in = rsum(py010g /*py021g */  py020g  py050g ///
							 py030g   /*not in eusilc aggregate*/ )
	
	/* egen my_labor_in = rsum(py010g py021g py050g)  */
	
	label var my_labor_in "Labor income (Individual)"
	percap my_labor_in
	
	
	*----------2.3: Capital Income 
	label var   hy040g "Income from rental of property or land"
	label var   hy090g "Interest, dividends, profit from capital investments in incorporated businesses"	               

	egen double my_capit_hh = rsum(hy040g hy090g)
	
	label var my_capit_hh "Capital income (Household)"
	
	percap my_capit_hh
	
	*----------2.4: Private transfers 

	label var hy080g "Regular inter-hh cash transfers received"	                                                   
	label var py080g "Pensions from individual private plans"

	bysort hhid: egen double s_py080g = sum(py080g)	 // hsize = 1

	recode hy130g (.=0)
	replace hy130g = hy130g*-1
	
	
	// net private transfers to be consisten with EU-SILC 
	// CEQ uses gross private transfers 
	
	egen double my_trans_hh = rsum(s_py080g  hy080g hy130g)
	label var my_trans_hh "Transfer income (Household)"
	percap my_trans_hh 
	replace hy130g = hy130g*-1
	
	*----------2.6: Imputed rent

	// label var   hy030g "Imputed rent"	  --> not included                                                                             	 no
	
	gen double my_irent_hh = 0  // + hy030g 
	label var my_irent_hh "Transfer income (Household)"
	percap my_irent_hh 
	
	*--------- 2.7 Self consumption 
	label var   hy170g "Value of goods produced for own consumption"                                                   

	/* hy170g float   %9.0g Value of goods produced for own consumption*/
	
	gen double my_sprco_hh = 0   + hy170g 
	label var my_sprco_hh "Self production consumption (Household)"
	percap my_sprco_hh 
	
	*----------2.8: Other Income
	label var   hy110g "Income received by people aged under 16"                                                       
	

	gen double my_other_hh = hy110g
	label var my_other_hh "Other income sources (Household)"
	percap my_other_hh 

	
	*----------2.9: Pensions 


	** Private included in direct transfers 
	** Public are part of disposable income 
	
	
	*----------2.10: Market income PGT = LABOR + capit + private transfers

	label var   hy050g "Family/ Children related allowances"	                                                           
	label var   hy060g "Social exclusion payments not elsewhere classified"
	label var   hy070g "Housing allowances"	                                                                           

	label var   hy100g "Interest repayments on mortgage"	                                                               
	label var   hy120g "Regular taxes on wealth"	                                                                       
label var   hy130g "Regular inter household cash transfer paid"	                                                   
	label var   hy140g "Tax on income and social contributions"                                                       

label var py090g "Unemployment benefits"	                           
label var py100g "Old-age benefits"	                               
label var py110g "Survivors benefits"	                               
label var py120g "Sickness benefits"	                               
label var py130g "Disability benefits"	                               
label var py140g "Education-related allowances"	                   


	**hy023
	**hy040g Income from rental of a property or land
	**hy170n Total disposable hhd inc before social trnsf including oldage and

	
	// my_irent_pc and my_sprco_pc not included to be comparable with official 
	// disposable income 
	
	egen double ym_pc = rsum(my_labor_pc my_capit_pc my_trans_pc /*my_irent_pc*/ ///
					  /*my_sprco_pc*/ my_other_pc)
	
	tab ym_pc if ym_pc <0
	
	
	tempvar flag_n inc_notrans 
	gen `flag_n' = (ym_pc<0)
	tab `flag_n'
	*drop if `flag_n'
	replace ym_pc = 0 if `flag_n'
	egen double `inc_notrans' = rsum(my_labor_pc my_capit_pc /*my_irent_pc*/ ///
					  /*my_sprco_pc*/ my_other_pc)
	replace my_trans_pc = my_trans_pc - (`inc_notrans' + my_trans_pc) if `flag_n' 				  
	count if `flag_n'
	//60
	list hhid my*pc ym_pc my*hh if `flag_n'
	tab hhid if `flag_n'
	

/*	

  Household |
identificat |
 ion number |      Freq.     Percent        Cum.
------------+-----------------------------------
    2646800 |          1        1.67        1.67
    2686400 |          2        3.33        5.00
    2879700 |          2        3.33        8.33
    2890800 |          3        5.00       13.33
    2897300 |          1        1.67       15.00
    2941900 |          1        1.67       16.67
    3009500 |          2        3.33       20.00
    3101800 |          1        1.67       21.67
    3197700 |          1        1.67       23.33
    3217500 |          1        1.67       25.00
    3252500 |          2        3.33       28.33
    3258100 |          1        1.67       30.00
    3313300 |          2        3.33       33.33
    3367500 |          2        3.33       36.67
    3371600 |          2        3.33       40.00
    3459400 |          2        3.33       43.33
    3490900 |          2        3.33       46.67
    3491900 |          2        3.33       50.00
    3492700 |          2        3.33       53.33
    3601900 |          2        3.33       56.67
    3654300 |          1        1.67       58.33
    3755500 |          1        1.67       60.00
    3765700 |          1        1.67       61.67
    3816700 |          2        3.33       65.00
    3817300 |          2        3.33       68.33
    3839500 |          1        1.67       70.00
    3844300 |          1        1.67       71.67
    3858600 |          1        1.67       73.33
    3860900 |          1        1.67       75.00
    3882000 |          2        3.33       78.33
    3917700 |          2        3.33       81.67
    3930300 |          2        3.33       85.00
    3936900 |          1        1.67       86.67
    3983800 |          2        3.33       90.00
    4031500 |          1        1.67       91.67
    4093400 |          1        1.67       93.33
    4108100 |          2        3.33       96.67
    4121000 |          2        3.33      100.00
------------+-----------------------------------
      Total |         60      100.00


*/


	tabstat my_*_pc [w=round(weight)], stat(sum) format(%15.0fc)
	
	tabstat py050g py010g [w=round(weight)], stat(sum) format(%15.0fc) col(stat)
	
	*----------2.11: Check differences between EU-SILC and CEQ Pre-fiscal income 
	
	// Comparable Disposable income before transfers and pensions 
	//  + Regultar tranfers on wealth + 
	//  + Tax on income and social insurance contribution
	
	// HY023 = HY040G + HY080G + HY090G + HY110G – HY120G – HY130G – HY140G +
	// [for all household members](PY010G + PY021G + PY050G + PY080G) 
				
	gen double ym2_hh = hy023 /*+ hy030g */ + hy120g + hy140g // + hy170n (check if included)
		
	label var ym2_hh "Market income EUSILC (Household)"
	percap ym2_hh	
	
	count if ym2_hh<0
	
	/*
	. count if ym2_hh<0
	32
	*/
	
	summ ym_pc ym2_pc 
	/*
	    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
       ym_pc |     17,012    4079.827    5167.895          0   178499.9
      ym2_pc |     17,012      3067.6    4744.662  -2059.515   176118.3
	*/
	
	sort hhid hhin, stable 
	
	*by hhid: gen memb_no=_n
	gen corr_no = real(substr(strofreal(hhin,"%9.0f"),8,2))
	sort hhid corr_no 
	by hhid: gen memb_no=_n 
	
	unique hhid 
	tab memb_no 
	
	tab uno [w=round(weight)] 
	
	// 6.951.482 Eurostat 2020
	// 6,922,933  Survey 	
		
	ainequal ym_pc ym2_pc [w=round(weight)] if memb_no==1
	
	/*
	---------------------------------------------------
       Inequality measures |      ym_pc      ym2_pc
	---------------------------+-----------------------
          Gini coefficient |    0.52762     0.61807
	Theil index (GE(a), a = 1) |    0.54491     0.98889
	---------------------------------------------------

	*/
	
	
	/**
	** checking difference between Market Income using EU-SILC components vs
	CEQ definition 
	**/
	cap drop _*
	
	tempvar dif1 dif3 ym3 dif4 ym4 dif5 ym5 dif6 dif7 ym6 ym7 py030g_hh ///
		py030g_pc dpy020 dpy020_hh dpy020_pc 
		
	gen `dif1' = round(ym_pc - ym2_pc)
	summ  `dif1'
	count if abs(`dif1')>0
	
	//   12,442
	
	/// + employer contributions (py030g)
	bysort hhid: egen `py030g_hh' = sum(py030g)
	gen double `py030g_pc' = `py030g_hh'/hsize 	
	egen double `ym3' = rsum(ym2_pc `py030g_pc')
	gen double `dif3' = round(ym_pc - `ym3')
	misstable summ `dif3'
	summ  `dif3'
	count if abs(`dif3')>0

	//   1,657
	
/// + self consumption  (my_sprco_pc)
	egen double `ym4' = rsum(`ym3')
	gen double `dif4' = round(ym_pc - `ym4')
	misstable summ `dif4'
	summ  `dif4'
	count if abs(`dif4')>0
	
	//   1,657
	
	** + imputed rent   == 0
	egen double `ym5' = rsum(`ym4' my_irent_pc)
	gen double `dif5' = round(ym_pc - `ym5')
	summ  `dif5'
	count if abs(`dif5')>0	
	
	//  1,657
	
	** + non-cash income - car income 
	gen `dpy020' = py020g - py021g 
	replace `dpy020' =0  if `dpy020'==.
	bysort hhid: egen `dpy020_hh' = sum(`dpy020')
	gen double `dpy020_pc' = `dpy020_hh'/hsize 	
	egen double `ym6' = rsum(`ym5' `dpy020_pc')
	gen double `dif6' = round(ym_pc - `ym6')
	summ  `dif6'
	count if abs(`dif6')>0
		//  60
	tab `dif6'
	
	list hhid ym2_pc ym_pc `ym6' s_py080g  hy080g hy130g if abs(`dif6')>0, sepby(hhid)
	
	// the difference is the regular inter-household cash transfer paid 
	
	tempvar hy130g_pc 
	
	gen double `hy130g_pc' = hy130g/hsize
	
	gen double `ym7' = `ym6' + `hy130g_pc' if abs(`dif6')>0
	replace `ym7' = `ym6' if abs(`dif6')==0	
	gen double `dif7' = round(ym_pc - `ym7')
	summ  `dif7'
	count if abs(`dif7')>0
		//  		4
	tab `dif7'
	
	//4 cases 
	count if round(my_labor_pc,0.01) == round(-my_trans_pc,0.01) & my_labor_pc!=0
	// +1
	count if round(my_capit_pc,0.01) == round(-my_trans_pc,0.01) & my_capit_pc!=0
	// +3 
	
	// Note: differences due to transfers paid make income <0 
	// Now, the transfers are reduced, so the ym_pc if transf > other mkt income 
	list hhid ym2_pc ym_pc `ym7' s_py080g  hy080g hy130g if abs(`dif7')>0, sepby(hhid)
	
	
	tabstat `dif1' `dif3' `dif4'  `dif5' `dif6' `dif7' [w=weight], stat(sum) ///
		format(%15.0fc) col(stat) save
		
	/*
	
	    Variable |             Sum
-------------+----------------
    __000004 |   4,071,818,641 	-- differenc4
    __000005 |     138,882,290		-- employer contributions 
    __000007 |     138,882,290		-- self-consumption NA
    __000009 |     138,882,290		-- imputed rent NA
    __00000B |       4,834,331		-- other fringe benefits 
    __00000C |        -246,478		-- paid intra-hhd transfers 
------------------------------

	
	*/
	
	// exchange rate 
	summ px010, meanonly 	
	replace px010 = r(mean) if px010==.
	
	summ y*pc
	
	tempvar ym_pc_lcu ym_ae_lcu
	gen double `ym_pc_lcu' = ym_pc*px010
	gen double `ym_ae_lcu' = (`ym_pc_lcu'*hsize)/hx050
	
	summ `ym_pc_lcu' `ym_ae_lcu'	 
	
	povcc `ym_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")   ppof(0.25) 
	povcc `ym_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")   ppof(1.36) 
	povcc `ym_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")   ppof(3.62) 
	povcc `ym_ae_lcu' [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 

	
	/*
.         povcc `ym_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")   ppof(0.25) 
ppp 1.9: 14.59, official:  0.25

.         povcc `ym_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")   ppof(1.36) 
ppp 3.2: 17.60, official:  1.36

.         povcc `ym_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")   ppof(3.62) 
ppp 5.5: 21.25, official:  3.62

.         povcc `ym_ae_lcu' [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 
National: 32.32, official: 22.10



	*/
	
		
save "${tmp}BGR20_mkt_inc.dta", replace
	
exit 

-******************************************************************************
Notes
- 1. There is a difference with respect to the HY023 + direct taxes 
the reason is the transfers paid. 
 
