capture log close
log using "${log}5_BGR20_DispIncome.txt", replace text
**	4_BGR20_DispIncome.do
/*==================================================
	project:       CEQ Bulgaria 2020
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR20_net_inc.dta
	
	Output files:
	- BGR20_dis_inc.dta 
	----------------------------------------------------
	Creation Date:       17 Dec 2022
	Modification Date:   6 Jun 2023
	Do-file version:    2.7
	Track main changes: 
		
	References:          
	
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2022),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2019-2022” 
	- MISSOC
	european commission (2021), "your social security rights in bulgaria", luxembourg: 
	publications office of the european union, 2021
	- Do files provided by Lucian Bucur 
	
	
================================================== */

cap program drop sumt 
program define sumt 
summ `1'  [w=weight], meanonly
di %18.0fc r(sum)	
end 

/*==================================================
	1: Cleaning files 
==================================================*/

use "${tmp}BGR20_net_inc.dta", clear 
cap drop _*



recode py09*_f py1*_f (min/0=0) (1/max=1) // create participation indicators (0/1) in various SP schemes

// Don't include Sickness Benefits from SP benefits --> NOT IN CEQ 

rename yd_pc yd2_pc 

* 1.2 household members characteristics --------------------------------

gen int age_0=(age==0)
bysort hhid: egen sage_0=sum(age_0)
gen int age_1=(age<=1)
bysort hhid: egen sage_1=sum(age_1)

gen int age_18 = (age<=18)
bysort hhid: egen sage_18=sum(age_18)
gen int age_1820 = inlist(age,19,20) & pe010==1
bysort hhid: egen sage_1820=sum(age_1820)
gen int cond_1  = (sage_18 | sage_1820)
gen int age_7=(age==7)
bysort hhid: egen sage_7=sum(age_7)

*1.3 DMI conditions ----------------------------------------------------

gen int adult=age>16 & age<.   
gen int child=(age<=16 & age!=.)  // 0 to 16 years
gen int old=(age>64 & age!=.) 		// over the age of 65
gen int workage=(age>16 & age<65)

*1.4 DMI HHD variables --------------------------------------------------

by hhid, sort: egen int nkids3yo  = total(age<=3) // no. children under 3yo by HH
by hhid, sort: egen int nkids16yo = total(age<=16) // no. children under 16yo by HH
by hhid, sort: egen int nkidss16yo = total(age<=16 & pe010==1 | ///
	!(inlist(rl010,"0"," ") & inlist(rl020,"0"," "))) // no. children under 16yo by HH
by hhid, sort: egen int nkids18yo = total(age<=18) // no. children under 18yo by HH
by hhid, sort: egen int nkidss17_18 = total(inrange(age,17,18) & pe010==1) // no. children under 18yo by HH
by hhid, sort: egen int nkidss19_20 = total(inrange(age,19,20) & pe010==1) // no. children under 18yo by HH

//- child has loneparent; see GESIS codebook for variables
gen spouse_in_hhd = pb180_f==1
bysort hhid: egen spouse_in_hhd2= max(spouse_in_hhd)
rename spouse_in_hhd spouse_in_hhd3
rename spouse_in_hhd2 spouse_in_hhd

gen lonep_ch= (pb160_f==1 & pb170_f<1 & spouse_in_hhd!=1) | (pb160_f<1 & pb170_f==1 & spouse_in_hhd!=1) 

// change lone parents with children 
replace lonep_ch = 0 if (nkidss16==0 & nkids3yo==0 & nkidss17_18==0 & nkidss19_20==0)
list hhid gender age hsize lonep* pb160_f pb170_f spouse_in_hhd nk* if hhid==2629900 

gen lonep_ch2= (rb220_f==1 & rb230_f<1 & spouse_in_hhd!=1) | (rb220_f<1 & rb230_f==1)
replace lonep_ch2 = 0 if (nkidss16==0 & nkids3yo==0 & nkidss17_18==0 & nkidss19_20==0)
list hhid gender age hsize lonep* rb220_f rb230_f spouse_in_hhd if hhid==2629900 

replace lonep_ch = 1 if lonep_ch==0 & (nkidss16>=1 | nkids3yo>=1 | ///
	nkidss17_18>=1 | nkidss19_20>=1) & (pb180_f<1 & rb220_f!=1 & rb230_f!=1) ///
	& workage==1 & spouse_in_hhd==0  & age<=18
	
list hhid gender age hsize lonep* pb180_f rb220_f rb230_f if hhid==2629900 	
	
replace lonep_ch = lonep_ch2 if lonep_ch2!=0	

//- no. of children w/ lone parents in the HH
by hhid, sort: egen lonep_hh    =total(lonep_ch) 
by hhid, sort: egen nworkage_hh =total(workage)
by hhid, sort: egen nadult_hh   =total(adult)

label define yesno 0 "No" 1 "Yes"

gsort -hy052g age

preserve 

keep if rb220_f==1 

keep rb220
rename rb220 hhin 
tempfile father1 
gen f_01=1
destring hhin, replace 
recast double hhin
sort hhin 
collapse (first) f_01, by(hhin)
save `father1', replace 

restore 

preserve 
keep if rb230_f==1 
keep rb230
rename rb230 hhin 
tempfile mother1 
gen m_01 = 1
destring hhin, replace 
recast double hhin
sort hhin 
collapse (first) m_01, by(hhin)

save `mother1', replace 
restore 

cap drop _merge
merge  1:1  hhin using `father1', keep(match master)

cap drop _merge
merge  1:1  hhin using `mother1', keep(match master)

drop _merge 

bysort hhid: egen sf01=sum(f_01)
bysort hhid: egen sm01=sum(m_01)

tab lonep_hh if memb_no==1

replace lonep_hh = 0 if sf01==sm01
replace lonep_hh = 0 if sf01!=sm01 & lonep_hh!=0 & sm01<sf01 & sm01>=1
replace lonep_hh = 0 if sf01!=sm01 & lonep_hh!=0 & sf01<sm01 & sf01>=1
replace lonep_hh = 0 if hsize==1
replace lonep_hh = 1 if sage_18==1 & hsize==2
replace lonep_hh = 0 if spouse_in_hhd==1
replace lonep_hh = 1 if sage_18==2 & hsize==3


tab lonep_hh if memb_no==1
tab lonep_hh 

drop sf01 sm01 m_01 f_01 

*1.5 Family allowances variables -----------------------------------------

gen agef_2 = (rb081<2 & rb230!=" ")
replace agef_2 = 0.5 if rb080==2018 & rb081==2 & rb082==2 & rb230!=" "
by hhid, sort: egen nkids02f = max(agef_2)

// mother of child of two years (for family tranfers)
preserve 
keep if agef_2>0 & agef_2<.
gen id_mother2 = 1
drop hhin 
rename rb230 hhin 
destring hhin, replace 

drop if hhin==.
keep hhin id_mother2 
collapse (first) id_mother2, by(hhin)
tempfile mother2 
save `mother2', replace 
restore 
merge 1:1 hhin using "`mother2'"

gen birth_f = (rb081==0 | rb080>=2020) & (hy052g>0 & hy052g<.) 
replace birth_f =  0.5 if rb080==2019 & rb081==1 & rb082==1 & hy052g>0 & hy052g<.
replace birth_f = 1 if rb081==0
bysort hhid: egen  nbirthf = sum(birth_f)

gen childm_1 	 = (rb080==2020)
replace childm_1 = 1   if (rb080==2019 & rb082==1)
replace childm_1 = 0.5 if (rb080==2020 & rb082==0)
bysort hhid: egen  nchildm1 = sum(childm_1)

// mother of child of two years (for family tranfers)
preserve 
keep if birth_f>0 & birth_f<.
gen id_mother0 = 1
drop hhin 
rename rb230 hhin 
destring hhin, replace 

drop if hhin==.
keep hhin id_mother0 
collapse (first) id_mother0, by(hhin)
tempfile mother0 
save `mother0', replace 
restore 

preserve 
keep if birth_f>0 & birth_f<.
gen id_father0 = 1
drop hhin 
rename rb220 hhin 
destring hhin, replace 

drop if hhin==.
keep hhin id_father0 
collapse (first) id_father0, by(hhin)
tempfile father0 
save `father0', replace 
restore 

cap drop _*
merge 1:1 hhin using "`mother0'"
cap drop _*
merge 1:1 hhin using "`father0'"

//-- Income for testing 

/*=====================================================================================
	2: Family/children benefits 
==================================================*/

/*
1. Non-mean tested
* Child & family contributory 
	a- Income maintenance benefit in the event of childbirth  [ ]
	b- Parental leave benefit periodic						 [x]
	c- Birth grant (lump sum)								 [ ]
	d- Other periodic benefits							 [ ]
	
2. Child & family nc 
	a- Family or child allowance							[ ] 
	b- Other lump sum cash benefits                           [ ] 
	
3. Mean-tested / NC
	a- Parental leave benefit periodic
	b- Family or child allowance
	c- Other cash periodic benefits
	d- Other lump sum benefits
	
In-Kind 
*	Child day care 

*/	

*-------------------------------------------------------------------------	
* 2.1 Social assistance family benefits (contributory & non means-tested)- 
*-------------------------------------------------------------------------	

*** All Social Protection - ESSPROS (we leave out sickness benefits hpy120)
codebook hy05*f hy06*f hy07*f
recode hy05*f  (min/161=0) (162/max=1) // -2 is NA  code 161 is zero 
gen  dtr_famc_rh        = hy052g_f>0 	& memb_no==1 


********************************************************************************
*** 2.1.a Contributory maternity benefit for bringing up a child up to the age of 2
********************************************************************************

global cn_matbenage2=380/EXR

// 
// multiple of the monthly allowance 
// using reported figures that coincide with the benift

tempvar m1_child2  m2_child2 no_transf 
gen `m1_child2' = round(hy052g/($cn_matbenage2),0.01)
gen `m2_child2' = `m1_child2' - int(`m1_child2')
gen fm_child2 = `m2_child2'==0 & `m1_child2'<=12  & hy052g>0

table nkids02f fm_child2 if id_mother2==1 [w=round(weight)], stat(total one) ///
	stat(rawtotal one)

/*
 -------------------------------------------------
                     |          fm_child2        
                     |        0       1     Total
---------------------+---------------------------
nkids02f             |                           
  .5                 |                           
    Total            |   31,608   2,301    33,909
    Unweighted total |       52       4        56
  1                  |                           
    Total            |   80,965   4,128    85,093
    Unweighted total |      146       9       155
  Total              |                           
    Total            |  112,573   6,429   119,002
    Unweighted total |      198      13       211
-------------------------------------------------

*/	

gen dtr_fncs_in = hy052g if id_mother2==1 & nkids02f>0 & fm_child2==1
gen dtr_fncs_ri = id_mother2==1 & nkids02f>0 & fm_child2==1

table dtr_fncs_ri if id_mother2==1 [w=round(weight)], stat(total one) ///
	stat(rawtotal one)

/*
-----------------------------------------
            |    Total   Unweighted total
------------+----------------------------
dtr_fncs_ri |                            
  0         |  112,573                198
  1         |    6,429                 13
  Total     |  119,002                211
-----------------------------------------
*/

// 12.409

/*
those reporting benefits & paying SIC 	
some are inactive but contributing (py030g>0)	father / mother 
*/

gen flag1=dtr_fncs_ri
tempvar py030g_v2 hpy030g

//-- at least with one year spent in paid work 
gen     `py030g_v2' = py030g if inrange(nkids02f,0.5,1)	& ///
		id_mother2==1 & inrange(pl200,1,62)		
replace `py030g_v2' =0 if  `py030g_v2'==.
bysort hhid: egen `hpy030g' = sum(`py030g_v2')
replace dtr_fncs_ri=1	if id_mother2==1 & (con_smtp_pc>0 | con_smts_pc>0 | ///
	`py030g_v2'>0) & dtr_fncs_ri==0 & nkids02f>0 & hy052g>0 
	
table dtr_fncs_ri if id_mother2==1 [w=round(weight)], stat(total one) stat(rawtotal one)

/*
-----------------------------------------
            |    Total   Unweighted total
------------+----------------------------
dtr_fncs_ri |                            
  0         |   30,179                 60
  1         |   88,823                151
  Total     |  119,002                211
-----------------------------------------
*/

/* 
	weighted by the months not working in last year 
 the max number of benefits were adjusted to get a closer total from 
 admin figures 	
assumption max benefits = 8  
*/

replace dtr_fncs_in = $cn_matbenage2*max(1,(8-max(pl073,pl074,pl075,pl076))) ///
if dtr_fncs_ri==1 & dtr_fncs_in==. & nkids02f==1 & id_mother2==1	
	
// assumption max benefits in the year = 3	
replace dtr_fncs_in = $cn_matbenage2*max(1,(3-max(pl073,pl074,pl075,pl076))) ///
	if dtr_fncs_ri==1 & dtr_fncs_in==. & nkids02f==0.5 & id_mother2==1	
	
//-- half of the benefit if worked 12 months last year 
replace dtr_fncs_in = $cn_matbenage2*6*nkids02f if ///
	max(pl073,pl074,pl075,pl076)==12 & flag1!=1 & dtr_fncs_ri==1
	
sumt  dtr_fncs_in 
//     90,077,007

gen `no_transf' = round(hy052g/$cn_matbenage2)

/* total tranfers> admin data 
adjusting the months using the reported hy052g 
 assuming rounded hy052g / benefit is the actual number of months of the benefit 
not 12 as assumed  */

replace dtr_fncs_in = `no_transf'*$cn_matbenage2*nkids02f ///
	if dtr_fncs_in>hy052g & dtr_fncs_in!=. & `no_transf'<12 	

sumt  dtr_fncs_in  //  88,796,136
label var dtr_fncs_in "Dir.transfer: Benefit for bring up child up of 2 (individual)"
sumt dtr_fncs_ri 	// 88,825
percap dtr_fncs_in 

// benefits 	   1.02 =  88.7/ 86.9
// beneficiaries 1.01 =  88.8 / 87.8

isid hhin, sort 
set seed 848570
cap drop rand1 
gen rand1  = runiform() if dtr_fncs_ri==1
sort rand1
gen t_benef = sum(weight)
replace dtr_fncs_ri =0 if t_benef>88000
sumt dtr_fncs_ri  // 87.7 vs 87.8 0.998
// 87,659
replace dtr_fncs_in =0 if dtr_fncs_ri==0
percap dtr_fncs_in
sumt dtr_fncs_pc // 88.1 vs 86.9 -- 1.01
// 88,095,474

drop t_benef flag1 rand1 _merge

*************************************************************************
***2.1.b Cash benefits in case of pregnancy and childbirth
********************************************************************************
	
gen dtr_fncb_in = .
global min_wage = 311

// i. replace as a differenct of hy052g and dtr_fncs_in
//--
// with dtr_fncs_in > hy052g 
// age is on the limit of receiving both benefits 
// assumed only one 	

replace dtr_fncs_in =0 if dtr_fncs_in==. & hy052g>0 & hy052g<.
replace dtr_fncb_in =0 if nbirthf>0 & (child_f==1 | child_m==1) & ///
	dtr_fncs_ri==1 & hy052g<dtr_fncs_in	
	
gen dif = hy052g-dtr_fncs_in

bysort hhid: egen hdif=min(dif)
replace hdif = hdif if (id_father0==1 | id_mother0==1) 

// replace by difference (with mother id)
replace dtr_fncb_in=hdif if nbirthf>0 & (id_mother0==1 ) & ///
	nbirthf>0 & hdif!=. & hdif>$min_wage

percap dtr_fncb_in // gen hhd totals to check with next condition 

replace dtr_fncb_in=hdif if nbirthf>0 & (id_father0==1) & ///
	nbirthf>0 & hdif!=. & hdif>$min_wage  & dtr_fncb_hh==0	
		
rpayi dtr_fncb_in 
percap dtr_fncb_in dtr_fncs_in 
		
sumt dtr_fncb_in  // 119,990,152 vs 251.9
sumt dtr_fncb_ri  //  46,670 vs 104 thousand 

// ii. obs w/o mother and father id 
//--
	
replace dtr_fncb_in = hy052g if hy052g!=0 & hy052g<. & dtr_fncb_hh==0 & ///
	dtr_fncs_hh==0 & hdif>$min_wage & nbirthf>0 & memb_no==1
sumt dtr_fncb_in 	// 120,838,887
rpayi dtr_fncb_in 
sumt dtr_fncb_ri  // 47,067


// iii. Using reported income for insured mothers/fathers and children 0/1
//		hy052g is not capturing the benefit 
//     the benefit is the max of minimum salary or income multiplied by 90%

percap dtr_fncb_in
replace dtr_fncb_in = max(311*nbirthf,py010g*.90) if dtr_fncb_hh==0 & ///
	(con_smtp_pc>0 | con_smts_pc>0 | (py030g>0 & py030g<.)) & ///
  nbirthf>0 & dtr_fncb_hh==0 & id_mother0==1

sumt dtr_fncb_in	// 143,441,225
rpayi dtr_fncb_in 
sumt dtr_fncb_ri  // 57,321
percap dtr_fncb_in

replace dtr_fncb_in = max(311*nbirthf,py010g*.90) if dtr_fncb_hh==0 & ///
	(con_smtp_pc>0 | con_smts_pc>0 | (py030g>0 & py030g<.)) & ///
  nbirthf>0 & dtr_fncb_hh==0 & id_father0==1
  
rpayi dtr_fncb_in 
sumt dtr_fncb_ri // 58,659


// v. Using reported income for some insured in hhd and children 0/1
// 		with mother id 

percap dtr_fncb_in
bysort hhid: egen max_py030g = max(py030g)
replace dtr_fncb_in = $min_wage*12 if dtr_fncb_hh==0 & (con_smtp_pc>0 | ///
	con_smts_pc>0 | max_py030g>0) & nbirthf>0 & dtr_fncb_hh==0 & id_mother0==1
rpayi dtr_fncb_in 
sumt dtr_fncb_ri 	// 59,909

// vi. Using reported income for some insured in hhd and children 0/1
//		without mother id 

percap dtr_fncb_in
replace dtr_fncb_in = $min_wage*12 if dtr_fncb_hh==0 & (con_smtp_pc>0 | ///
	con_smts_pc>0 | max_py030g>0) & nbirthf>0 & dtr_fncb_hh==0 & memb_no==1

label var dtr_fncb_in "Dir.transfer: Pregnancy & childbirth benefit (individual)"
rpayi dtr_fncb_in 

sumt dtr_fncb_ri // 60,184  		  57%
sumt dtr_fncb_in // 153,541,366  of 251.9 million 61%
percap dtr_fncb_in 

drop dif hdif 

********************************************************************************
*** 2.1.c Other contributory benefits 
***	[family/child allowance, other periodic cash benfits, lump-sum benefits]
********************************************************************************

percap dtr_fncb_in dtr_fncs_in

summ hy052g [w=round(weight)] if memb_no==1 & dtr_fncb_hh==0 & dtr_fncs_hh==0, meanonly
di %18.0fc r(sum)  // 102,003,730 vs 111.0 88%

gen double dtr_fnco_in = max(0, hy052g-dtr_fncb_hh-dtr_fncs_hh) if memb_no==1 
label var dtr_fnco_in "Other Family Contributory transfers (individual)"
percap dtr_fnco_in 
sumt dtr_fnco_in 
sumt dtr_fnco_pc //  184,158,778

rpayi dtr_fnco_in


********************************************************************************
*** 2.1.d Sum of family and children Contributory 
********************************************************************************
/*
	Two years benit		 86.9	 88.8  -101%
	Birth allowance		251.9	153.6 - 61%
	Other tranfers		 3.6 	184.0 - 2826%
	Total 		    342.3  	426.6 = 125%
*/

*-------------------------------------------------------------------------	
* 2.2 Social assistance family benefits (non-contributory & means-tested)
*-------------------------------------------------------------------------	

**************************************************************************
** 2.2.a Benefit for students in 1st grade bchedyc,  -S-
**************************************************************************

/// Family allowances 

tempvar inbenef hinbenef 
egen `inbenef' = rsum(py100g py110g py120g py130g)
bysort hhid: egen `hinbenef' = sum(`inbenef')
egen famtestinc20_hh  = rsum(hy023 `hinbenef') 
gen  famtestinc20_pc = famtestinc20_hh/hx040
global benf_edyc = 250/EXR

global miny_fam01 = (450/EXR)*12	
destring rl020, replace 
gen int first_grade = ((rl020>=25 & rl020<.) & inrange(age,7,7))
gen int dtr_fmne_ri = (first_grade & famtestinc20_pc<=$miny_fam01)
gen double dtr_fmne_in = dtr_fmne_ri*$benf_edyc
sumt dtr_fmne_ri  // 33.2 vs 30  1.10
// 33,221
sumt dtr_fmne_in  // 4.2 vs 3.5 million 1.2 
// 4,246,438

label var dtr_fmne_in "Dir.tranfers: School children enrolled in 1st grade N-MT (individual)"
percap dtr_fmne_in 


**************************************************************************
** 2.2.b Non-contributory benefit for raising a child under the age of 1
** bmaprnc, S  100 BGN per month 
**************************************************************************
global benf_fam01 = 100/EXR

tempvar ingfam01 

gen dtr_fmn1_ri = (nchildm1>0 & famtestinc20_pc<=$miny_fam01 & childm_1>0) 
sumt dtr_fmn1_ri // 46,479

// excluding those receving allowance for raising a child up to 2 years 
replace dtr_fmn1_ri=0 if dtr_fncb_pc>0  | dtr_fncs_pc>0
sumt dtr_fmn1_ri  // 5,411 vs 12  45%

gen dtr_fmn1_in = $benf_fam01*12 if dtr_fmn1_ri==1
sumt dtr_fmn1_in   // 3.320267 million  vs 7.66  43%
label var dtr_fmn1_in "Dir.transfer: Benefit for raising achild under 1 N-MT (individual)"
recode dtr_fmn1_in (.=0)
percap dtr_fmn1_in 
rpayi dtr_fmn1_in


**************************************************************************
** 2.2.c Means-tested child benefit / bchmt00 -S   14.49 BGN  - 7.4
*** Non-contributory benefit for raising a child under the age of 1 
*   For those women and their families, who satisfy the legislated 
*    income-test, we impute the Non-contributory benefit for raising a 
*    child under the age of 1 equal to the minimum 
*    between the legislated amount and HY053. The benefit amount is 
*    adjusted for the child’s quarter of birth
**************************************************************************

global miny_fam02 = (410/EXR)*12		  // 100%
global miny_fam03 = (510/EXR)*12		  // 80%


// lone parents widow receive the benefit without income test 

*** social assistance family benefits (non-contributory & means-tested)
//gen max_benefit = (3067*cond_1 + 2761*sage_0 + 128*sage_7)
//gen double  dtr_famm_hh = min(max_benefit, hy053g)
egen totchild = 	rsum(sage_18 sage_1820)

tempvar benefmt00 widow widow_in_hhd
gen     `benefmt00' = (40*12)/EXR  if totchild==1
replace `benefmt00' = (90*12)/EXR  if totchild==2
replace `benefmt00' = (135*12)/EXR if totchild==3
replace `benefmt00' = (145*12)/EXR if totchild==4
replace `benefmt00' = (145*12)/EXR +((20*12)/EXR)*(totchild-4) if totchild>4 & totchild<.

gen double dtr_fmnc_in = `benefmt00' if famtestinc20_pc<$miny_fam02 & memb_no==1
replace dtr_fmnc_in = `benefmt00'*.8 ///
	if inrange(famtestinc20_pc,$miny_fam02,$miny_fam03) & memb_no==1	
gen `widow' = pb190==4 & (child_f>0 | child_m>0)	
bysort hhid: egen `widow_in_hhd' = max(`widow')
replace dtr_fmnc_in = `benefmt00' if lonep_hh>0  & memb_no==1 & `widow_in_hhd' ==1

rpayi dtr_fmnc_in 
sumt dtr_fmnc_ri  // 508,252  vs 344,000  /509217/
replace dtr_fmnc_ri = 0 if hy053g==0 | hy053g==.
replace dtr_fmnc_ri = 0 if hy052g>0 & hy052g<.
sumt dtr_fmnc_ri  // 306,524 vs 344,000 89%  /307027
replace dtr_fmnc_in=0 if dtr_fmnc_ri==0
sumt dtr_fmnc_in // 137322568 m vs 143  // 96%  /137.446142/
label var dtr_fmnc_in "Dir.Transfer: Monthly child allowance N-MT (individual)"

percap dtr_fmnc_in 


**************************************************************************
*** 2.2.c Lump-sum grant for pregnancy  -bchprls- I
** included in the hy053g
**************************************************************************

**************************************************************************
*** 2.2.d Financial support for bringing up a child by relatives or foster family
** bchmtfp 	I
** included in the hy053g
**************************************************************************

**************************************************************************
*** 2.2.e Other family & child NC-MT transfers  -D
** difference	
**************************************************************************

gen double dtr_fmno_hh = max(0,hy053g-dtr_fmnc_hh-dtr_fmn1_hh-dtr_fmne_hh) if memb_no==1
/*max(0,hy053g - dtr_fmn1_hh - dtr_fmnc_hh) // residual */
replace dtr_fmno_hh=0 if memb_no!=1
label var dtr_fmnc_hh "Dir.Transfer: Family N-MT Other benefit (individual)"
percap dtr_fmno_hh 
sumt dtr_fmno_pc  // 399,668,947

/* this benefit includes 
	- benefits for studens in 1st Grade 3.5 m
	- lump-sum grant for pregnancy 	-NA 
	- Financial support for bringing up a child by relatives or foster family - NA
	???
*/

*************************************************************************
*** 2.2.f Sum of family and children non-Contributory Mean-tested
**************************************************************************
/*
	1st grade				  3.5		4.3  122%			  
	Under 1 year benit		  7.4	 	3.3 	44%
	Child allowance			138.0	   140.9	102%
	Other tranfers			 19.75	   397.0  20%  <<<----
	Total 				168.7	   545.5  323%
*/

*-------------------------------------------------------------------------	
* 2.3 Social assistance family benefits (non-contributory & non-means-tested)
*-------------------------------------------------------------------------	

*************************************************************************
*** 2.3.a Birth grant (also for adoption)(bchbals_s)
**************************************************************************

// max benefit per year according to the nth child 
mat child_12 = (1533.9, 3681.4, 1840.7, 1227.1)  
mat child_1 = child_12/12  

recode child_m (4/7=4) (.=0),  gen(child_m2)  // no of children max=4

gen double  dtr_fnnb_hh = child_1[1, child_m2] if /*hy054g>0 &*/ sage_0>0

label var dtr_fnnb_hh "Dir.tranfers: Family N-NMT Birth child grant (household)"
percap dtr_fnn*hh
sumt dtr_fnnb_pc  // 7,569,095 vs	 11.7 million  (64%)


rpayh dtr_fnnb_pc 
sumt dtr_fnnb_rh 	// 39,035 ( 67%) vs 58 thousand beneficiaries

*************************************************************************
*** 2.3.b Non-means-tested child benefit for mothers in tertiary education 
**  (bchnm01_s)
**	>> sim 
**************************************************************************

gen int dtr_fnnt_ri=(pe021==50 & inrange(child_m,1,7) & sage_1>0)
sumt dtr_fnnt_ri // 1464 vs less than 1000 
gen double dtr_fnnt_in = (2880/EXR)*dtr_fnnt_ri 
sumt dtr_fnnt_in  // 2.155 vs 0.5
label var dtr_fnnt_in "Dir.tranfers: Family N-NM mothers in tertiary education (individual)"
percap dtr_fnnt_in 

*************************************************************************
*** 2.3.c Non-means-tested child benefit for twins  (bchnm02_s)
** >> sim 
**************************************************************************

tempvar twin1age maxtwin mintwin

gen `twin1age' = age if age_1==1
 
bysort hhid: egen `maxtwin' = max(`twin1age')
bysort hhid: egen `mintwin' = min(`twin1age')

gen int dtr_fnnw_ri=(sage_1==2 & `maxtwin'==`mintwin' & inrange(child_m,2,7))
sumt dtr_fnnw // 1109*2  vs 2 thousand 

replace dtr_fnnw_ri=dtr_fnnw_ri*2
gen double dtr_fnnw_in = dtr_fnnw_ri*1200/EXR 
label var dtr_fnnw_in "Dir.tranfers: Family N-NM child benefit for twins (individual)"
sumt dtr_fnnw_in // 1,360,405 million  vs 898 thousand 
percap dtr_fnnw_in 

	
*************************************************************************	
*** 2.3.d  Other non-means-tested family benefits (bfanmot)
** >> no sim 
**************************************************************************

gen double  dtr_fnno_hh = max(0, hy054g - dtr_fnnb_hh - dtr_fnnt_hh - dtr_fnnw_hh  )  // residual

label var dtr_fnno_hh "Dir.transfers: Family N-NM Other (household)"
percap dtr_fnno_hh 
rpayh dtr_fnno_hh 

label val dtr_*_rh dtr_*_ri yesno 

*************************************************************************	
*** 2.3.e  Totals 
**************************************************************************

/*
a.	Birth grant 				11.7	 	7.6
b.  Mothers in tertiary education 	 0.5		2.1
c.  Twins 					 	2.0		0.9
d.  Other 						93.1	-	102.5
	total 
*/

tabstat dtr_*_pc [w=round(weight)], stat(sum) save col(stat) format(%18.0fc)
tabstatmat dtr 
mata: sum(st_matrix("dtr"))

/*=====================================================================================
		3: Disability 
==================================================*/

*-------------------------------------------------------------------------	
	* 3.1 Disability  (all benefits)
*-------------------------------------------------------------------------	

egen double dtr_disb_in = rsum(py132g  py133g py134g)
gen dtr_disb_ri = (dtr_disb_in>0)
label var dtr_disb_in "Direct transfers: disability (individual)"

percap dtr_disb_in
lab_ri dtr_disb_in 

*-------------------------------------------------------------------------	
*** 3.2 Totals Disability 
*-------------------------------------------------------------------------	

sumt dtr_disb_in  // 748,041,783 vs 718.46
sumt dtr_disb_ri 	// 759,592	  vs	

// scale-down benefits 
summ dtr_disb_in [w=weight]
local ratio = (r(sum)/1000000)/718.46
replace dtr_disb_in = dtr_disb_in / `ratio'
percap dtr_disb_in
sumt dtr_disb_pc

/*==================================================
		4: Old-age and survivors 
==================================================*/


//  Old age and disability is grouped because this observation 
// 
// from @lucien:  old age and disability social assistance (individual); in 2019 
// there were shifts in numbers from old age to disability maybe because 
// measurement/ definition  
// 

************************************************************************
*** 4.1 Old age 
**************************************************************************

gen int dtr_oldb_ri= py103g>0 & py103g<.
	
tab dtr_oldb_ri   

/*
dtr_oldb_ri |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |     13,181       77.48       77.48
          1 |      3,831       22.52      100.00
------------+-----------------------------------
      Total |     17,012      100.00
*/

sumt dtr_oldb_ri 

// warning: from @lucien	2018
// old age and disability social assistance (individual); there were shifts in 
// numbers maybe due to measurement/ definition or legislation in 2019 
	
replace dtr_oldb_ri = 0 if (age<70) 
replace dtr_oldb_ri = 0 if (py132g>0 & py132g<.)
sumt  dtr_oldb_ri 	// 7,198

egen double dtr_oldb_in= rsum(py103g) 

tabstat dtr_oldb_in [w=weight] , stat(sum) format(%18.0fc) by(dtr_oldb_ri)

// INCOME TEST 


************************************************************************
*** 4.2 Others in Old age 
**************************************************************************

replace dtr_othr_in = dtr_othr_in + dtr_oldb_in if dtr_oldb_ri==0
replace dtr_oldb_in =0 					   if dtr_oldb_ri==0

label var dtr_oldb_in "Direct transfers: old-age nc (individual)"

percap dtr_oldb_in  //  5,674
lab_ri dtr_oldb_in 
sumt dtr_oldb_pc //  6,361,811  vs 4.84 

sumt dtr_oldb_ri 

************************************************************************
*** 4.3 Survivors 	
**************************************************************************
// Survivors total looks different than other sources, 
// so it has been added 
// to other transfers 

gen int dtr_surv_ri = py110g>0 & py110g<.
gen double dtr_surv_in = py110g
recode dtr_surv_in (.=0)

replace dtr_othr_in = dtr_othr_in + dtr_surv_in 


************************************************************************
*** 4.4 Totals 	
**************************************************************************


	/*==================================================
		5:  Unemployment  
	==================================================*/
	
************************************************************************
*** 5.1 Unemployment 
**************************************************************************
	
gen int dtr_unem_ri= py090g_f>0	// all "unemployment" benefits (contributory and non-contributory)
gen double dtr_unem_in= py090n		// all "unemployment" benefits (contributory and non-contributory)

drop dtr_unem_ri 
label var dtr_unem_in "Direct transfers: unemployment (individual)"

percap dtr_unem_in
rpayi dtr_unem_in 
lab_ri dtr_unem_in
sumt dtr_unem_in  // 403,198,527 vs 405.7 million 


************************************************************************
*** 5.2 Totals 	
**************************************************************************

	/*==================================================
		6:  Social assistance   not elsewhere classified  -- GMI --
	==================================================*/


*-------------------------------------------------------------------------	
*-------- 6.1 DMI
*-------------------------------------------------------------------------	
recode  hy07*f (min/0=0) (1/max=1) // -2 is NA 	

// calculate DMIs (EUROMOD 2020); see EU-SILC 2018 codebook by GESIS for variables
// hx040 = hsize 
	
// people over age of 75 living alone	
gen dmi_1= 1.65*(age>75 & hx040==1 & age!=.) 

// people over age of 65-75 living alone
gen dmi_2= 1.40*(age>65 & hx040==1 & age!=. /*& age<75*/ ) 

// people over 65y cohabiting w/other p
gen dmi_3= 1.00*(age>65 & hx040>1  & age!=. & hx040!=.) 

// people under 65y living alone 
gen dmi_4= 0.73*(inrange(age,17,65) & hx040==1) // IME dmi_5 

// people under 65y living w/other 
gen dmi_5= 0.66*(inrange(age,17,65) & hx040>1 & hx040!=.) 
recode dmi_5 (0.66=1.20) if (nkids3yo>0  & nworkage==1 & lonep_hh>0)
recode dmi_5 (0.66=1.00) if (nkidss16yo>0 & nworkage==1 & lonep_hh>0)
recode dmi_5 (0.66=1.00) if ((nkidss17_18>0 | nkidss19_20>0) & nworkage>1 & ///
	lonep_hh>0 & pe010!=1)

// 	disabled 50%+ (2, yes, limited)
gen dmi_6= 1.00* (ph030==2) 

// disabled 70%+ (1, yes, strongly limited) 
gen dmi_7= 1.25* (ph030==1) 

// all children, and youth in education
gen dmi_8= 0.91* (age<=16 | (inrange(age, 17, 20) & pe010==1))  

// for children not attending schoool
recode dmi_8 (0.91=0.20) if (rl020==0 & rl020_f==1) 	&	///
		(real(rl010)==0 | real(rl010)==.) & inrange(age,6,11) 
		
// for children not attending schoool
// asumming all 13-15, no info for educatio for those ages. 
	
recode dmi_8 (0.91=0.20) if rl020==. & rl020_f==-2 & pe010!=1 & ///
		(real(rl010)==0 | real(rl010)==.) & age==16 
		
recode dmi_8 (0.91=0.20) if (rl020==. & rl020_f==-2) & ///
		(real(rl010)==0 | real(rl010)==.) & age<13 		

/* not available 
pregnant woman = 1.00
for an orphan child; for a child accommodated in a family of close friends or 
relatives or in a receiving family – 100 percent of GMI
*/	

// from @lucien code note that the DMIs are calculated with the 2020 coefficient for adults 
// with children (0.73)

// dmi factor 
egen dmi_ind2020= rmax(dmi_1 dmi_2 dmi_3 dmi_4 dmi_5 dmi_6 dmi_7 dmi_8)
by hhid, sort: egen dmi_hh2020 = total(dmi_ind2020)


*-------------------------------------------------------------------------	
*--------  6.2 DMI  Heating 
*-------------------------------------------------------------------------	
	
// dmih1  person living alone 	
gen dmih_1     = 1.30*(hx040==1) 

// living alone reduced capacity
gen dmih_3	   = 1.57*(hx040==1 & inlist(ph030,1,2)) 

// orphan == NA

// living alone and bring up child up to 18 
gen dmih_2     = 1.57*(nkids18yo>0 &  lonep_hh>0) 
replace dmih_2 = 1.57 if (nkidss19_20>0 & lonep_hh>0) //  19-20 if studying 

// each spouses living together, including consensual union 
gen dmih_4     = 1.000*(hx040>1 & hx040!=. & spouse_in_hhd==1) 	

// child aged up to 18 (20 if studying)
gen dmih_5	   = 1.03*(age<=18) 
replace dmih_5 = 1.03 if (nkidss19_20>0)  //  19-20 if studying 
// children not attending school 
replace dmih_5 = 0.3 if inrange(age,5,16)  & rl020==.
replace dmih_5 = 0.5 if inrange(age,17,18) & rl020==.
replace dmih_5 = 0.9 if inrange(age,16,18) & rl020==. & employ_status==.z

recode dmih_5 (1.03=1.3) if ((age<=8) & dtr_disb_pc>0)
recode dmih_5 (1.03=1.3) if (inrange(age,9,20) & dtr_disb_pc>0) & rl020!=.

// child accommodated with relatives's family or in foster family 
// n/a

// Personal cohabiting with other persons. 
gen dmih_6= 1.24*(inrange(age,17,70) & hx040>1 & spouse_in_hhd==0 & ///
	!inrange(dmih_5,0.5,1.3))  
	
// pregnant woman 45 days before the term
// n/a

// lone? parent taking care of a children under age of 3 
gen dmih_7= 1.2*(nkids3yo>0  & nworkage==1 & lonep_hh>0) 

// people over age of 70
gen dmih_8= 1.2*(age>70 & age!=.) 

// people over age of 65 living alone
gen dmih_10=1.75*(age>65 & hx040==1 & age!=.) 

// people over age of 75 living alone
gen dmih_9= 1.85*(age>75 & hx040==1 & age!=.) 

// reduced working capacity´ 50% or more 
gen dmih_11= 1.2*(ph030==2) // 	d 50%+ (2, yes, limited)

// disabled 70%+ (1, yes, strongly limited) 
replace dmih_11= 1.42  if ph030==1 

// children with permanent disabilities
gen dmih_12 = 1.30*(inrange(age,0,8) & dtr_disb_hh>0) | ///
				(inrange(age,9,20) & rl020!=. & dtr_disb_hh>0)	
					
egen dmih_ind2020= rowmax(dmih_*)
by hhid, sort: egen dmih_hh2020= total(dmih_ind2020)


*-------------------------------------------------------------------------	
*--------  6.3 GMI &  Heating TOTALS 
*-------------------------------------------------------------------------	

*************************************************************************
*** 6.3.1 Exempted income by hhd 
**************************************************************************
	
/*  
generate the HH income subject to means test: disposable HH income minus 
	(social exclusion, disability allowances, education allowances) 	
- HH social exclusion allowances: hy063g (imtsoexb_hh)
- HH education allowances (non-contributory): hpy143g and hpy144g; 
	see also flags for corresponding py
- HH disability allowances (non-contributory): hpy133g and hpy134g; 
	see also flags for corresponding py
- egen igmiexempt_hh=rowtotal(hy063g hpy143g hpy144g hpy133g hpy134g) 
e	xemptions from the test with all disability noncontributory benefits 
*/

bysort hhid: egen double hpy140g = sum(py140g)
bysort hhid: egen double hpy130g = sum(py130g)
// travel free allowance around 26.25 euros in 2018
// assumming 30 EUR in 2020
/*	
One-off assistance for free travel once a year by rail and bus is offered by the Agency for
Social Assistance (ASA) based on the GMI of mothers with three or more children. In
2018, 8,521 mothers received support to travel. The total sum paid by the ASA was
437,353 BGN (€223,709)6
*/

gen pytravel=30 if child_m>=3 
bysort hhid: egen double hpytravel = sum(pytravel)


/// GMI 
egen igmiexempt20_hh=rowtotal(hy060g hpy140g hpy130g dtr_fncb_hh dtr_fnnb_hh hpytravel)
gen    igmitestable20_hh=hy020-igmiexempt20_hh // INCOME = HY020 OR HY023
recode igmitestable20_hh (min/0=0)

*************************************************************************
*** 6.3.2 Dmi value 2020 ................................................
**************************************************************************

global dmi_val2020  = 75   
global gmih_val2020 = 150

// HHD monthly Benefit Heating allowance 
scalar HEATING_ALLOWANCE = 99.16

*************************************************************************
*** 6.3.3  Test income = disp income SILC - Exempt income ...............
**************************************************************************

// see above hy020 - exempt income 

*************************************************************************
*** 6.3.4 Annual benefits  in euros ......................................
**************************************************************************
	
gen double gmi2020_hh=(${dmi_val2020}*dmi_hh2020*12)/EXR  // to Euros 

// adjusting gmi for heating based on lower figures w/r admin accounts 
// justification: missing info for orphan child, pregnant women, child 
//	16-18 registered at a local employment office (we used only unemployment)


gen double hai2020_hh=(${gmih_val2020}*dmih_hh2020*12)/EXR*1.17  // to Euros 

// GMI dif dmi2020 (annual in euros) minus test income 
gen double dtr_gmis_hh = max(0, gmi2020_hh - igmitestable20_hh)
gen double dtr_hais_hh = (hai2020_hh > igmitestable20_hh)*(HEATING_ALLOWANCE/EXR)
replace dtr_hais_hh= dtr_hais_hh*5  // only 5 months 

foreach var of varlist dtr_gmis_hh dtr_hais_hh {
	replace `var' = 0  if  rb290=="OTH" & `var'>0 // not local and not UE
}

label var dtr_gmis_hh "Direct transfer: Social Monthly Assistance GMI (household)"
label var dtr_hais_hh "Direct transfer: Heating allowance (household)"

sort hhid hhin 
by hhid: gen num = _n 

*************************************************************************
*** 6.3.5  Per capita benefits ...........................................
**************************************************************************

percap dtr_gmis_hh 
percap dtr_hais_hh 

rpayh dtr_gmis_hh 
sumt dtr_gmis_rh // 42600 vs 24000
sumt dtr_gmis_pc 	//  27.584601 vs 14.31

rpayh dtr_hais_hh 
sumt dtr_hais_rh  // 265,896 vs 284,000 //266412
sumt dtr_hais_pc 	// 67.4 m vs 71.58m

**************************************************************************
** 6.3.6  Check totals .................................
**************************************************************************

// recipients variable (only 1 per household)

summ dtr_gmis_rh [w=weight], meanonly
local ben_gmi100 = r(sum)
di %18.0fc `ben_gmi100' //  42,600   vs 24,000  [57% uptake]

summ dtr_hais_rh [w=weight], meanonly
local ben_hai100 = r(sum)
di %18.0fc `ben_hai100' //  265,896 vs 284,000 [99% uptake] with adjustment to hhd gmi 
	
// Benefits 	
summ dtr_gmis_pc [w=weight], meanonly
di %18.0fc r(sum) "...BGN" as result %18.0fc r(sum)*EXR //    24,761,226
//    27,584,601...BGN        53,949,963 

summ dtr_hais_pc [w=weight], meanonly
di %	18.0fc r(sum) "...BGN" as result %18.0fc r(sum)*EXR  //   67,536,066
//      67,536,066...BGN        131,831,110

**************************************************************************
** 6.3.7  Select a share of the beneficiaries ............................
**************************************************************************

set seed 13270
gen rand = runiform()

local ben_gmitk = 24000
local ben_haitk = 284000

local limit_dtr_gmis = `ben_gmitk'+500
local limit_dtr_hais = `ben_haitk'+500

local adjustment dtr_gmis dtr_hais 
mat define adj_val = J(wordcount("`adjustment'"),2,.)
mat rownames adj_val = `adjustment'
mat colnames adj_val = benefs LCU 
local i=1

foreach var of local adjustment {
	cap drop sum_weight sum_benefits 
	cap drop _*

	gsort -`var'_rh num rand 
	gen double sum_weight=sum(weight) if num==1

	tempvar benef1
	gen double `benef1' = `var'_hh*weight*EXR
	gen double sum_benefits=sum(`benef1') 

	replace `var'_rh =0 if sum_weight > `limit_`var'' & `var'_rh==1
	summ `var'_rh [w=weight], meanonly
	mat adj_val[`i',1]=r(sum)
	tempvar `var'_max
	bysort hhid: egen ``var'_max' = max(`var'_rh)
	replace `var'_pc =0  if ``var'_max'==0 
	replace `var'_hh =0  if ``var'_max'==0 

	summ `var'_pc [w=weight], meanonly
	mat adj_val[`i',2]=r(sum)*EXR
	local ++i
}	

matlist adj_val, format(%12.0fc)

/*

             |       benefs           LCU 
-------------+----------------------------
    dtr_gmis |       24,413    32,256,142    vs 24.0 th   -  28 m 
    dtr_hais |      264,344   131,061,819 	vs 284  th  -  140 m	
	
             |       benefs           LCU 
-------------+----------------------------
    dtr_gmis |       24,413    32,256,142 
    dtr_hais |      264,771   131,273,708 

	
*/

*-------------------------------------------------------------------------	
*--------  6.4 Other social assistance direct transfers 
*-------------------------------------------------------------------------	

**************************************************************************
*** 6.4.1 check duplicates 
**************************************************************************
*** 6.4.2 other transfers 
**************************************************************************


recode hy07*f (min/0=0) (1/max=1) // -2 is NA  CHECK 

gen int dtr_hous_rh = hy070g_f>0  // could be as an in-kind transfer
gen int dtr_educ_ri = py140g_f>0 // education related allowances

/*
gen double dtr_soem_hh = hy063g	  // means-tested non-contributory social exclusion (social benefit and heating allowance)
gen double dtr_soen_hh = hy064g	  // non means-tested non-contributory social exclusion (social benefit and heating allowance)
*/

gen double dtr_soem_hh= max(0, hy070g - dtr_hais_hh - dtr_gmis_hh)
gen double dtr_hous_hh = hy070n	  // could be as an in-kind transfer
gen double dtr_educ_in = py140n  	  // education related allowances

recode dtr_educ_in (.=0)

label var dtr_hous_hh "Direct transfers: survivors (household)"
label var dtr_soem_hh "Direct transfers: other social exclusion (household)"
label var dtr_educ_in "Direct transfers: education allowances (individual)"

percap dtr_hous_hh dtr_soe?_hh dtr_educ_in dtr_othr_in 
rpayh  dtr_hous_hh dtr_soe?_hh 
rpayi  dtr_educ_in 
/*lab_rh dtr_hous_hh dtr_soe?_hh 
lab_ri dtr_educ_in*/ 

misstable summ dtr*pc dtr*in 


//                             SB + HEATING   HEATING      EDUCATION 
replace dtr_othr_in = dtr_othr_in + dtr_soem_pc + dtr_educ_in + dtr_hous_pc  // <-HOUSING 

percap dtr_othr_in 

drop dtr_soem_* dtr_educ_* dtr_hous_*

*All Social Assistance

label val dtr_*_rh yesno 

tabstat dtr_*_pc [w=weight], stat(sum) format(%15.0fc) col(stat) 

/*
    Variable |             Sum
-------------+----------------
 dtr_fncb_pc |     153,541,366
 dtr_fncs_pc |      88,095,474
 dtr_fnco_pc |     184,158,778
 dtr_fmne_pc |       4,246,438
 dtr_fmn1_pc |       3,320,267
 dtr_fmnc_pc |     137,446,142
 dtr_fmno_pc |     399,668,947
 dtr_fnnb_pc |       7,569,095
 dtr_fnnt_pc |       2,155,324
 dtr_fnnw_pc |       1,360,405
 dtr_fnno_pc |     102,270,260
 dtr_disb_pc |     718,460,000
 dtr_oldb_pc |       6,361,811
 dtr_unem_pc |     403,198,527
 dtr_gmis_pc |      16,492,556
 dtr_hais_pc |      67,251,066
 dtr_othr_pc |     136,850,767
------------------------------
*/



tempvar dtr_tot_pc dtr_fam_pc 
egen `dtr_fam_pc' = rsum(dtr_f*_pc)
summ `dtr_fam_pc' [w=weight], meanonly 
	di %15.0fc r(sum)	
** 1,083,832,496  OK 

egen `dtr_tot_pc' = rsum(dtr_*_pc)
summ `dtr_tot_pc' [w=weight], meanonly 
	di %15.0fc r(sum)

**  2,432,447,223  ok 

/*==================================================
	7: Disposable Income 
	==================================================*/

egen double yd_pc = rsum(yn_pc dtr_*_pc)	
label var yd_pc "Disposable income (per capita)"

egen double yg_pc = rsum(yp_pc dtr_*_pc)	
label var yg_pc "Gross income (per capita)"

drop if yd_pc ==.

	cap drop yd_ae 
	tempvar yd_pc_lcu yd_ae_lcu  
	gen `yd_pc_lcu' = yd_pc*px010
	gen  `yd_ae_lcu' = (`yd_pc_lcu'*hsize)/hx050	
	summ `yd_pc_lcu'
	
	/*
	    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
    __000001 |     17,012    8623.678    9246.328   29.23565   346012.2
	*/
	
	ainequal yd_pc ym_pc [w=round(weight)] if memb_no==1
	
	povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
	povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
	povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62) 		
	povcc `yd_ae_lcu'  [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	
	
	summ y*_pc 

	/*
.         povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.87) 
ppp 1.9:  0.93, official:  0.87

.         povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(2.16) 
ppp 3.2:  2.16, official:  2.16

.         povcc `yd_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(6.90)           
ppp 5.5:  6.82, official:  6.90

.         povcc `yd_ae'      [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.6)  
National: 22.83, official: 22.60


	*/
	
	


/**
	** checking difference between Market Income using EU-SILC components vs
	CEQ definition 
	**/
	cap drop _*
	
	tempvar dif1 dif2 yd2 dif3 yd3 dif4 yd4 dif5 yd5 dif6 yd6 ///
		dtax1_hh dtax1_pc dtax2_hh dtax2_pc empcon_hh empcon_pc dtx_tot difym 
	gen `dif1' = round(yd_pc - yd2_pc)
	summ  `dif1'
	count if `dif1'>0
	**   15,661
	
	** + differences btw market income and EUSILC disp income befor transfers
	** and taxes 
	
	gen `difym' = ym_pc - ym2_pc 	
	egen double `yd2' = rsum(yd2_pc `difym' )
	gen double `dif2' = round(yd_pc - `yd2')
	summ  `dif2'
	count if `dif2'>0
	**  3,882
	
	** difference in direct taxes + contributions 
	
	egen double `dtax1_hh' = rsum(hy120g)
	bysort hhid: egen double `empcon_hh' = sum(py030g)	
	gen double `dtax1_pc' = (`dtax1_hh' / hsize)
	egen double `dtax2_hh' = rsum(hy140g)	
	gen double `dtax2_pc' = (`dtax2_hh' / hsize)
	gen double `empcon_pc' = (`empcon_hh' / hsize)*-1 
	egen double `dtx_tot'  =  rsum(dtx_*_pc con_*_pc cpn_*_pc) 
				
	egen double `yd3' = rsum(`yd2' `dtx_tot' `dtax1_pc' `dtax2_pc'  `empcon_pc')
	gen double `dif3' = round(yd_pc - `yd3')
	summ  `dif3'
	count if `dif3'>0
	** 383
	
	summ ym_pc yd_pc ym2_pc yd2_pc 

	/* gsort -`dif3'
	format y*pc  `yd3' `dif3' cpn* con* dtx* dtr* %15.0fc 
	
	tab `dif3' if `dif3'>0
	
	** diff ym, cons. 
	
	list hhid ym2_pc ym_pc yp_pc yn_pc yd2_pc yd_pc `yd2' `yd3' `dif3' ///
	`dtx_tot' dtx*pc con*pc cpn*pc ///
	`dtax1_pc' `dtax2_pc' `empcon_pc' hy120g hy140g py030g ///
	dtr*pc pen*pc  ///
	if `dif3'>0 & `dif3'>1000, sepby(hhid)
	
		
	list hhid ym2_pc ym_pc yd2_pc yd_pc `yd3' `dif3' ///
	`dtx_tot' `dtaxes_pc' `empcon_pc' hy120g hy140g dtx*hh ///
	if `dif3'<0 , sepby(hhid) */
		
	
/*==================================================
	8:  Clean & save file  
	==================================================*/


	cap drop _*		
	save "${tmp}BGR20_dis_inc.dta", replace 
	
	cap log close
	exit 
	/* End of do-file */
	
	/*
		><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><
		
		Notes:
		
		Version Control: 6
		
		Changes 
		------------------
		6. Jan 2023
		-	GMI estimation
		
		
		
	*/
	

/*==================================================
	9:  ESPROSS estimates for Macro consistency 
	==================================================*/



cd "${tmp}"

global espross_year = 2020

cd "${path}3.data/NATIONAL ACCOUNTS/ESPROSS"
	** Social Protection 
mat tot_benefits = J(1,2,.)
mat disability   = J(7,2,.)
mat old_age      = J(3,2,.)
mat fam_child    = J(16,2,.)
mat unemployment = J(1,2,.)
mat housing       =J(1,2,.)
mat oth_socialex  =J(5,2,.)
mat oth_socialpr  =J(4,2,.)
mat sickness      =J(1,2,.)
mat health        =J(5,3,.)
mat education     =J(9,3,.)
mat other         =J(1,2,.)


	
eurostatuse spr_exp_eur, clear geo( BG) keepdim() start(${espross_year}) end(${espross_year})
drop geo*
drop spscheme*

table spfunc_label  spdep  if substr(spdep,4,1)=="C" & !inlist(spfunc,"TOTAL","SICK"), stat(sum spr_exp)
** sickness should be in health 

/*
---------------------------------------------------------------------------------------------------------------------------------------------
                          |                                                 ESSPROS-expenditure                                              
                          |   SNTCASH   SNTCLUMP   SNTCPERIOD   STACASH   STACLUMP   STACPERIOD    STTCASH   STTCLUMP   STTCPERIOD      Total
--------------------------+------------------------------------------------------------------------------------------------------------------
spfunc_label              |                                                                                                                  
  Disability              |    718.46      21.82       696.63       .01        .01            0     718.47      21.83       696.63   2,873.86
  Family/Children         |     449.7      13.52       436.17    165.12       5.59       159.53     614.82      19.12        595.7   2,459.27
  Housing                 |         0          0            0         0          0            0          0          0            0          0
  Old age                 |  4,718.31      298.8     4,419.51      4.84          0         4.84   4,723.15      298.8     4,424.35   18,892.6
  Social exclusion n.e.c. |         0          0            0     27.27       3.23        24.04      27.27       3.23        24.04     109.08
  Survivors               |    555.89      20.84       535.05         0          0            0     555.89      20.84       535.05   2,223.56
  Unemployment            |    405.75      67.41       338.34         0          0            0     405.75      67.41       338.34      1,623
  Total                   |  6,848.11     422.39      6,425.7    197.24       8.83       188.41   7,045.35     431.23     6,614.11   28,181.4
---------------------------------------------------------------------------------------------------------------------------------------------

*/

/*

    spfunc_label |       Sum
-----------------+----------
      Disability |    674.36
 Family/Children |    600.64
         Housing |         0
         Old age |   4125.33
Social exclusion |     15.55
       Survivors |    513.09
    Unemployment |    269.28
-----------------+----------
           Total |   6198.25
----------------------------
*/	


tabstat  spr_exp if inlist(spdep,"STTCASH") & !inlist(spfunc,"TOTAL","SICK"), stat(sum ) by(spfunc_label) save 
tabstatmat totcash 

/*
    spfunc_label |       Sum
-----------------+----------
      Disability |    142.89   tot 817.25
 Family/Children |    379.34
         Housing |       .27
         Old age |     23.95
Social exclusion |    114.34
       Survivors |       .06
    Unemployment |     15.22
-----------------+----------
           Total |    676.07
----------------------------
*/

tabstat  spr_exp if inlist(spdep,"STTKIND") & !inlist(spfunc,"TOTAL","SICK"), stat(sum ) by(spfunc_label) save
tabstatmat totkind

mata: st_matrix("totsp",(st_matrix("totcash")+st_matrix("totkind"), st_matrix("totcash")))

mat tot_benefits[1,1]=totsp[8,1]
mat tot_benefits[1,2]=totsp[8,2]


**************************************************************************
* Tables by benefits - family/children function (spr_exp_ffa) 	
eurostatuse spr_exp_ffa, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
drop spscheme*
keep if unit=="MIO_EUR"

list spdep* spr if substr(spdep,1,4)=="SNTC" & spdep!="SNTCPERIOD" & spdep!="SNTCASH" & spdep!="SNTCLUMP"

list spdep* spr if substr(spdep,1,4)=="STAC" & !inlist(spdep,"STACASH","STAPERIOD","STACLUMP")
summ spr_exp if substr(spdep,1,4)=="STAC" & !inlist(spdep,"STACASH","STACPERIOD","STACLUMP")
di %18.2fc r(sum)

list spdep* spr if substr(spdep,1,3)=="STT"


encode spdep, gen(cspdep)
recode cspdep (1=.) (2=2) (5=.) (6=10) (4=5) (3=5)  (7=9)   (8=4) (9=.) (10=6) ///
	(11=7) (12=.) (13/17=.) (18=12) (19/21=.) (22=16) (23=13) (24/25=.) (26=14) ///
	(27=15) (28/33=.) (34=1) (35/39=.) ///
	 (40=.) (41/46=.) (47=21)  (48/51=.), gen(fcspdep2)

replace fcspdep2=22 if spdep =="SNTKIND"
replace fcspdep2=23 if spdep =="STAKIND"

label define fcspdep2 1 "Cash Total" 2 "Non-means-tested" 3 "Contributory" ///
4 "Income maintenance benefit in the event of childbirth" ///
5 "Birth grant" ///
6 "Parental leave benefit periodic" ///
7 "Other periodic benefits" ///
8 "Child & family nc" 9 "Family or child allowance"  ///
10 "Other lump sum cash benefits" ///
11 "Mean-tested" ///
12 "Child & family means-tested"  13 "Family or child allowance" ///
14 "Parental leave benefit periodic" 15 "Other periodic cash benefits" ///
16 "Other lump sum cash benefits" 

label define fcspdep2 21 "In-kind Total" 22 "In-kind non-means-tested" ///
   23 "In-kind non-means-tested", modify

label val fcspdep2 fcspdep2

tabstat  spr_exp if fcspdep2<21, stat(sum ) by(fcspdep2) save nototal
tabstatmat totcash 
/*
        fcspdep2 |       Sum
-----------------+----------
      Cash Total |    600.64
Non-means-tested |    428.95
Income maintenan |     228.5
     Birth grant |     12.74
Parental leave b |     90.41
Other periodic b |      3.66
Family or child  |      91.7
Other lump sum c |      1.94
Child & family m |    171.69
Family or child  |     145.9
Parental leave b |      7.69
Other periodic c |     14.75
Other lump sum c |      3.35
----------------------------

*/	


mata: st_matrix("totsp" , (st_matrix("totcash")[1::2,1] \ /// 
sum(st_matrix("totcash")[3::6,1]) \  st_matrix("totcash")[3::6,1] \ ///
sum(st_matrix("totcash")[7::8,1]) \ st_matrix("totcash")[7::8,1] \ ///
st_matrix("totcash")[9::9,1] \ st_matrix("totcash")[9::13,1]))


tabstat  spr_exp if fcspdep2>=21, stat(sum ) by(fcspdep2) save nototal
tabstatmat totkind
mat totkind = (totkind[1,1]  \  totkind[2,1] \ totkind [2,1] \ ///
				J(8,1,.) \ totkind[3,1] \  J(4,1,.))


mata: st_matrix("fam_child", (rowsum(st_matrix("totkind"))+st_matrix("totsp"), st_matrix("totsp")))

list spdep* spr if substr(spdep,1,3)=="STT"
list spdep* spr if substr(spdep,1,4)=="STTC"

summ spr if inlist(spdep,"STTCASH","STTKIND")
di %12.2fc r(sum)


**************************************************************************
** Disability 
eurostatuse spr_exp_fdi, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

encode spdep, gen(cspdep)
recode cspdep (1=.) (2=.) (3=.) (4=6) (5=.) (7=4) (6=7) (8=2) (9=.) (10=5) ///
	(11=.) (12=3) (13/22=.) (23=7) (24=.) (25=2) (26/35=.) (36=1) (37/48=.) ///
	 (49=10) (50/51=.), gen(cspdep2)

label define cspdep2 1 "Disability Total"  2 "Disability pension" ///
3 "Other periodic cash benefits" 4 "Periodic care allowance" ///
5 "Periodic economic integration of the handicapped" ///
6 "Lump sum economic integration of the handicapped" ///
7 "Other lump sum cash benefits"

label define cspdep2 10 "In-kind Total", add 

label val cspdep2 cspdep2

tabstat  spr_exp if cspdep2<10, stat(sum ) by(cspdep2) save 
tabstatmat totcash 
tabstat  spr_exp if cspdep2>=10, stat(sum ) by(cspdep2) save 
tabstatmat totkind
mat totkind = totkind[1,1] \ J(5,1,.) \ totkind[1,1]

mata: a= (st_matrix("totcash")[1::7, 1]+rowsum(st_matrix("totkind")), st_matrix("totcash")[1::7,1])
mata: st_matrix("totsp", a[1,.] \ a)




list spdep* spr if substr(spdep,1,3)=="STT"

summ spr if inlist(spdep,"STTCASH","STTKIND")
di %12.2fc r(sum)

matlist totsp , format(%12.2fc)

mat disability = totsp 

**************************************************************************

** Old.age
eurostatuse spr_exp_fol, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

list spdep* spr if substr(spdep,1,3)=="STT"

list spdep* spr if substr(spdep,1,3)=="SNT"

list spdep* spr if substr(spdep,1,3)=="STA"

summ spr if spdep == "STTCASH", meanonly
matrix old_age[1,2]=r(sum)
summ spr if spdep == "SNTCASH", meanonly
mat old_age[2,2]=r(sum)
summ spr if spdep == "STACASH", meanonly
mat old_age[3,2]=r(sum)

summ spr if inlist(spdep, "STTCASH", "STTKIND"), meanonly
matrix old_age[1,1]=r(sum)
summ spr if inlist(spdep, "SNTCASH","SNTKIND"), meanonly
mat old_age[2,1]=r(sum)
summ spr if inlist(spdep, "STACASH", "STAKIND"), meanonly
mat old_age[3,1]=r(sum)




* Tables by benefits - unemployment function (spr_exp_fun) 	
eurostatuse spr_exp_fun, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

summ spr if spdep == "STTCASH", meanonly
matrix unemployment[1,2]=r(sum)

summ spr if inlist(spdep, "STTCASH", "STTKIND"), meanonly
matrix unemployment[1,1]=r(sum)

* Tables by benefits - housing function (spr_exp_fho) 	
eurostatuse spr_exp_fho, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

summ spr if spdep == "STTCASH", meanonly
matrix housing[1,2]=r(sum)

summ spr if inlist(spdep, "STTCASH", "STAKIND"), meanonly
matrix housing[1,1]=r(sum)


*Tables by benefits - social exclusion n.e.c. function (spr_exp_fex) 	
eurostatuse spr_exp_fex, clear geo( BG) keepdim() start($espross_year) end($espross_year)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

summ spr if spdep == "STTCASH", meanonly
matrix oth_socialex[1,2]=r(sum)

summ spr if spdep == "STACASH", meanonly
matrix oth_socialex[2,2]=r(sum)
summ spr if spdep == "STACPERIOD", meanonly
matrix oth_socialex[3,2]=r(sum)

summ spr if spdep == "STACLUMP", meanonly
matrix oth_socialex[4,2]=r(sum)

summ spr if spdep == "SNTCASH", meanonly
matrix oth_socialex[5,2]=r(sum)


summ spr if inlist(spdep, "STTKIND",  "STTCASH"), meanonly
matrix oth_socialex[1,1]=r(sum)

summ spr if inlist(spdep, "STAKIND", "STACASH"), meanonly
matrix oth_socialex[2,1]=r(sum)

summ spr if inlist(spdep, "STACPERIOD"), meanonly
matrix oth_socialex[3,1]=r(sum)

summ spr if inlist(spdep, "STACLUMP"), meanonly
matrix oth_socialex[4,1]=r(sum)

summ spr if inlist(spdep, "SNTKIND", "SNTCASH"), meanonly
matrix oth_socialex[5,1]=r(sum)

*summ spr if inlist(spdep, "STTCASH", "STAKIND"), meanonly
*matrix oth_socialex[1,1]=r(sum)

**************************************************************************
* Tables by benefits - survivors function (spr_exp_fsu) 	
eurostatuse spr_exp_fsu, clear geo( BG) keepdim() start($espross_year) end($espross_year)

drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

summ spr if spdep == "STTCASH", meanonly
matrix oth_socialpr[1,2]=r(sum)

summ spr if spdep == "STTCASH", meanonly
matrix oth_socialpr[2,2]=r(sum)
summ spr if spdep == "STTCPERIOD", meanonly
matrix oth_socialpr[3,2]=r(sum)

summ spr if spdep == "STTCLUMP", meanonly
matrix oth_socialpr[4,2]=r(sum)

summ spr if inlist(spdep, "STTKIND",  "STTCASH"), meanonly
matrix oth_socialpr[1,1]=r(sum)

summ spr if inlist(spdep, "STTAKIND", "STTCASH"), meanonly
matrix oth_socialpr[2,1]=r(sum)

putexcel set "${tmp}espross.xlsx", modify sheet("${espross_year}")

putexcel D21=matrix(disability) D30=matrix(old_age) D33=matrix(fam_child) ///
		D49=matrix(unemployment) D52=matrix(housing) ///
		D53=matrix(oth_socialex) D59=matrix(oth_socialpr)
		
putexcel clear 		


** Sickness Health 
eurostatuse spr_exp_fsi, clear geo( BG) keepdim() start($espross_year) end($espross_year)

***************************************************************




* Tables by benefits - all functions (spr_exp_fto) 	
eurostatuse spr_exp_fto, clear geo( BG) keepdim() start(2019) end(2019)
drop geo*
keep if unit=="MIO_EUR"
drop spscheme*
drop unit*

/*
	     +----------------------------------------------------------------------------+
     |               spdep                                 spdep_label   spr~2019 |
     |----------------------------------------------------------------------------|
  1. | SNONTARGETNOREROUTE                   Non means-tested benefits       9595 |
  2. |             SNTCASH            Cash benefits (non means-tested)    6327.44 |
  3. |            SNTCLUMP   Lump sum cash benefits (non means-tested)     165.76 |
  4. |          SNTCPERIOD   Periodic cash benefits (non means-tested)    6161.68 |
  5. |             SNTKIND         Benefits in kind (non means-tested)    3267.55 |
     |----------------------------------------------------------------------------|
  6. |    SPBENEFNOREROUTE                  Social protection benefits    9847.12 |
  7. |             STACASH                Cash benefits (means-tested)     191.68 |
  8. |            STACLUMP       Lump sum cash benefits (means-tested)       4.46 |
  9. |          STACPERIOD       Periodic cash benefits (means-tested)     187.21 |
 10. |             STAKIND             Benefits in kind (means-tested)      60.44 |
     |----------------------------------------------------------------------------|
 11. |    STARGETNOREROUTE                       Means-tested benefits     252.12 |
 12. |             STTCASH                               Cash benefits    6519.12 |
 13. |            STTCLUMP                      Lump sum cash benefits     170.22 |
 14. |          STTCPERIOD                      Periodic cash benefits     6348.9 |
 15. |             STTKIND                            Benefits in kind       3328 |
     +----------------------------------------------------------------------------+
*/


eurostatuse spr_exp_sum, clear geo( BG) keepdim() start(2019) end(2019)

** Pensions 
eurostatuse spr_exp_pens, clear geo( BG) keepdim() start(2019) end(2019)
drop geo*
keep if unit=="MIO_EUR"
drop unit*

/*
-------------------------------------------------------------------------------------------------------------------
                                                           |                       spdepm_label                    
                                                           |  Means-tested   Non means-tested      Total      Total
-----------------------------------------------------------+-------------------------------------------------------
spdepb_label                                               |                                                       
  Anticipated old age pension                              |             0              496.3      496.3      992.6
  Disability pension                                       |             0             394.62     394.62     789.24
  Early retirement benefit due to reduced capacity to work |             0                  0          0          0
  Early retirement benefit for labour market reasons       |             0                  0          0          0
  Old age pension                                          |          4.43           3,546.15   3,550.58   7,101.16
  Partial pension                                          |             0                  0          0          0
  Survivors pension                                        |             0             158.15     158.15      316.3
  Total                                                    |          4.43           4,595.23   4,599.66   9,199.32
  Total                                                    |          8.86           9,190.45   9,199.31   18,398.6
-------------------------------------------------------------------------------------------------------------------
*/

eurostatuse  spr_rec_sumt, clear geo( BG) keepdim() start(2019) end(2019)

eurostatuse spr_rec_eur, clear geo( BG) keepdim() start(2019) end(2019)

eurostatuse gov_10a_taxag, clear geo( BG) keepdim() start(2019) end(2019)

** Government finance statistics  ----------------------------------
eurostatuse gov_10a_main, clear geo( BG) keepdim() start(2000) end(2019)
keep if sector=="S13"
keep if unit=="MIO_NAC"
drop geo*
drop sector* 
drop unit*

** deficit B9
forval i=2000(1)2019 {
	local disp = "`disp' "+"gov_10a_main`i'"
}

order unit-na_item_label `disp'

mkmat gov*  if na_item=="B9", mat(deficit)
mkmat gov*  if na_item=="D41PAY", mat(interest)

** For B3 checking ********************************************************
*eurostatuse gov_10a_main, clear geo( BG) keepdim() start(2019) end(2019)
eurostatuse gov_10a_main, clear geo( BG) keepdim() start(2018) end(2018)	
keep if unit=="MIO_EUR"
drop geo*
drop unit*
gen na_iteml = substr(na_item_label,1,40)
list na_item na_iteml gov* if sector =="S13" & flag!="z" & gov!=. ///
	& inlist(substr(na_item,1,1),"D","T","O")
cd "C:\Users\mynor\Dropbox (Personal)\zotros\BM\BGR\3.data\NATIONAL ACCOUNTS\macro\"
export excel na_item na_iteml gov* using "gen_gov_eurostat_18.xlsx" ///
if sector =="S13" & flag!="z" & gov!=. &  ///
inlist(substr(na_item,1,1),"D","T","O"), firstrow(variables) sheetmodify ///
sheet("general")

*eurostatuse gov_10a_taxag, clear geo( BG) keepdim() start(2019) end(2019)

eurostatuse gov_10a_taxag, clear geo( BG) keepdim() start(2018) end(2018)
keep if unit=="MIO_EUR"
drop geo*
drop unit*
gen na_iteml = substr(na_item_label,1,40)
list na_item na_iteml gov* if sector =="S13" & flag!="z" & gov!=. 

export excel na_item na_iteml gov* using "gen_gov_eurostat_18.xlsx" ///
if sector =="S13" & flag!="z" & gov!=. , firstrow(variables) sheetmodify sheet("taxes")
