capture log close
log using "${log}5_BGR_IndTaxes.txt", replace text
/*==================================================
	project:       CEQ Bulgaria
	Author:        Cabrera, M. 
	E-email:       
	url:           
	Dependencies:  World Bank
	----------------------------------------------------
	Creation Date:    11 Apr 2022 - 10:21:11
	Modification Date:   
	Do-file version:    02
	References:          
	Output:             dotemplate.ado
==================================================*/

/*==================================================
	0: Program set up
==================================================*/
version 15

global escen_0		0
global xlmip_2014   "${tmp}io_2014.xlsx"
global xlmip_2010   "${tmp}io_2010.xlsx"
global ctec   		"${tmp}ctaugio_2014.xlsx"
global simulations  "$escen_0" 
global io_version   "2010"
global fpath_2014   "${raw}miprd_2012_producto_producto.xlsx"
global fpath_2010   "${raw}miprd_2012_producto_producto.xlsx"
global yy_eurostat 	 2020
global std_rateoil = 0.4474955 //0.326874 HIGHEST RATE 
global std_ratevat = 20 

cd "${tmp}"

/*==================================================
	1: Cleaning HBS survey 
==================================================*/


*----------1.1: Open survey from Excel 

** need usepss ado 
cap confirm file "${tmp}hsb_coicop.dta"

if _rc {
	
	import excel using "${raw}HBS/2021 HBS/Data/Basic_HBS_2021/hh_basic_2021_HBS_BG.xlsx", clear firstrow
	rename *, lower 
	
	
	*----------1.2: label variables 
	
	label var ha02 "Survey year(s)"
	label var ha04 "Identification number of the household"
	label var ha06 "Stratum"
	label var ha07 "Primary sampling unit"
	label var ha08 "Region of residence"
	label var ha09 "Degree of urbanisation"
	label var ha10 "Sample weight"
	
	
	
	*----------1.3: dropping income variables 
	drop hh* 
	drop hi*
	
	*----------1.4:
	rename he_a_*  consm*
	rename hq_*    quant*
	rename he_*    expen*
	
	rename ha04 hhid 
	rename ha06 strata 
	rename ha07 psu 
	rename ha10 weight 
	
	bysort hhid: gen no=_n
	gen one=1
	tab one [w=round(weight)] if no==1
	
	/*
	        one |      Freq.     Percent        Cum.
	------------+-----------------------------------
          1 |  2,914,049      100.00      100.00
	------------+-----------------------------------
      Total |  2,914,049      100.00
	
	2973 hhid 
	*/
	
	drop one no 
	
	*----------1.5: Reshape file to use codes 
	
	reshape long consm expen quant, i(hhid) j(code) string 
	
	*----------1.6: Create COICOP codes 
	
	preserve 
	
	keep if strlen(code)==2
	save "${tmp}hsb_cons_div.dta", replace 
	restore 
	
	preserve 
	
	keep if strlen(code)==4
	save "${tmp}hsb_cons_group.dta", replace 
	restore 
	
	preserve 
	
	keep if strlen(code)==6
	save "${tmp}hsb_cons_class.dta", replace 
	restore 
	
	keep if strlen(code)==8
	
	gen cod_div         = substr(code,1,2)
	gen cod_group       = cod_div   + substr(code,4,1)
	gen cod_class       = cod_group + substr(code,6,1)
	gen cod_subclass    = cod_class + substr(code,8,1)
	gen coicop          = cod_subclass
	
	// 2973 hhid 
	
	save "${tmp}hsb_coicop.dta", replace 
	
	import excel using "${raw}HBS/2021 HBS/Data/Basic_HBS_2021/hh_basic_2021_HBS_BG.xlsx", clear firstrow
	rename *, lower 
	/*
	usespss "${raw}HBS/hh_basic_2018_HBS_BG.sav", clear
	rename *, lower */
	rename ha04 hhid 
	rename ha06 strata 
	rename ha07 psu 
	rename ha10 weight 
	rename hh099 netincome   // check netincome vs disp income 
	
	gen double he_total = he_a_00
	
	gen one=1	
	tab one [w=round(weight)]
	
	/*
	        one |      Freq.     Percent        Cum.
	------------+-----------------------------------
          1 |  2,914,049      100.00      100.00
	------------+-----------------------------------
      Total |  2,914,049      100.00
	
	2973 hhid 
	*/
	
	keep hhid netincome strata psu weight 
	
	save "${tmp}hsb_netinc.dta", replace 
	
}

import excel using "${proc}carbon_taxes_params.xlsx",  clear firstrow
keep coicop_group rate2 opt 
rename rate2 rate_carb
rename opt1  emiss_carb 
rename coicop_group cod_group
sort cod_group
save "${tmp}carb_rates.dta", replace 

*----------1.2: Tobacco consumption 

cap confirm file "${tmp}smoke1.dta"
if _rc {
	eurostatuse hlth_ehis_sk1i, clear geo( BG) keepdim() start($yy_eurostat) end($yy_eurostat)
	save "${tmp}smoke1.dta", replace 
}
else {
	use "${tmp}smoke1.dta", clear 	
}	

if c(version)==17 {
	table smoking_label quant_inc if smoking!="SM_CUR" & sex=="F", stat(mean hlth) nformat(%5.1fc)
	table smoking_label quant_inc if smoking!="SM_CUR" & sex=="M", stat(mean hlth) nformat(%5.1fc)
}

drop if inlist(age,"Y15-24","Y15-29","Y15-44","Y15-64","Y18-44","Y18-24","Y18-64","Y25-64","Y45-64")
drop if inlist(age,"Y_GE65","Y_GE18")

drop unit*  geo* // unit is percentage 

if c(version)==17 {
	table age_label quant_inc if smoking=="SM_DAY" & sex=="M" , stat(max hlth) nformat(%5.1fc)
	table age_label quant_inc if smoking=="SM_DAY" & sex=="F" , stat(max hlth) nformat(%5.1fc)
}

preserve 

keep if smoking == "SM_DAY" 
drop smoking*
drop quant_inc_label sex_label flag
rename hlth_ehis_sk1i2019 tobacco 
reshape wide tobacco, i(sex age) j(quant_inc) string
descr 
list 
save "${tmp}tobacco_day.dta", replace 

restore 


*----------1.4: Alcoholic consumption 

*eurostatuse hlth_ehis_al1i, clear geo( BG) keepdim() start(2019) end(2019)


*----------1.5: COICOP consumption 
cap confirm file "${tmp}coicop_total.dta" 
if _rc {
	eurostatuse nama_10_co3_p3, clear geo( BG) keepdim() start($yy_eurostat) end($yy_eurostat)
	save "${tmp}coicop_total.dta" , replace 
}	
else {
	use "${tmp}coicop_total.dta", clear 	
}	


keep if unit=="CP_MNAC"
drop geo*

/*
	-------------------------------------------------------------
	|  Maximum value
	---------------------------------------------+---------------
	coicop_label                                 |               
	Alcoholic beverages                        |         1595.7  -173.7
	Alcoholic beverages, tobacco and narcotics |         3642.9
	Narcotics                                  |          186.1
	Tobacco                                    |         2347.5  -339.8 
	Total                                      |         3642.9
	-------------------------------------------------------------
*/


list if coicop=="TOTAL"


** TOTAL SURVEY 16,295,039,396

/*
	+--------------------------------------------------------------------------------------------------------+
	|    unit                                           unit_label   coicop   coicop~l   na~32018   fl~32018 |
	|--------------------------------------------------------------------------------------------------------|
	61. | CP_MNAC   Current prices, million units of national currency    TOTAL      Total    69520.7            |
	+--------------------------------------------------------------------------------------------------------+
*/	
clear 

use "${tmp}coicop_total.dta", clear 	

keep if unit=="CP_MEUR"
drop geo*

list if coicop=="TOTAL"

/*
	+----------------------------------------------------------------------------------+
	|    unit                     unit_label   coicop   coicop~l   na~32018   fl~32018 |
	|----------------------------------------------------------------------------------|
	61. | CP_MEUR   Current prices, million euro    TOTAL      Total    35545.9            |
	+----------------------------------------------------------------------------------+
	. tabstat expen consm [w=weight], stat(sum) format(%15.0fc)
	(analytic weights assumed)
	
	Stats |           expen           consm
	---------+--------------------------------
	Sum |  31,869,838,051  31,439,305,109
	------------------------------------------
*/


** share of consumption in survey --->  0.4584 (if svy lev)
	**	0.89 if svy in euros 
** asumming survey in Euros 


/*
	-------------------------------------------------------------
	|  Maximum value
	---------------------------------------------+---------------
	coicop_label                                 |               
	Alcoholic beverages                        |          573.7 - 419.2  = 73.0%
	Alcoholic beverages, tobacco and narcotics |         1862.6
	Narcotics                                  |           88.6
	Tobacco                                    |         1200.3	-1,163  = 96.9%
	Total                                      |         1862.6
	-------------------------------------------------------------
*/


capture copy "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/codelist/ESTAT/COICOP/?compressed=false&format=TSV&lang=en" coicop.tsv, replace
insheet using "coicop.tsv", clear 
rename v1 coicop 
rename v2 coicop_label
sort coicop 
save "{tmp}coicopl.dta", replace 

// eurostatuse nama_10_co3_p3, clear geo( BG) keepdim() start($yy_eurostat) end($yy_eurostat)
//insheet using "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/nama_10_co3_p3/?format=SDMX-CSV&compressed=true", clear 
capture copy  "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1/data/nama_10_co3_p3/?format=SDMX-CSV&compressed=true" nama_10_co3_p3.tsv.gz, replace
	shell "C:\Program Files\7-Zip\7zG.exe" x -y nama_10_co3_p3.tsv.gz
	insheet using "nama_10_co3_p3.tsv", clear 


capture keep if inrange(time_period,$yy_eurostat,$yy_eurostat)
keep if geo=="BG"
keep if unit=="CP_MNAC"
drop geo

merge 1:1 coicop using "{tmp}coicopl.dta"
drop if _merge==2
gen eur_value = obs_value / 1.9558
list coicop_label *_value  if substr(coicop,1,4)=="CP02"


/*
     +-------------------------------------------------------------------+
     |                               coicop_label   obs_va~e   eur_value |
     |-------------------------------------------------------------------|
  4. | Alcoholic beverages, tobacco and narcotics     4024.1   2057.5212 |
  5. |                        Alcoholic beverages     1334.5   682.32948 |
  6. |                                    Tobacco     2544.5   1301.0021 |
  7. |                                  Narcotics      145.1    74.18959 |
     +-------------------------------------------------------------------+	
	
*/	

/*
	. list if coicop=="TOTAL"
	
	+----------------------------------------------------------------------------------+
	|    unit                     unit_label   coicop   coicop~l   na~32019   fl~32019 |
	|----------------------------------------------------------------------------------|
	61. | CP_MEUR   Current prices, million euro    TOTAL      Total    38217.7            |
	+----------------------------------------------------------------------------------+
	
*/




/*
	-------------------------------------------------------------
	|  Maximum value
	---------------------------------------------+---------------
	coicop_label                                 |               
	Alcoholic beverages                        |          573.7  - 173.7 = 0.3028
	Alcoholic beverages, tobacco and narcotics |         1862.6
	Narcotics                                  |           88.6
	Tobacco                                    |         1200.3  - 339.8 = 0.2831
	Total                                      |         1862.6
	-------------------------------------------------------------
*/




/*==================================================
	2:  Import rates 
==================================================*/


*----------2.1: Simulations specified in Master 



*----------2.2:

foreach sim of global simulations  {
	
	if "`sim'"=="0" {  // base scenario 
		import excel using "${proc}coicop.xlsx",  sheet("Sheet1") cellrange(A1:X297) clear firstrow
		rename *, lower 
		local div group class subclass 
		
		qui foreach x of local cod_des  {  // label codes 
			capture confirm file "${do}tmp/cod_`x'.do"
			if _rc {			
				preserve 
				keep cod_`x' `x' 	
				bysort  cod_`x': gen num=_n 	
				cap keep if num==1
				local tot=_N
				forval i=1(1)`tot' {
					local varcod  = cod_`x'[`i']
					local vardes  = `x'[`i']		
					label define cod_`x' `varcod' "`vardes'", add 
				}	
				label save cod_`x' using "${ado}cod_`x'.do" , replace 
				restore 
			}
		}
		
		qui foreach x of local cod_des {
			do "${ado}cod_`x'.do"
			label val cod_`x' cod_`x'
		}
		
		drop div group class subclass
		
		sort cod_subclass 
		
		tempvar durables exempt normal reduced 
		gen `durables' = iocode2 if segment =="durables"
		gen `exempt'   = iocode2 if segment =="exempt"
		gen `normal'   = iocode2 if segment =="normal"
		gen `reduced'  = iocode2 if segment =="reduced"
		
		levelsof(`normal'), local(g_normal) separate("-")
		global g_normal_vat0 `g_normal'
		
		foreach rate in exempt rateoil ratevat ratebev ratetob { 
			rename `rate' `rate'0 			
		}
		sort cod_subclass
		save "${tmp}tasas_itx.dta", replace 
		
	}
	
	if "`sim'"!="0"  {		 // simulation scenario 
		tempfile simtasas_`sim'		
		import excel using "${proc}coicop.xlsx",  sheet("sim`sim'") clear firstrow
		keep cod_subclass exempt* 
		sort cod_subclass 
		foreach tax in oil vat bev tob { 
			gen rate`tax'`sim' = ${`tax'_`sim'}
		}
		
		cap drop if cod_subclass==.		
		save `simrates_`sim'', replace 
	}
}

foreach sim of global simulations {
	if "`sim'"=="0" {
		use "${tmp}tasas_itx.dta", clear 
		cap drop _*
	}
	
	** Merge simulations 
	display "`sim'"
	if "`sim'"!="0" {
		merge m:1 cod_subclass using `simtasas_`sim''
		
		// if code is not in simulation excel, uses baseline tax rate 
		if "${exentogr_`sim'}"=="0" {
			replace exempt`sim'=exempt0 if _merge==1 
			foreach tax in oil vat bev tob { 
				replace rate`tax'`sim' = rate`tax'0
			}
		}
		
		// with this condition, all non-exempt become taxed  condición los que no figuran como exempt se vuelven gravados
		if "${exentogr_`sim'}"=="1" {
			replace ratevat`sim'   =${vat_`sim'} if _merge==1  & exempt0==0 
			replace exempt`sim'=1		         if _merge==1  & exempt0==0
		}	
		
		
		// verify non-taxed have rate equal to 0 
		replace ratevat`sim'   =tasa0 	  if exempt`sim'==.
		replace exempt`sim'=exempt0 	  if exempt`sim'==.
		
		replace ratevat`sim'=0		      if exempt`sim'==0		
		replace ratevat`sim'=${vat_`sim'} if ratevat`sim'==.  & exempt`sim'==1
		
		
		// uniform rates if unifor_`sim'==1 
		if "${unifor_`sim'}"=="1" replace ratevat`sim'=${vat_`sim'} if ratevat`sim'>0
		
		
		tempvar normal
		gen iocode2_`sim'=iocode2 
		replace iocode2_`sim'=io_code*2-(exempt`sim')  // change IO code 
		cap drop _*
		gen `normal'= iocode2_`sim' if exempt`sim'==1 & segment!="durables"
		levelsof(`normal'), local(g_normal) separate("-")
		global g_normal_itb`sim' `g_normal'	  // rescata los sectores gravados. 		
		
	}	
	
}

save "${tmp}itx_rates.dta", replace 


*----------2.3: Place of purchase not included 


*----------2.4: Urban - rural not relevant 


/*==================================================
	3: I-O table & indirect effects 
==================================================*/

local import_xl = 1


*----------3.1: Import IO Matrix 


import excel using "${xlmip_${io_version}}",  sheet("ctt") cellrange(A2:BL67) clear firstrow	

gen double A=0
cap label drop mipcat 
forval i=1(1)62 {
	local a1=real(substr(code2[`i'],5,2))
	local b1=descrip[`i']
	label define mipcat `a1' "`b1'", add // ad labels from each row of IO 
	replace A=`a1' if _n==`i'
}

drop descrip 
*destring A, replace
	*drop if _n==1
	
	rename A mipcat
	label val mipcat mipcat
	
	*destring P*, replace
	order mipcat prod* 
	drop code2 
	
	label data "BGR IO Matrix ${io_version}" 
	
	save "${tmp}bgr_io${io_version}.dta", replace 
	
    
*----------3.2: Create pseudo - IO 
    drop if mipcat==0
	mkmat prod01-prod62, matrix(p)  // IO converted to matrix 
// creating 2 fictional activities following VAT methodology 
		// for Fiji to have exempt - non exempt 
		/*
		mata:
		p0=st_matrix("p")    				// input matrix to mata 
		p1=rows(p0)							// technical coefficients estimation
		p2=p1-3
		ct=p0[1::p2,]:/p0[p1,]				// p0 row is total production 
	*/
	
	mata: 
	ct=st_matrix("p")
ct_2=ct:*0.5         				// each fictional sector has 50% of original sector 
	ct_4=J(rows(ct_2)*2,cols(ct_2),.)   // rows of ct_4 having 50% of sector ct_4 (rows 1,2) =  ct_2 (row 1) = 0.5*p
	
	mata:
	for (i=1; i<=rows(ct_4); i++) {    // rearranging rows  ct_4 (rows 1,2) =  ct_2 (row 1)
		j=round(i/2)
		ct_4[i,]=ct_2[j, ]   
	}
	
	ct_8 = (ct_4 , ct_4)  				// filling a matrix with columns x 2
	
	for (i=1; i<=cols(ct_8); i++) {  	// rearranging columns  ct_8 (col 1,2) =  ct_2 (col 1)
		j=round(i/2)
		ct_8[, i]=ct_4[, j]  
	}
	
	st_matrix("A",ct_8)  				// export from mata to stata 

	end
	
	/*
		We have created an augmented IO matrix where we have duplicated the number of 
		rows and columns. Now we have two columns/rows for each sector, one taxed 
		and the other one exempted.
		** BGR has not a few of exempted sectors. 
		*Each cell refers to the relative use of each input to produce each 
		output. For instance, the cell water supply (row) and crops 
		(column) contains the share of water used to produce crops over 
		total production of crops. However, since we have an augmented 
		matrix, the total production of crops (total of the column) has 
		been split into 2 and assigned to the two columns that refer to 
		crops production (taxed, and exempted). The same applies to water 
		supply. This row has been split into two (water taxed and 
		exempted). Given that the sector "crops" has the same technology 
		regardless of whether it pays taxes or not, we will observe the 
		same share in the 4 cells: crops taxed-water taxed, crops 
		exempted-water taxed, crops taxed-water exempted, and crops 
		exempted-water exempted.	
		
	*/
	
	** 3.2.1 Exportin coefficients matrix to Excel 
	
	putexcel set  "${ctec}" , replace 
	
	local xl_cols = ""
	
	di "`lista_'"
	
local lista_ = substr(c(alpha),3,50)   // b - z 
	local lista1 = c(alpha)
	local lista2 = substr(c(alpha),1,44)   // a -> v
	di "`lista2'"
	
	foreach x of local lista1 {
		local listaa = "`listaa' a`x'"
		local listab = "`listab' b`x'"
		local listac = "`listac' c`x'"
	}
	foreach x of local lista2 {
		local listad = "`listad' d`x'"	
	}
	
	
	local alpha = "`lista_'" + "`listaa'" + "`listab'" + "`listac'" + "`listad'"	
	
	*local alpha=c(ALPHA)
	
	forval i=1(1)125 {
		local co : word `i' of `alpha'
		local xl_cols = "`xl_cols' `co'"
	}
	local xl_cols = strtrim("`xl_cols'")
	
	tokenize `xl_cols'
	
	di "`27'"
	
di strtrim("`xl_cols'")
	
	putexcel b2=matrix(A)
local nrows=rowsof(A)
	local co_1 = ""
	local ro_1 = ""
	forval i=1(1)`nrows' {
		local mip_row=round(`i'/2)
		local name_sector : label mipcat `mip_row' 
		local no_sector= 2-mod(`i',2)
		local name_sector = "`i'_`name_sector' `no_sector'"
		local xl_row = `i'+1 
		local co_1   `co_1'  A`xl_row'= "`name_sector'"
		local ro_1   `ro_1' ``i''1    = "`name_sector'"			
	}	
	
	putexcel `co_1'  , bold 
	putexcel `ro_1'  , bold 
	
	putexcel clear 
	
	*----------3.3: Reading matrix from IO Table 

	/* Product description in IO Matrix 
		
	*/	
	
	* Matrix with sectors splitted in 2 
	drop if mipcat==0
	local Nsectors=rowsof(A)
	di `Nsectors'
	
	
	*----------3.4: Introduce changes 
	
/*
		Methodology- Indirect Effects for VAT Exemptions
		
		*Indirect Effects: Will be the "embedded/implicit VAT" for EXEMPT final 
		goods/services bought by households. Exempt items have "embedded VAT" because 
		sellers of these goods cannot claim VAT credit for their inputs.
		
		*Methodology: We calculate Indirect Effects using the Cost-Push Model in Stata
		
		*Data Input: Matrix of Technical Coefficients of the "Augmented IO Table". 
		Augmented IO: Duplicate all sectors (columns and rows); divide each technical 
		coefficient by 2. [Why we need an Augmented IO for Exemptions? Because some 
		sectors might have a combination of exempt and non-exempt products]
		
		*Main Assumptions:
		(i) Fixed (Output) Prices- Assumed for non-exempt sectors (e.g. these sectors 
		don't have indirect effects from inputs, because sellers can claim VAT 
		credit); 
		(ii) "Turned Off" (Input) Sectors in "dp_sim (delta price simulation)": 
		Exempt sectors will be "turned off" because they do not carry 
		statutory/explicit VAT
		(iii) Size of Delta Price Simulation: 0.01667 (t/1+t; t= VAT rate as of 2019, 
		e.g. 20%). This is not a price shock but the upper bound of the VAT burden 
		per sector. 
	*/
	
//=============================
	// UPDATE RATES
	//=============================
	
	scalar vat_rate  = (0.20 /1.20)   // VAT tax rate
	scalar oil_rate  = 0.4474955 // the highest for petrol 	
	scalar gas_rate  = 0.042364/2  // for business is the half of for households 
	
	** Taxed sectors 
	**11([0-9])  vs 12\1
	
local fix_price_vat  ///
	1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26     ///
		27 28 29 30 31 32 34 33 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 ///
		50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 ///
		73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 ///	
	96 97 98 99  100 101 102 103 104 105 106 107 108 109 110 111 112 113 ///
114 115 116 117 118 119 120 121 122 123 124 
	
	local fix_price_oil 19 20
	
	local fix_price_gas 47 48
	
	local indeff vat oil gas // indirect effects for indirect taxes 
	
	
	*----------3.5: Compute indirect price effects, based on the Cost-Push Model
	
	foreach sim of local indeff {	
		
		matrix dp_sim`sim' = J(1,`Nsectors',0)
		foreach x of local fix_price_`sim' {
			mat dp_sim`sim'[1,`x']=`sim'_rate
		}
		
		matrix gamma_`sim'=J(`Nsectors',`Nsectors',0)  // initializes fixed price matrix 
		// Specify the row/column numbers of the commodities whose price will be fixed                                                           
		foreach row of numlist `fix_price_`sim'' {                       
			matrix gamma_`sim'[`row',`row']=1                  
		}
		// Calculating cost-push model pass-through for prices of all sectors
		matrix alpha_`sim' = I(`Nsectors') - gamma_`sim'                                          
		// Here we have the Inverse Leontief Coefficients               
		matrix V_`sim'     = inv(I(`Nsectors') - alpha_`sim' * A)   
		*
		matrix deltaptilda_`sim' = dp_sim`sim' * A * V_`sim'                                   
		matrix deltap_`sim'      =(dp_sim`sim' *gamma_`sim') + ///
		(deltaptilda_`sim'+dp_sim`sim') * alpha_`sim'   
		
		// Output simulated price shock and price pass-through on all sectors 
		dis "simulated price decreases "                         
		matrix list dp_sim`sim'                                               
		dis "fixed price sectors: gamma"                                  
		matrix list gamma_`sim'                                                 
		dis "Indirect effect price increase"                              
		matrix list deltaptilda_`sim'                                           
		dis "total price decrease"                                        
		matrix list deltap_`sim'	
		
		// This loop generates price variables for price changes by sector         
		foreach sector of numlist 1/`Nsectors' {                          				
			gen double pt`sim'_`sector'=deltap_`sim'[1,`sector']  // ptot 
			label var  pt`sim'_`sector' "total price inc. `sim' tax for sector `sector'"			
			gen double pi`sim'_`sector'=deltaptilda_`sim'[1,`sector'] // pind 
			label var  pi`sim'_`sector' "indirect tprice inc. `sim' tax for sector `sector'"			
			gen double pd`sim'_`sector'= pt`sim'_`sector'- pi`sim'_`sector'
			label var  pd`sim'_`sector' "direct tprice inc. `sim' tax for sector `sector'"		
		}	
	}

	
	rename mipcat sector 
	keep sector pt* pi* pd* 
	ren sector s 
	/* descr ptvat_ pivat_ ptoil_ pioil_ ptgas_ pigas_ , varlist
		local vars = r(varlist)
	di "`vars'" */
	reshape long  ptvat_ pivat_ pdvat_ ptoil_ pioil_ pdoil_ ptgas_ pigas_ pdgas_, i(s) j(sector)
drop s 
	duplicates drop 
	sort sector
	rename sector sector2
	
	foreach ss of local indeff {
		gen double pt`ss'_ex=pt`ss'_[_n+1]	
		label var pt`ss'_   "total effects vat esc `ss' "
		label var pt`ss'_ex "total effect evasion esc `ss'"  // same as embedded rate for exempted 
	}
	
	sort sector2
	compress	
	
	
	/* 
		foreach x of varlist pt* pd* pi* {
		replace `x'=round(`x'*100)/100
		}	
	*/
	
	*Some NOTES on the Results
	sum pi*  //OK: Average Indirect effect is 9.3% 
	
	/*
	    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
      pivat_ |        124    .0933649     .027579    .015755   .1618335
      pioil_ |        124    .0230625    .0161812   .0021554   .0828983
      pigas_ |        124    .0019039    .0014072   .0001767   .0070336
	*/
	
	summ p*vat*
	
	/*
	    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
      ptvat_ |        124    .1666667           0   .1666667   .1666667
      pivat_ |        124    .0933649     .027579    .015755   .1618335
      pdvat_ |        124    .0733017     .027579   .0048332   .1509117
    ptvat_ex |        123    .1666667           0   .1666667   .1666667
	*/
	
	save "${tmp}ieffectsVAT.dta", replace 
	
	
	
	*----------3.5: Merge indirect effects & rates 
	
	use "${tmp}tasas_itx.dta", clear
	cap drop _*
	cap confirm variable sector2 
	if _rc {
	rename iocode2 sector2 
	}
	order sector2 

	
merge m:1 sector2 using "${tmp}ieffectsVAT.dta"
	
	tabstat pt*, by(sector2)
	
	list  sector2 if _merge==2
	drop if _merge==2
	drop _merge 
	
	sort cod_subclass
	save "${tmp}tasas_itx.dta", replace 
	
	/*==================================================
		4: VAT & excises estimation 
	==================================================*/
	
	cap confirm file "${do}ados/labcoicop.do" 

	if _rc {
		import excel using "${proc}coicop_labels", clear firstrow
		destring coicop, replace 
		rename coicop ncoicop 
		qui: levelsof ncoicop  , local(values) // Se tomas los valores numericos que puede tener la variable
		foreach val of local values{
			qui: levelsof subclass if ncoicop == `val', local(detalle) // Se toma el significado de cada valor numerico
			foreach str of local detalle{
				label define lcoicop `val' "`str'", add // Se crea la definicion del label en base a los parametros anteriores
			}
		}
		
		label list 
		
		label save using "${do}ados/labcoicop.do" 
	}
	
	use "${tmp}hsb_coicop.dta", clear 
	merge m:1 cod_subclass using "${tmp}tasas_itx.dta"	, keep(master match)
	gen ncoicop=coicop 
destring ncoicop, replace 
	run "${do}ados/labcoicop.do" 
label val ncoicop lcoicop
	
	
	
	
	*----------4.1: Oil excises 

gen double itx_oild_hh = expen*pdoil_*(rateoil0/$std_rateoil) 
gen double itx_oili_hh = expen*pioil_

if c(version)==17 table ncoicop if rateoil0!=0 & rateoil0!=. [w=round(weight)], stat(sum expen)

/*
---------------------------------------------------------------
                                               |          Total
-----------------------------------------------+---------------
ncoicop                                        |               
  Natural gas and town gas                     |    100,664,275
  Liquefied hydrocarbons-butane- propane-etc   |     38,947,728
  Liquid fuels                                 |        329,682
  Coal                                         |     73,640,619
  Diesel                                       |    592,171,191
  Petrol                                       |  1,072,412,735
  Other fuels for personal transport equipment |    184,749,279
  Total                                        |  2,062,915,507
---------------------------------------------------------------
*/	


*----------4.2:  Beverage excises 

tabstat expen [w=weight] if inlist(cod_class,"0211","0213"), by(ncoicop) stat(sum) format(%15.0fc)
/*
	ncoicop |             Sum
	-----------------+----------------
	Spirits and liqu |     129,810,182
	Alcoholic soft d |         983,448
	Lager beer |     207,248,716
	Other alcoholic  |       1,369,493
	Low and non-alco |         287,369
	Beer-based drink |          67,639
	-----------------+----------------
	Total |     339,766,847
	----------------------------------
*/

summ expen [w=weight] if inlist(cod_class,"0211","0213"), meanonly
di %18.0fc r(sum)/EXR
/*
	173,722,695
*/	

gen double itx_beve_hh = expen*(ratebev0) 


*----------4.3:  Tobacco Excises 

tabstat expen [w=weight] if inlist(cod_class,"0220"), by(ncoicop) stat(sum) format(%15.0fc)

/*
	Summary for variables: expen
	Group variable: ncoicop 
	
	ncoicop |             Sum
	-----------------+----------------
	Cigarettes |   1,135,951,527
	Cigars |          81,781
	Other tobacco pr |      27,248,646
	-----------------+----------------
	Total |   1,163,281,954
	----------------------------------
*/
summ expen [w=weight] if inlist(cod_class,"0220"), meanonly
di %18.0fc r(sum)

/*
	594,785,742
	
	
*/


gen double itx_toba_hh = expen*(ratetob0)

summ itx_toba_hh [w=weight] , meanonly
di %18.0fc r(sum)

recode itx_*_hh (.=0)

/*
	.  di %18.0fc r(sum)
	795,990,799
	
*/

*----------4.4: VAT

if c(version)==17 table ratevat0 [w=round(weight)], stat(sum expen)

/*
-------------------------
        |           Total
--------+----------------
ratevat |                
  9     |     182,587,506
  14.5  |   1,427,963,285
  20    |  34,630,907,816
  Total |  36,241,458,607
-------------------------

*/



** direct 
gen double itx_vatx_hh = (expen - itx_beve_hh-itx_oild_hh-itx_toba_hh )* ///
ptvat_*(ratevat0/$std_ratevat) if exempt0 ==0   
** indirect 						
replace itx_vatx_hh    = (expen)*pivat_ if exempt0 ==1   

*----------4.5: Carbon Taxes (not included in analysis)

cap drop _merge 

merge m:1 cod_group using "${tmp}carb_rates.dta"
drop _m

gen double itx_carb_hh = (expen*rate_carb/EXR*emiss_carb)


gen coicop_c = "HE_"+substr(cod_group,1,2)+"_"+substr(cod_group,3,1)
tabstat expen [w=weight], by(coicop_c) stat(sum) format(%18.0fc)

save "${tmp}hbs_proc1.dta", replace 

tempfile hhd1 
collapse (sum) expen consm itx* (mean) psu weight strata, by(hhid)

sort hhid 
save `hhd1', replace 

import excel using "${raw}HBS/2021 HBS/Data/Basic_HBS_2021/hm_basic_2021_HBS_BG.xlsx", clear firstrow
/*usespss "${raw}HBS/hm_basic_2018_HBS_BG.sav", clear */

rename *, lower 

rename ma04 hhid 
rename ma05 id 
rename mb02 gender // 1 male 2 female 
rename mb03 age 
rename mb04 marital_status // 1  Never married 2  Married 3  Widowed 4  Divorced 9  Not specified
rename mb042 partners // Partners living in the same household
rename mb05 relation 

merge m:1 hhid using "`hhd1'"
cap drop _*
merge m:1 hhid using "${tmp}hsb_netinc.dta"



drop if relation=="6"

bysort hhid: gen hsize = _N 

gen double centvar = netincome 

gen double centvar_pc = expen / hsize 

quantiles  centvar_pc  [w=weight], n(100) k(hhid) gen(centyd)
quantiles  centvar_pc  [w=weight], n(10) k(hhid)  gen(dectyd)

foreach x of varlist itx_*_hh {
	gen double sh_`x' = `x'/  centvar    //expen  
}


lowess sh_itx_vatx_hh centyd  , adjust gen(rati_vatx) nograph 
lowess sh_itx_oild_hh centyd  , adjust gen(rati_oild) nograph
lowess sh_itx_oili_hh centyd  , adjust gen(rati_oili) nograph
lowess sh_itx_beve_hh centyd  , adjust gen(rati_beve) nograph
lowess sh_itx_toba_hh centyd  , adjust gen(rati_toba) nograph

/*
preserve 

collapse (mean) rati* , by(centyd)
twoway (line rati_vatx centyd) , title(VAT) ///
xtitle("Share of Net Income") ytitle("Centiles of Consumption")

*twoway (line rati_oild centyd) 

restore 
*/

tempfile carb 
preserve 
replace weight = round(weight)
collapse (mean) sh_itx_carb_hh  [fw=weight], by(centyd)
rename sh_itx_carb_hh rati_carb 
save `carb'
restore 
drop _merge 
merge m:1 centyd using `carb'




save "${tmp}hbs_proc2.dta", replace 

collapse (median) rati* [w=weight], by(centyd)

save "${tmp}itx_centile.dta", replace 

*twoway (line rati_vatx centyd) (line rati_toba centyd)
*twoway (line rati_oild centyd) (line rati_oili centyd)
*twoway (line rati_beve centyd) (line rati_toba centyd)

/*==================================================
5:  Impute results in EU_SILC survey 
==================================================*/


*----------5.1: open BGR disposable income 
use "${tmp}BGR20_dis_inc.dta" ,clear 

*----------5.2: generate centiles of disp income 

xtile centyd = yd_pc [w=weight], nq(100)

*----------5.3: merge shares of indirect taxes 

merge  m:1 centyd using "${tmp}itx_centile.dta"

*----------5.4: estimate indirect taxes 
cap drop yd_hh 
bysort hhid: egen double yd_hh=sum(yd_pc)

foreach x of varlist rati* {
local itx = subinstr("`x'","rati_","",.)
local itx = "itx_`itx'_hh"
gen double 	`itx' = yd_hh*`x'	
}

label var itx_vatx_hh "Indirect taxes: VAT (household)"
label var itx_beve_hh "Indirect taxes: Excise Alcoholic Beverages (household)"
label var itx_toba_hh "Indirect taxes: Excise Tobacco (household)"
label var itx_oild_hh "Indirect taxes: Oil derivates direct effects (household)"
label var itx_oili_hh "Indirect taxes: Oil derivates indirect effects (household)"
label var itx_carb_hh "Indirect taxes: Carbon (household)"

percap itx*hh 

foreach var of varlist itx_*_pc {
local rhh = subinstr("`var'","_pc","_rh",1)
gen int `rhh' = (`var'>0 & memb_no==1)
}


lab_torh itx_*_rh  

*----------5.5: check if there are negatives 

tempvar tot_itx tmp_yc 

egen double `tot_itx' = rsum(itx_vatx_pc  itx_oild_pc  itx_oili_pc  itx_beve_pc  itx_toba_pc)

replace `tot_itx' = `tot_itx'*-1

egen `tmp_yc' = rsum(yd_pc `tot_itx')

summ `tmp_yc'

list hhid yd_* `tmp_yc' rati* if `tmp_yc'<0

recode itx*pc (.=0)

/*==================================================
6:  Save file - part of consumable income 
==================================================*/

cap drop _*
save "${tmp}BGR20_cons1_inc.dta", replace 


log close
exit
/* End of do-file */

><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><

Notes:
1. 
2.
3.


Version Control:

Rates changes 2020

After a meeting between representatives of the restaurant industry and 
government leaders, in May 2020, the Bulgarian government decided to 
decrease the value added tax (VAT) from 20% to 9% for dining and catering 
services, under the requirement that the minimum social іnѕurаnсе threshold 
fоr аll еmрlоуееѕ іn thе ѕесtоrѕ 'Ноѕріtаlіtу', 'Rеѕtаurаntѕ', 'Trаvеl 
аgеnсіеѕ' аnd аll оthеr асtіvіtіеѕ rеlаtеd tо trаvеl аnd rеѕеrvаtіоnѕ is 
rаіѕеd frоm ВGN 610 (€300) tо ВGN 800 (€400).

After debates in the parliament, the parliament agreed to decrease VAT also for 
baby foods and nappies, books and textbooks to 9%. Added tax for food and 
pharmaceuticals remains 20%.

https://static.eurofound.europa.eu/covid19db/cases/BG-2020-27_1104.html

catering & dining 14.5 = 20% first six months and 9% for the rest of the year 
books, 