/*==================================================
	7_BGR_Education.do
	project:       CEQ Bulgaria 
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR_net_inc.dta
	
	Output files:
	- BGR_dis_inc.dta 
	----------------------------------------------------
	Creation Date:       17 Dec 2022
	Modification Date:   22 Feb 2022
	Do-file version:    5
	Track main changes: 
	- bugs 
	
	References:          
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2020),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2017-2020” 
	- MISSOC
	european commission (2021), "your social security rights in bulgaria", luxembourg: 
	publications office of the european union, 2021
	- Do files provided by Lucian Bucur 
	
	Output:             
	Questions & comments 
	
	
================================================== */


/*==================================================
	1: Eurostat files for enrolment 
==================================================*/
set seed 63710
** ssc install eurostatuse  // must be installed 
** G7ZIP must be installed 

** https://ec.europa.eu/eurostat/web/education-and-training/data/database?p_p_id=NavTreeportletprod_WAR_NavTreeportletprod_INSTANCE_LUWsdX8ute5m&p_p_lifecycle=0&p_p_state=normal&p_p_mode=view

cd "${tmp}"

**************************************************************************
// all levels 

global edu_year = 2020

cap confirm file "${tmp}BG20_enrolment${edu_year}.dta"

if _rc {
	eurostatuse educ_uoe_enra01, clear geo( BG) keepdim() start(${edu_year}) end(${edu_year})
	
	if c(version)==17 table () sector, stat(max educ_uoe_enra01${edu_year})
	
	/*
		--------------------------------------------------------------------------
		|                            Sector                         
		|   PRIV   PRIV_DEP   PRIV_IND      PUBL   TOT_SEC     Total
		--------------+-----------------------------------------------------------
		Maximum value |  62888          .      62888   1124045   1186933   1186933
		--------------------------------------------------------------------------
	*/
	
	drop if isced11=="ED02-8"
	
	keep if inlist(sector,"PRIV","PUBL","TOT_SEC") // no private dependent
	
	if c(version)==17 {
		table (worktime ) sector if sex=="T" , stat(max educ_uoe_enra01${edu_year})
	}
	
	/*
		-------------------------------------------------
		|                Sector             
		|   PRIV     PUBL   TOT_SEC    Total
		-------------+-----------------------------------
		Working time |                                   
		FT         |  10572   252213    256496   256496
		PT         |  10351    30288     40639    40639
		TOTAL      |  20923   267938    281563   281563
		TOT_FTE    |  15023   258432    265428   265428
		Total      |  20923   267938    281563   281563
		-------------------------------------------------
		
	*/
	
	keep if worktime=="TOTAL" // not broke down by time 
	drop if sector=="TOT_SEC" // only keep public and private 
	drop if sex=="T" //only keep male and female 
	drop if isced11=="ED5"
	
	levelsof isced11
	local rlev = r(levels)
	foreach x of local rlev {
		list isced11 isced11_label if isced11=="`x'" & sex=="F" & sector=="PUBL", clean noheader noobs
		if c(version)==17 table sex sector if isced11=="`x'", stat(sum educ_uoe_enra01${edu_year}) 
		if c(version)==17 table sector if isced11=="`x'", stat(percent educ_uoe_enra01${edu_year})
	}
	
	/*
		
		------------------------------------
        |            Sector         
        |   PRIV      PUBL     Total
		--------+---------------------------
		Sex     |                           
		F     |  2,404   102,907   105,311
		M     |  2,578   109,978   112,556
		Total |  4,982   212,885   217,867  -- 212.788
		------------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     2.29   VS 2.11 IN 2018
		PUBL  |    97.71
		Total |   100.00
		------------------
	*/
	
	
	/*
        ED1   Primary education  
		
		------------------------------------
        |            Sector         
        |   PRIV      PUBL     Total
		--------+---------------------------
		Sex     |                           
		F     |  2,259   118,225   120,484
		M     |  2,391   125,479   127,870
		Total |  4,650   243,704   248,354   -- 243.358
		------------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     1.87   VS 1.67 IN 2018
		PUBL  |    98.13
		Total |   100.00
		------------------
		
		
	*/
	
	/*
        ED2   Lower secondary education  
		
		------------------------------------
        |            Sector         
        |   PRIV      PUBL     Total
		--------+---------------------------
		Sex     |                           
		F     |  4,843    91,275    96,118
		M     |  3,443    98,953   102,396
		Total |  8,286   190,228   198,514  -- 189.651  -- 190,236 public 
		------------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     4.17   VS 5.57 in 2018
		PUBL  |    95.83
		Total |   100.00
		------------------
	*/
	
	/*
        ED3   Upper secondary education  
		
		------------------------------------
        |            Sector         
        |   PRIV      PUBL     Total
		--------+---------------------------
		Sex     |                           
		F     |  5,083   125,317   130,400
		M     |  4,211   139,413   143,624
		Total |  9,294   264,730   274,024 -- 264,693  -- 264,735 public 
		------------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     3.39  vs 4.84 in 2018
		PUBL  |    96.61
		Total |   100.00
		------------------
		
	*/
	
	/*
        ED4   Post-secondary non-tertiary education  
		
		------------------------------
        |         Sector      
        |  PRIV   PUBL   Total
		--------+---------------------
		Sex     |                     
		F     |   268     56     324
		M     |   296    141     437
		Total |   564    197     761
		------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |    74.11  vs 77.93 in 2018
		PUBL  |    25.89
		Total |   100.00
		------------------
		
		
	*/
	
	/*
        ED6   Bachelor's or equivalent level  
		
		-------------------------------------
        |            Sector          
        |    PRIV      PUBL     Total
		--------+----------------------------
		Sex     |                            
		F     |  11,146    65,513    76,659
		M     |  10,060    61,225    71,285
		Total |  21,206   126,738   147,944
		-------------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |    14.33  vs 13.98 in 2018
		PUBL  |    85.67
		Total |   100.00
		------------------
        ED7   Master's or equivalent level  
		
		----------------------------------
        |           Sector        
        |   PRIV     PUBL    Total
		--------+-------------------------
		Sex     |                         
		F     |  4,320   38,010   42,330
		M     |  2,734   27,160   29,894
		Total |  7,054   65,170   72,224
		----------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     9.77  vs 10.09 in 2018
		PUBL  |    90.23
		Total |   100.00
		------------------
        ED8   Doctoral or equivalent level  
		
		-------------------------------
        |         Sector       
        |  PRIV    PUBL   Total
		--------+----------------------
		Sex     |                      
		F     |   129   3,255   3,384
		M     |   135   2,921   3,056
		Total |   264   6,176   6,440
		-------------------------------
		
		------------------
        |  Percent
		--------+---------
		Sector  |         
		PRIV  |     4.10   vs 3.94 in 2018
		PUBL  |    95.90
		Total |   100.00
		------------------
		
			admin tertiary  198,087
			tertiary survey 197,930
		
	*/
	
	gen gender = (sex=="F")
	label define gender 0 "Male" 1 "Female"
	label val gender gender 
	
	gen type_school = (sector=="PUBL")
	label define type_school 0 "Private" 1 "Public"
	label val type_school type_school
	
	drop unit* worktime* geo* 
	drop sector* sex* 
	drop flag*
	
	rename educ_uoe_enra01* enrol_*
	
	save "${tmp}BG20_enrolment${edu_year}.dta", replace 
	
	}
	
	
	/*==================================================
		2: Eurostat files for benefits 
	==================================================*/
	
	********************************************************************************
		* Annual government finance statistics (gov_10a) 	
		* Government revenue, expenditure and main aggregates (gov_10a_main) 	
	* General government expenditure by function (COFOG) (gov_10a_exp) 	
	cap confirm file "${tmp}BG20_cofog_${edu_year}.dta"
	
	if _rc {
		
		eurostatuse gov_10a_exp, clear geo( BG) keepdim() start(${edu_year}) end(${edu_year})
		
		drop if regexm(cofog99,"GF0[1-5]0[1-9]") 
		drop if regexm(na_item,"D[4-9]_S131[1-4]")
		drop if na_item=="D92" 
		drop if inlist(na_item, "P2_D29_D5_D8", "P31", "P32", "P51G", "D62_D632")
		keep if unit=="MIO_EUR"
		sort sector cofog99 na_item 
		keep if sector=="S13"  // General Goverment 
		
		keep if inlist(na_item,"TE","P5") // Total General & Gross Capital Formation 
		
		drop unit* sector* geo* 
		drop fla*
		recode gov* (.=0)
		drop na_item_label
		
		rename gov_10a_exp* exp_*
		
		list cofog99* exp*${edu_year} if regexm(cofog99,"GF09") & na_item=="TE"
		
		list cofog99* exp*${edu_year} if regexm(cofog99,"GF07") & na_item=="TE"
		
		reshape wide exp_${edu_year} , i(cofog99) j(na_item) string
		
		gen double exp_${edu_year}_curr = exp_${edu_year}TE - exp_${edu_year}P5
		
		
		order cofog* exp_${edu_year}_c* exp_${edu_year}P5 
		format exp* %13.0fc
		list 
		
		save "${tmp}BG20_cofog_${edu_year}.dta", replace 
	}

/*==================================================
	2: Estimate per capita benefits 
==================================================*/

use "${tmp}BG20_cofog_${edu_year}.dta", clear 

keep  if regexm(cofog99,"GF09")

keep  if regexm(cofog99,"GF090[1-5]")  // only school levels

gen double exp${edu_year}c = exp_${edu_year}_curr*1000000

drop if exp${edu_year}c ==0

mkmat exp${edu_year}c 

use "${tmp}BG20_enrolment${edu_year}.dta", clear 

mat define enr${edu_year}c  = J(4,1,.)
mat define enr${edu_year}p  = J(4,1,.)
local restric ""
local restricc ""
local restrip "& type_school==1"
local restripp "if type_school==1"

drop if isced11=="ED0-8"

foreach ss in c p {
	summ enrol if regexm(isced11,"ED[0-1]") `restri`ss'', meanonly 
	mat enr${edu_year}`ss'[1,1] = r(sum)
	summ enrol if regexm(isced11,"ED[2-4]") `restri`ss'', meanonly 
	mat enr${edu_year}`ss'[2,1] = r(sum)
	summ enrol if regexm(isced11,"ED[6-8]") `restri`ss'', meanonly 
	mat enr${edu_year}`ss'[3,1] = r(sum)
	summ enrol  `restri`ss'`ss'', meanonly 
	mat enr${edu_year}`ss'[4,1] = r(sum)
}

mata: st_matrix("pc${edu_year}p", st_matrix("exp${edu_year}c"):/st_matrix("enr${edu_year}p"))

tabstat enrol_${edu_year} if gender==1 & type_school==1, by(isced11) save
tabstatmat edu1 
tabstat enrol_${edu_year} if gender==0 & type_school==1, by(isced11) save
tabstatmat edu2 
tabstat enrol_${edu_year} if gender==1 & type_school==0, by(isced11) save
tabstatmat edu3 
tabstat enrol_${edu_year} if gender==0 & type_school==0, by(isced11) save
tabstatmat edu4 

mat edu_t = (edu1, edu2, edu3, edu4)
mat colnames edu_t = fem_pub male_pub  fem_priv male_priv

putexcel set "${tmp}espross.xlsx", modify sheet("${edu_year}")

putexcel C68=matrix(edu_t) i68=matrix(exp${edu_year}c) i73=matrix(enr${edu_year}p) ///
i78 = matrix(pc${edu_year}p)

putexcel clear 		



/*==================================================
3: Enrolment in EU-SILC 
==================================================*/
use "${tmp}BGR20_cons2_inc.dta", clear 
cap drop _*

** use rl010 education at pre-school 
	** use rl020 education at compulsory school 
	** check education benefits for public education dtr_edu
** only for over 15 years asumming overage 

// pre-school 

destring rl010, replace 
destring rl020, replace 
gen level_school = 1 if rl010>=25 & rl010<. & age>=3

tab level_school [w=round(weight)]
/*
	level_schoo |
	l |      Freq.     Percent        Cum.
	------------+-----------------------------------
	1 |    219,209      100.00      100.00
	------------+-----------------------------------
	Total |    219,209      100.00
*/


** enrolment using admin accounts 
di %18.0fc edu_t[1,1]+edu_t[1,2]+edu_t[1,3]+edu_t[1,4]
* 218,767

replace level_school=2 if rl020>20  & rl020 <. & inrange(age,6,10) 
tab level_school [w=round(weight)]
/*
	level_schoo |
	l |      Freq.     Percent        Cum.
	------------+-----------------------------------
	1 |    219,209       43.06       43.06
	2 |    289,897       56.94      100.00
	------------+-----------------------------------
	Total |    509,106      100.00
*/

cap drop one 
cap drop rand
gen one=1 
summ one [w=round(weight)] if level_school==2 
local tot_sprim = r(sum)

local tot_prim = edu_t[2,1]+edu_t[2,2]+edu_t[2,3]+edu_t[2,4]
di %12.0fc `tot_prim'

local dif = `tot_prim' - `tot_sprim'
di %12.0fc `dif'
*26,138

* 256,867
** Random assignment of students: no info for 13 and 14 years 
sort hhin 
gen rand = runiform()

gsort rl020 -level_school rand 

by rl020: gen spop = sum(weight) if rl020==20 & inrange(age,6,10) & level_school==.
sort spop 
replace level_school=2 if spop < `dif' & rl020==20 & inrange(age,6,10) & level_school==.
tab level_school [w=round(weight)]
drop spop 

/*
	level_schoo |
	l |      Freq.     Percent        Cum.
	------------+-----------------------------------
	1 |    219,209       46.07       46.07
	2 |    256,581       53.93      100.00
	------------+-----------------------------------
	Total |    475,790      100.00
	
*/

replace level_school=3 if rl020>20  & rl020 <. & inrange(age,11,12) 
replace level_school=3 if pe021==20
tab level_school [w=round(weight)]

summ one [w=round(weight)] if level_school==3 
local tot_slose = r(sum)

local tot_lose = edu_t[3,1]+edu_t[3,2]+edu_t[3,3]+edu_t[3,4]
di %12.0fc `tot_lose'
* 199,394

local dif = `tot_lose' - `tot_slose'
di %12.0fc `dif'
*104.477

gsort -level_school rand age 

gen spop = sum(weight) if inrange(age,13,14) & level_school==.
sort spop 
replace level_school=3 if spop < `dif' & inrange(age,13,14) & level_school==.
tab level_school [w=round(weight)]
drop spop 

/*
	l |      Freq.     Percent        Cum.
	------------+-----------------------------------
	1 |    219,209       32.50       32.50
	2 |    256,581       38.04       70.53
	3 |    198,801       29.47      100.00
	------------+-----------------------------------
	Total |    674,591      100.00
	
*/


replace level_school=. if level_school==4
replace level_school=4 if inlist(pe021, 30, 34, 35)
replace level_school=4 if pe010==1 & inrange(age,15,18) & level_school==.
replace level_school=4 if level_school==. & inrange(age,15,18) & pl087>0 & pl087<.
replace level_school=4 if level_school==. & inrange(age,15,18) & px050==7

tab level_school [w=round(weight)]
local tot_upse = edu_t[4,1]+edu_t[4,2]+edu_t[4,3]+edu_t[4,4]
di %12.0fc `tot_upse'
* 281,563
summ one if level_school ==4 [w=weight], meanonly
local tot_upsc = r(sum)

local dif = `tot_upse' - `tot_upsc' 
di %12.0fc `dif'
*77484

gsort -level_school rand age 
gen spop = sum(weight) if inrange(age,15,18) & level_school==. & px050==.

replace level_school=4 if spop < `dif' & inrange(age,15,18) & level_school==.
tab level_school [w=round(weight)]
drop spop 


replace level_school=. if level_school==7
replace level_school=7 if inlist(pe021, 50)
tab level_school [w=round(weight)]
local tot_tert = edu_t[6,1]+edu_t[6,2]+edu_t[6,3]+edu_t[6,4] + ///
edu_t[7,1]+edu_t[7,2]+edu_t[7,3]+edu_t[7,4] + ///
edu_t[8,1]+edu_t[8,2]+edu_t[8,3]+edu_t[8,4] 

di %12.0fc `tot_tert'
*229,464

gen byte at_school = (level_school>0 & level_school<.)
label var at_school   "Currently attending school"

*label val at_school yesno




label define level_school 0 "Not attending" 1 "Preschool [5-6]" 2 "Primary [7-12]" ///
3 "Lower secondary [13-15]" 4 "Upper secondary [16-17]" ///
5 "Secondary (total) [13-17]" 6 "Post-secondary non-tertiary" ///
7 "Tertiary (Bachelor’s or equivalent) [18-22]" ///
8 "Master, Doctoral or equivalent" 9 "Other (not specified before)"

label val level_school level_school
label var level_school "Level of schooling that the person is attending"
tab level_school, m

replace level_school=0 if at_school==0

tab level_school [w=round(weight)]

** public 
xtile decile  = yd_pc [pw=weight], nq(10) 

** Pre-school 
local presc_pub = edu_t[1,1]+edu_t[1,2]
di %12.0fc `presc_pub'
*      214,161
cap drop edu_pesc_ri
gen edu_pesc_ri=(level_school==1)

summ edu_pesc_ri [w=weight] if decile<=3
local seg1=r(sum)
di %12.0fc `seg1'
summ edu_pesc_ri [w=weight], meanonly
local segt = r(sum)
di %12.0fc `segt'
local dif_presc = (`segt' - `seg1')  + (`presc_pub' - `segt')
di %12.0fc `dif_presc'

sort edu_pesc_ri rand 
tempvar spesc 
by edu_pesc_ri:gen `spesc' = sum(weight) if edu_pesc_ri==1 & decile>3
sort `spesc' 
replace edu_pesc_ri=0 if edu_pesc_ri==1 & `spesc' > `dif_presc' & decile>3
list edu_pesc_ri `spesc' weight if level_school==1
summ edu_pesc_ri [w=weight], meanonly
di %12.0fc r(sum)

** Primary 
local prim_pub = edu_t[2,1]+edu_t[2,2]
di %12.0fc `prim_pub'  // 243,704
*      252,565
cap drop edu_prim_ri
gen edu_prim_ri=(level_school==2)

summ edu_prim_ri [w=weight] if decile<=3
local seg1=r(sum)
di %12.0fc `seg1'
summ edu_prim_ri [w=weight], meanonly
local segt = r(sum)
di %12.0fc `segt'
local dif_prim = (`segt' - `seg1')  + (`prim_pub' - `segt')
di %12.0fc `dif_prim'

sort edu_prim_ri rand 
tempvar sprim 
by edu_prim_ri:gen `sprim' = sum(weight) if edu_prim_ri==1 & decile>3
sort `sprim' 
replace edu_prim_ri=0 if edu_prim_ri==1 & `sprim' > `dif_prim' & decile>3
list edu_prim_ri `sprim' weight if level_school==1
summ edu_prim_ri [w=weight], meanonly
di %12.0fc r(sum)

** Lower secondary 
local losc_pub = edu_t[3,1]+edu_t[3,2]
di %12.0fc `losc_pub'
*       188,294
cap drop edu_losc_ri
gen edu_losc_ri=(level_school==3)

summ edu_losc_ri [w=weight] if decile<=3
local seg1=r(sum)
di %12.0fc `seg1'
summ edu_losc_ri [w=weight], meanonly
local segt = r(sum)
di %12.0fc `segt'
local dif_losc = (`segt' - `seg1')  + (`losc_pub' - `segt')
di %12.0fc `dif_losc'

sort edu_losc_ri rand 
tempvar slosc 
by edu_losc_ri:gen `slosc' = sum(weight) if edu_losc_ri==1 & decile>3
sort `slosc' 
replace edu_losc_ri=0 if edu_losc_ri==1 & `slosc' > `dif_losc' & decile>3
summ edu_losc_ri [w=weight], meanonly
di %12.0fc r(sum)
*    188,022

** Upper secondary 
local upsc_pub = edu_t[4,1]+edu_t[4,2]
di %12.0fc `upsc_pub'
*        267,938
cap drop edu_upsc_ri
gen edu_upsc_ri=(level_school==4)

summ edu_upsc_ri [w=weight] if decile<=3
local seg1=r(sum)
di %12.0fc `seg1'
summ edu_upsc_ri [w=weight], meanonly
local segt = r(sum)
di %12.0fc `segt'
local dif_upsc = (`segt' - `seg1')  + (`upsc_pub' - `segt')
di %12.0fc `dif_upsc'

sort edu_upsc_ri rand 
tempvar supsc 
by edu_upsc_ri:gen `supsc' = sum(weight) if edu_upsc_ri==1 & decile>3
sort `supsc' 
replace edu_upsc_ri=0 if edu_upsc_ri==1 & `supsc' > `dif_upsc' & decile>3
summ edu_upsc_ri [w=weight], meanonly
di %12.0fc r(sum)
*     263,357

** Tertiari 
local tert_pub = edu_t[6,1]+edu_t[6,2]+ edu_t[7,1]+edu_t[7,2]+ ///
edu_t[8,1]+edu_t[8,2]
di %12.0fc `tert_pub'
*        200,891
cap drop edu_tert_ri
gen edu_tert_ri=(level_school==7)

summ edu_tert_ri [w=weight] if decile<=3
local seg1=r(sum)
di %12.0fc `seg1'
summ edu_tert_ri [w=weight], meanonly
local segt = r(sum)
di %12.0fc `segt'
local dif_tert = (`segt' - `seg1')  + (`tert_pub' - `segt')
di %12.0fc `dif_tert'

sort edu_tert_ri rand 
tempvar stert 
by edu_tert_ri:gen `stert' = sum(weight) if edu_tert_ri==1 & decile>3
sort `stert' 
replace edu_tert_ri=0 if edu_tert_ri==1 & `stert' > `dif_tert' & decile>3
summ edu_tert_ri [w=weight], meanonly
di %12.0fc r(sum)
*     199,710

/*
	recode a15a (1=1) (2=3) (3=2) (4/9=4), gen(type_school)
	label var type_school ///
	"Type of school that the person is attending (public, private, semiprivate)"
	label define type_school 1 "Public" 2 "Private" ///
	3 "Semi-private (subsidised by Government" 4 "Other"
	label val type_school type_school
	replace type_school=. if at_school==0
*/


/*==================================================
	4: Benefits imputation
==================================================*/

gen double edu_pesc_in = edu_pesc_ri*(pc${edu_year}p[1,1]+pc${edu_year}p[4,1])
gen double edu_prim_in = edu_prim_ri*(pc${edu_year}p[1,1]+pc${edu_year}p[4,1])
gen double edu_losc_in = edu_losc_ri*(pc${edu_year}p[2,1]+pc${edu_year}p[4,1])
gen double edu_upsc_in = edu_upsc_ri*(pc${edu_year}p[2,1]+pc${edu_year}p[4,1])
gen double edu_tert_in = edu_tert_ri*(pc${edu_year}p[3,1]+pc${edu_year}p[4,1])


* Main national accounts tax aggregates (gov_10a_taxag) 	
***	 Annual financial accounts for general government (gov_10a_ggfa)
label 	var 	edu_pesc_in 	"In-Kind education benefits: Pre-school (individual)" 
label 	var 	edu_prim_in 	"In_kind education benefits primary level (individual)"  
label 	var 	edu_losc_in 	"In-Kind education benefits: Lower Secondary (individual)" 
label 	var 	edu_upsc_in 	"In-Kind education benefits: Upper Secondary (individual)" 
label 	var		edu_tert_in  	"In-Kind education benefits: Tertiary (individual)" 

percap edu_*_in 
rpayi  edu_*_in 	   

** No info about fees 

save "${tmp}BGR20_education.dta", replace 




********************************************************************************
	* Education 
* Education finance (educ_uoe_fin) 	

** Expenditure on education (educ_uoe_fine) 	

*** Total educational expenditure by education level, programme orientation 
*	and type of source (educ_uoe_fine01) 	

*** Public educational expenditure by education level, programme orientation, 
*	type of source and expenditure category (educ_uoe_fine02) 	

*** Private educational expenditure by education level, programme orientation, 
*	type of source and expenditure category (educ_uoe_fine03) 	

*** Public expenditure on education in current prices, by education level and 
*	programme orientation (educ_uoe_fine04) 	

*** Public subsidies to the private sector by education level and programme 
*	orientation (educ_uoe_fine07) 	

*** Public expenditure on education per pupil/student based on FTE by 
*	education level and programme orientation (educ_uoe_fine09) 	

*** Pupils and students enrolled by education level and programme orientation 
	*	with coverage adjusted to statistics on educational finance and aligned to 
*	financial year (educ_uoe_fine10) 	

**  Expenditure of/on public and private educational institutions (educ_uoe_fini) 	
	*** Financial aid to students by education level - as % of total public expenditure (educ_uoe_fina01) 	
	*** Funding of education by education level, programme orientation and recipient of funding (educ_uoe_finf01) 	
*** Funding of vocational education by education level, type of source and recipient of funding (educ_uoe_finf02)
