/*==================================================
	7_BGR_Education.do
	project:       CEQ Bulgaria 
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR_net_inc.dta
	
	Output files:
	- BGR_dis_inc.dta 
	----------------------------------------------------
	Creation Date:       17 Dec 2022
	Modification Date:   22 Feb 2022
	Do-file version:    5
	Track main changes: 
	- bugs 
	
	References:          
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2020),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2017-2020” 
	- MISSOC
	european commission (2021), "your social security rights in bulgaria", luxembourg: 
	publications office of the european union, 2021
	- Do files provided by Lucian Bucur 
	
	Output:             
	Questions & comments 
	
	
================================================== */


/*==================================================
	1: Eurostat COFOG  
==================================================*/

global hlt_year = 2020

cap confirm file "${proc}hlt_finan${hlt_year}.dta"
if _rc {	
eurostatuse hlth_sha11_hchf, clear geo( BG) keepdim() start(${hlt_year}) end(${hlt_year})
save "${proc}hlt_finan${hlt_year}.dta", replace 
}
else {
use "${proc}hlt_finan${hlt_year}.dta", clear 
}	
keep if inlist(unit,"EUR_HAB", "MIO_EUR")

/*
------------------------------------------------------------------------------------------------------------
                                                                                                 |     Total
-------------------------------------------------------------------------------------------------+----------
icha11_hf_label                                                                                  |          
  All financing schemes                                                                          |     4,364
  Compulsory contributory health insurance schemes and compulsory medical saving accounts (CMSA) |  2,188.86
  Enterprise financing schemes                                                                   |     12.47
  Financing schemes unknown                                                                      |         0
  Government schemes                                                                             |    455.29
  Government schemes and compulsory contributory health care financing schemes                   |  2,644.16
  Household out-of-pocket payment                                                                |   1,649.4
  NPISH financing schemes                                                                        |     23.14
  Rest of the world financing schemes (non-resident)                                             |         0
  Voluntary health care payment schemes                                                          |     70.45
  Voluntary health insurance schemes                                                             |     34.83
  Total                                                                                          |  11,442.6
------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------
                                                           |     Total
-----------------------------------------------------------+----------
Classification of health care financing schemes - SHA 2011 |          
  HF1                                                      |  2,644.16  <---
  HF11                                                     |    455.29
  HF12_13                                                  |  2,188.86
  HF2                                                      |     70.45
  HF21                                                     |     34.83
  HF22                                                     |     23.14
  HF23                                                     |     12.47
  HF3                                                      |   1,649.4
  HF4                                                      |         0
  HF_UNK                                                   |         0
  TOT_HF                                                   |     4,364
  Total                                                    |  11,442.6
----------------------------------------------------------------------



*/


cap confirm file "${proc}cofog_${hlt_year}.dta"
if _rc {	
eurostatuse gov_10a_exp, clear geo( BG) keepdim() start(${hlt_year}) end(${hlt_year})
save "${proc}cofog_${hlt_year}.dta", replace
}
else {
use "${proc}cofog_${hlt_year}.dta", clear 
}

drop if regexm(cofog99,"GF0[1-5]0[1-9]") 
drop if regexm(na_item,"D[4-9]_S131[1-4]")
drop if na_item=="D92" 
drop if inlist(na_item, "P2_D29_D5_D8", "P31", "P32", "P51G", "D62_D632")
keep if unit=="MIO_EUR"
keep if regexm(cofog99,"GF07")
keep if inlist(na_item,"TE","P5") // Total General & Gross Capital Formation 
sort sector cofog99 na_item 

/*
   Central government	-	S1311 
   General government -	S13
     Local government -   S1313
Social security funds -	S1314
     State government -   S1312
*/	
drop if gov_10a_exp==.

if c(version)>=17 {
table cofog99_label if na_item=="TE" & sector=="S13" & cofog99!="GF07", ///
stat(sum gov_10a_exp)
}

/*
-------------------------------------------------------
                                             |    Total
---------------------------------------------+---------
cofog99_label                                |         
  Health n.e.c.                              |    105.3
  Hospital services                          |  1,960.5
  Medical products, appliances and equipment |    368.9
  Outpatient services                        |    299.2
  Public health services                     |     52.2
  Total                                      |  2,786.1
-------------------------------------------------------
	
	
-------------------------------------------------------
                                             |    Total
---------------------------------------------+---------
cofog99_label                                |         
  Health n.e.c.                              |    119.3
  Hospital services                          |    1,873
  Medical products, appliances and equipment |      451
  Outpatient services                        |    342.4
  Public health services                     |     55.9
  Total                                      |  2,841.6
-------------------------------------------------------
*/
if c(version)>=17 {
table cofog99_label if na_item=="TE" & sector=="S13" & cofog99!="GF07" & ///
!inlist(cofog99,"GF0706","GF0704") , ///
stat(sum gov_10a_exp)
}
/*
	2018
-------------------------------------------------------
|    Total
---------------------------------------------+---------
cofog99_label                                |         
  Hospital services                          |  1,960.5
  Medical products, appliances and equipment |    368.9
  Outpatient services                        |    299.2
  Total                                      |  2,628.6
-------------------------------------------------------
	
	2019
	-------------------------------------------------------
                                             |    Total
---------------------------------------------+---------
cofog99_label                                |         
  Hospital services                          |    1,873
  Medical products, appliances and equipment |      451
  Outpatient services                        |    342.4
  Total                                      |  2,666.4
-------------------------------------------------------

VS 2644.16 
*/
if c(version)>=17 {
table cofog99_label if na_item=="TE" & sector=="S1314" & cofog99!="GF07" & ///
!inlist(cofog99,"GF0706","GF0704") , ///
stat(sum gov_10a_exp)
}
/*
-------------------------------------------------------
                                             |    Total
---------------------------------------------+---------
cofog99_label                                |         
  Hospital services                          |  1,418.1
  Medical products, appliances and equipment |    368.7
  Outpatient services                        |    222.5
  Total                                      |  2,009.3
-------------------------------------------------------

-------------------------------------------------------
                                             |    Total
---------------------------------------------+---------
cofog99_label                                |         
  Hospital services                          |  1,431.5
  Medical products, appliances and equipment |      451
  Outpatient services                        |    249.4
  Total                                      |  2,131.9
-------------------------------------------------------
vs 2188.86
*/	


summ gov_10a_exp if na_item=="TE" & sector=="S13" & !inlist(cofog99,"GF07", "GF0706","GF0704") & ///
	unit == "MIO_EUR" & regexm(cofog99,"GF07"), meanonly
local tot_gen = r(sum)
di %12.2f `tot_gen'
**2666.40

summ gov_10a_exp if na_item=="P5" & sector=="S13" & !inlist(cofog99,"GF07", "GF0706","GF0704") & ///
	unit == "MIO_EUR" & regexm(cofog99,"GF07"), meanonly
local cap_gen = r(sum)
display %12.1f `cap_gen'
local cur_gen = `tot_gen' - `cap_gen'
display %12.1f `cur_gen'

summ gov_10a_exp if na_item=="TE" & sector=="S1314" &  ///
	unit == "MIO_EUR" & !inlist(cofog99,"GF07", "GF0706","GF0704") & ///
	regexm(cofog99,"GF07"),  meanonly

local tot_sse = r(sum)
summ gov_10a_exp if na_item=="P5" & sector=="S1314" & cofog99!="GF07" & ///
!inlist(cofog99,"GF0706","GF0704") & unit == "MIO_EUR" & regexm(cofog99,"GF07") ///
, meanonly
local cap_sse = r(sum)
di %12.1fc `cap_see'

local cur_sse = `tot_sse' - `cap_sse'

scalar CUR_SEE = `cur_sse'
di %12.1fc `cap_sse'
* 0.0
display %12.1fc `cur_sse'
* 2,131.9

scalar CUR_HLM = `cur_gen' - `cur_sse'
local cap_hlm = `cap_gen' - `cap_sse'

di %12.1fc CUR_HLM
* 458.3
di %12.1fc `cap_gen'
*76.2

di as text "Total seguridad social ...." as result %18.2fc `tot_sse'


summ gov_10a_exp if na_item=="TE" & sector=="S13" & ///
inlist(cofog99,"GF0706","GF0704") & unit == "MIO_EUR" & regexm(cofog99,"GF07") ///
, meanonly

di %18.1fc r(sum)

/*==================================================
	2: Affiliation to health benefits 
==================================================*/
/* 
	Social security insurance value 
   1. Insured 
   2. Their family 
   3. Children below 18
   4. Pensioners 

	Ministry of Health and other 
	1. All population (EU citizens)

*/	
	

use "${tmp}BGR20_education.dta", clear 
cap drop _*

** 1.Insured 
gen hlt_nihs_ri = (con_hlte_ri==1 | con_hltp_ri==1 | con_hlts_ri==1 )

** 2.Family (dependents)
bysort hhid: egen double af_fam = max(hlt_nihs_ri)  // if family is affiliated 

** if affiliated father/mother/spouse
gen double f_fat  = hhin*hlt_nihs_ri if gender==0
gen double f_mot  = hhin*hlt_nihs_ri if gender==1
gen double f_esp  = hhin*hlt_nihs_ri if pb180_f==1

** father/mother/spouse code by hhd 
bysort hhid: egen double af_fat = max(f_fat) if gender==0
bysort hhid: egen double af_mot = max(f_mot) if gender==1 
bysort hhid: egen double af_esp = max(f_esp) 

** if father/mother/spouse code without flags
replace hlt_nihs_ri=1 if af_fat!=0 & af_fat!=.  & hlt_nihs_ri==0 & pb160_f==1
replace hlt_nihs_ri=1 if af_mot!=0 & af_mot!=.  & hlt_nihs_ri==0 & pb170_f==1
replace hlt_nihs_ri=1 if af_esp!=0 & af_esp!=.  & hlt_nihs_ri==0 & pb180_f==1


* 3. ALL Children under 18 
replace hlt_nihs_ri=1 if age<18

* 4. ALL Pensioners 
replace hlt_nihs_ri=1 if pen_csss_ri==1

tab hlt_nihs_ri [w=round(weight)]

/*
hlt_nihs_ri |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |    423,097        6.04        6.04
          1 |  6,585,415       93.96      100.00
------------+-----------------------------------
      Total |  7,008,512      100.00

*/

drop af_* f_*

gen hlt_hlmn_ri = 1  // for whole population 

summ hlt_nihs_ri [w=weight], meanonly
scalar BEN_SEE = r(sum)

summ hlt_hlmn_ri [w=weight], meanonly
scalar BEN_HLM = r(sum)

gen double hlt_nihs_in = hlt_nihs_ri*(CUR_SEE*1000000/BEN_SEE)
gen double hlt_hlmn_in = hlt_hlmn_ri*(CUR_HLM*1000000/BEN_HLM)

** No info about fees 

label 	var 	hlt_nihs_in 	"In-Kind health benefits: Social Security (individual)" 
label 	var 	hlt_hlmn_in 	"In_kind health benefits: Public health (individual)"  

percap hlt_*_in 
rpayi  hlt_*_in 	

/*==================================================
	3: Final Income 
==================================================*/


*----------3.1: estimate final income 
cap drop _*


egen yf_pc = rsum(yc_pc hlt_*_pc edu_*_pc )

label var yf_pc "Final Income (per capita)"

*----------3.5: check if there are negatives 

summ y*_pc 

*----------3.6: check inequality 

ainequal ym_pc yd_pc yc_pc yf_pc [w=round(weight)] 
	
	scalar PL190 = .8453251*1.90*365
	scalar PL320 = .8453251*3.20*365
	scalar PL550 = .8453251*5.50*365

cap drop pline_mod pline_ext 
gen pline_mod = (504.33*12)/EXR // 2534.25
gen pline_ext = pline_mod*.5

drop dtr_surv_*
gen dtr_othr_rh = (dtr_othr_pc>0 & memb_no==1)

cap drop *_ae	

label var dtr_fmno_pc "Dir.Transfer: Family N-MT Other (Per capita)"
rpayh dtr_fmno_pc 


foreach pc_var of varlist *_pc {
	local ae_var = subinstr("`pc_var'","pc","ae",1)
	local pc_lab : variable label `pc_var'
	local ae_lab = subinstr("`pc_lab'","Per capita","Adult equivalent",1)
	gen double  `ae_var' = ((`pc_var'*hsize))/hx050
	label var `ae_var' "`ae_lab'"
}	

tempvar zero 
gen `zero' = (yd_pc==0 & ym_pc==0 & yp_pc==0)
tab `zero'

levelsof psu if `zero'
local zlevels = r(levels)

summ weight , meanonly
local tot_pop = r(sum)
/*
foreach npsu of local zlevels {
		di "`npsu'"
		summ one [w=weight] if psu == `npsu', meanonly
		local pop_orig=r(sum)
		summ one [w=weight] if psu == `npsu' & `zero'==0, meanonly
		local pop_zero=r(sum)
		local scale_pop = `pop_orig' / `pop_zero'
		replace weight = weight * `scale_pop' if psu == `npsu' 
		// there was a mistake in readjustment in weights 
		summ one [w=weight] if psu == `npsu' & `zero'==0, meanonly
		di %18.0fc r(sum) "..." %18.0fc `pop_orig'
}	
*/
summ weight if `zero'==0 
di %18.0fc r(sum) "......" %18.0fc `tot_pop'

replace weight=round(weight)

povcc yd_ae      [w=weight], pline(PNATM) nn("National")  ppof(22.6) 

summ one [w=weight] if `zero' 
**drop if `zero'

summ yd_ae [w=weight], detail 
scalar PNATM = 0.6*r(p50)
// 3119.73 vs 3094.3655

// replace pline_mod = PNATM 
drop if yd_pc==.

di "-------------------------------------------------------------------------"
povcc yd_ae      [w=weight], pline(PNATM) nn("National")  ppof(22.6) 

// 4 cases 

/*==================================================
	6:  Save file - final  income 
==================================================*/
cap drop _*
	drop ym2_pc 
drop dtr_famc_rh 	

label var weight "Sampling weight" 
label var ym_pc "Market Income PGT (per capita)"
label var yd2_ae "Disposable Income SILC (Adult Equivalent)"
label var yd2_pc "Disposable Income SILC (per capita)"
label var ym_ae "Market Income PGT (Adult Equivalent)"
label var pline_mod "National Poverty line"
label var pline_ext "National Extreme Poverty line"
label var memb_no "Household member correlative"


lab_tori dtr*_*ri
lab_torh dtr*_*rh

drop e1 uno 
drop s_py080g corr_no /*informal_w ytcw_in ytcw2_in ytp_in*/ nre ///
	disab_allowance 	child_allowance ytp3_in ///	
nbirthf childm_1 nchildm1 fm_child2 max_py030g                  ///
famtestinc20_hh famtestinc20_pc first_grade totchild dtr_fmno_hh  dmi_1     ///
dmi_2 dmi_3 dmi_4 dmi_5 dmi_6 dmi_7 dmi_8 dmi_ind2020 dmi_hh2020 dmih_1     ///
dmih_3 dmih_2 dmih_4 dmih_5 dmih_6 dmih_7 dmih_8 dmih_10 dmih_9 dmih_11     ///
dmih_12 dmih_ind2020 dmih_hh2020 hpy140g hpy130g pytravel hpytravel         ///
igmiexempt20_hh igmitestable20_hh gmi2020_hh hai2020_hh 

drop /*informal_s ytcs_in ytpi_in ytp2_in*/ num sum_weight sum_benefits ///
 yd_hh one rand  famtestinc20_ae

label val dtr*_r? yesno 
label val itx*_rh yesno 
label val sub*_rh yesno 


save "${proc}BGR20WBN_final_Aug9_2023.dta", replace 





cap log close
exit



********************************************************************************
* Health care

***		Health care expenditure - cross-classified tables (hlth_sha11_cross) 	
***		Expenditure for selected health care functions by health care providers (hlth_sha11_hchp) 	
***		Expenditure for selected health care functions by health care financing schemes (hlth_sha11_hchf) 	
***		Expenditure for selected health care providers by health care financing schemes (hlth_sha11_hphf) 	
***		Revenues of health care financing schemes by health care financing schemes (hlth_sha11_hffs)

**  poverty UMIC 
preserve 

cd "${tmp}"

eurostatuse ilc_di12, clear geo(EU27_2020) keepdim() start(2010) end(2022) long 
mkmat time ilc_di12
mat eu_gini = ilc_di12 
mat drop ilc_di12

eurostatuse ilc_di12, clear geo(BG) keepdim() start(2010) end(2022) long 
mkmat  ilc_di12

mat gini_bgue = (time, eu_gini, ilc_di12)

eurostatuse ilc_di12, clear geo() keepdim() start(2022) end(2022) long 
sort ilc 
drop if ilc==.
replace geo_label = "Euro area" if geo=="EA"
replace geo_label = "Germany" if geo=="DE"
replace geo_label = "European Union" if geo=="EU27_2020"
drop if inlist(geo,"EA18","EA19","TR","AL","RS","ME","MK","CH","NO") 
drop if inlist(geo,"EA") 

keep geo* ilc 
export excel * using "${tmp}pov_umic.xlsx", sheet("comparative_gini2") sheetmodify firstrow(varlabels)

wbopendata, country(BGR) indicator(SI.POV.UMIC) long clear

keep if inrange(year,2006,2022)  // 2021 not available 

twoway (line si year)
list year si_pov_umic  

mkmat year si_pov_umic  

wbopendata, country(BGR) indicator(SI.POV.GINI) long clear 

wbopendata,  indicator(SI.POV.UMIC) long clear latest 

keep if inlist(countrycode, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK") | ///
	    inlist(countrycode, "EST", "FIN", "GRC", "HUN" ) | ///
		inlist(countrycode, "LVA", "LTU", "LUX", "MLT", "NLD","NOR") | ///
		inlist(countrycode, "PRT", "ROU", "SVK", "SVN", "ESP", "SWE")
		
graph bar (mean) si, over(countryname, sort(si_pov_umic) label(angle(ninety)))


putexcel set "${tmp}pov_umic.xlsx", modify  sheet("bgr_06_20")

putexcel a2=mat(year) b2=mat(si_pov_umic)

putexcel set "${tmp}pov_umic.xlsx", modify  sheet("bgr_ue_gini")

putexcel a2=mat(gini_bgue)

putexcel clear 

sort si 
export excel countryname si using "${tmp}pov_umic.xlsx", sheet("comparative") sheetmodify firstrow(varlabels)


shell excel "${tmp}pov_umic.xlsx"

use "C:\Users\mynor\Dropbox (Personal)\zotros\BM\BGR\3.data\MC\tmp\BGR19WBN_final_Jun1_2023.dta", clear
scalar EXR = 1.9558
ainequal  yd_pc yc_pc yf_pc [w=weight]

/*
---------------------------------------------------------------
       Inequality measures |      yd_pc       yc_pc       yf_pc
---------------------------+-----------------------------------
          Gini coefficient |    0.40750     0.38531     0.32518
Theil index (GE(a), a = 1) |    0.35282     0.31577     0.23234
---------------------------------------------------------------
*/

local ppp_17 =   0.751069
local cpi_17 = 107.9315
local cpi_18 = 110.97406
local cpi_19 = 114.41839
local cpi_20 = 116.33197


gen double  pl_umic = (`ppp_17'*(`cpi_18'/`cpi_17')*6.85*365)/EXR
apoverty yp_pc yc_pc [w=weight], varpl(pl_umic)
di real(r(head_1))- real(r(head_2))

use "${proc}BGR20WBN_final_May29_2023.dta", clear

ainequal  yp_pc yd_pc yc_pc yf_pc [w=weight]

local ppp_17 =   0.751069
local cpi_17 = 107.9315
local cpi_20 = 116.33197


gen double  pl_umic = (`ppp_17'*(`cpi_20'/`cpi_17')*6.85*365)/EXR
apoverty yp_pc yc_pc [w=weight], varpl(pl_umic)
di real(r(head_2))- real(r(head_1))

apoverty yp_ae yc_ae [w=weight], varpl(pline_mod)
di real(r(head_2))- real(r(head_1))

apoverty yp_ae yn_ae yd_ae yc_ae [w=weight], varpl(pline_mod)
apoverty yp_pc yn_pc yd_pc yc_pc [w=weight], varpl(pl_umic)

