/*==================================================
	9_BGR20_Groups.do
	project:       CEQ Bulgaria 
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR_net_inc.dta
	
	Output files:
	- BGR_dis_inc.dta 
	----------------------------------------------------
	Creation Date:       17 Dec 2022
	Modification Date:   22 Feb 2022
	Do-file version:    5
	Track main changes: 
	- bugs 
	
	References:          
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2020),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2017-2020” 
	- MISSOC
	european commission (2021), "your social security rights in bulgaria", luxembourg: 
	publications office of the european union, 2021
	- Do files provided by Lucian Bucur 
	
	Output:             
	Questions & comments 
	
	
================================================== */
set scheme tab2
graph set window fontface "Calibri"

cap program drop marg_contch

cap program drop chart01ch
program define chart01ch   // poverty charts  
	preserve 	 
	sp_groupfunction [w=weight], poverty(yp_ae yd_ae yc_ae) povertyline(pline_mod) by(`1')
	keep if measure=="fgt0"
	drop reference _* measure
	rename value y1_ 
	replace y1_=round(y1_*100,0.001)
	reshape wide y1_, i(`1') j(variable) string
	rename y1_y* y*
	label val `1' `1'
	label var yp_ae "Market income plus pensions"
	label var yd_ae "Disposable income"
	label var yc_ae "Consumable income"
	format y*ae %6.1fc
	graph bar (mean) yp_ae (mean) yd_ae (mean) yc_ae, over(`1', label(`5' labsize(`4'))) ///
	blabel(bar, format(%3.`3'fc)) title(Bulgaria 2020)  ///
	subtitle($title1)  ///
	caption(Source: Author estimations based on EU-SILC 2021 and HBS 2021 using CEQ methodology, size(small)) ///
	legend(order(1 "Market Income plus pensions" 2 "Disposable Income" 3 "Consumable Income") size(small))
	
	graph export "${outp}fig_`2'.png", as(png) replace width(800) height(600)
	
	restore 
end 	

program define marg_contch  // marginal contributions to child poverty 
	syntax , def1(string asis) pline(string) fig1(string) wb(string) sh(string) [ord(string)]
	local d1 = "`def1'"
	local p1 = "`pline'"
	if "`ord'"=="" local ord = "1"

	preserve 
	foreach var of varlist dtr*`d1' sub*`d1' {
		local vardtr = substr("`var'",1,8)
		gen yc_`d1'_`vardtr' =  yc_`d1' - `var'	
	}	

	foreach var of varlist itx*`d1' dtx*`d1' con*`d1' {
		local vardtr = substr("`var'",1,8)
		gen yc_`d1'_`vardtr' =  yc_`d1' + `var'	
	}	

	apoverty yc_`d1' yc_`d1'_dtr_fncb [w=weight], varpl(`p1')
	tab child_

	sp_groupfunction [w=weight], poverty(yc_`d1'*) povertyline(`p1') by(child_)
	keep if measure=="fgt0"
	drop reference _* measure
	rename value y1_ 
	replace y1_=round(y1_*100,0.001)
	list 

	reshape wide y1_, i(child_) j(variable) string
	rename y1_y* y*
	format yc* %2.1fc
	list 
	descr 
	foreach var of varlist yc_`d1'_dtr_disb-yc_`d1'_sub_gasi {
		local vardtr = substr("`var'",7,8)
		gen d_`vardtr' = `var' - yc_`d1' 	 
	}	

	keep child d_*		
	reshape long d_ , i(child_) j(fisc) string 		
	keep if child_==1
	format d_ %2.1fc 
	merge m:1 fisc using "${tmp}varnames1.dta", 
	drop child_ _m 
	if "`ord'"=="1" gsort -d_
	if "`ord'"=="2" sort fisc
	order varlab  d_ 
	list 

	replace varlab = regexr(varlab,"Dir.[T|t]ran[s|f][e|f][e|r][r|s](s*)","Direct Transfer")
	replace varlab = regexr(varlab,"Direct [t|T]ranfers","Direct Transfer")	
	replace varlab = subinstr(varlab,"N-NMT","non means-tested",1)	
	replace varlab = subinstr(varlab,"N-NM","non means-tested",1)	
	gen tmp1 = regexm(varlab,"non means-tested")
	replace varlab = subinstr(varlab,"non means-tested","",1) if tmp1==1
	replace varlab = varlab + "(non means-tested)" if tmp1==1
	gen tmp2 = regexm(varlab,"N-MT")
	replace varlab = subinstr(varlab,"N-MT","",1) if tmp2==1
	replace varlab = varlab + "(means-tested)" if tmp2==1
	replace varlab = subinstr(varlab,"old-age nc","non-contributory pensions",1) 
	replace varlab = subinstr(varlab,"achild","a child",1) 
	replace varlab = subinstr(varlab,"Family  ","Family ",1) 
	drop tmp2 tmp1 

	drop if inlist(fisc,"itx_car2","itx_carb")	
	list 

	encode varlab, gen(fiscal_intervention)
	table fiscal_intervention, stat(mean d_) nformat(%2.1fc) nototal 

	graph hbar (mean) d_ if substr(fisc,1,3)=="dtr", over(fiscal_intervention, sort(d_) descending  ///
		label(labsize(vsmall)) axis(lcolor(maroon) outergap(2))) stack ///
		blabel(bar, format(%3.1f)) ///
		ytitle(`"Marginal contribution to child poverty reduction"') ///
		ytitle(, size(small)) yscale(fextend) ylabel(-7(1)6, labsize(tiny)) 
	graph export "${outp}`fig1'.png", as(png) replace width(800) height(600)			

	label var d_ "Marginal contribution to child poverty reduction" 
	label var varlab "Fiscal intervention"
	list varlab d_
	if "`ord'"=="1" sort d_
	if "`ord'"=="2" {
		tempvar fisc3 
		gen `fisc3'=substr(fisc,1,3)
		gsort `fisc3' -d_
	}	

	export excel varlab d_ using "${outp}`wb'", sheet(`sh',modify) firstrow(varlabels) 
	mata: b = xl()
	mata: b.load_book("${outp}`wb'.xls")
	mata: b.set_sheet("`sh'")
	mata: fmt_id1 = b.add_fmtid()
	mata: b.fmtid_set_number_format(fmt_id1, "#0.0") 
	mata: rows = (2,28)
	mata: cols = (2,2)
	mata: b.set_fmtid(rows, cols, fmt_id1)
	mata: b.set_column_width(1, 1, 60)
	mata: b.close_book()
	restore 
	
end 

global check1 =0 

use "${proc}BGR20WBN_final_Aug9_2023.dta", clear
rename yd2_pc ydold_pç 
rename yd2_ae ydold_ae 

preserve 
keep dtr*ae itx*ae sub*ae dtx*ae con*ae
describe, replace clear 
keep name varlab 
replace name = subinstr(name,"_ae","",1)
replace varlab = subinstr(varlab,"(Adult equivalent)","",1)
rename name fisc 
list 
save "${tmp}varnames1.dta", replace 

restore 

gen child_=(age<18)

apoverty yp_ae yc_ae if child_ [w=weight], varpl(pline_mod)

if $check1 == 1 {
	
	preserve 
	collapse (median) my_labor_in [fw=weight], by(age gender)
	twoway (line my_labor_in age if gender==0, sort) (line my_labor_in age if gender==1) ///
	, ytitle(`"Annual Labor Income"') legend(order(1 "Men" 2 "Women")) ///
	title("Bulgaria 2020:" "Labor income by age and gender (median)")	
	restore
	
	preserve 
	collapse (mean) my_labor_in [fw=weight], by(age gender)
	twoway (line my_labor_in age if gender==0, sort) (line my_labor_in age if gender==1) ///
	, ytitle(`"Annual Labor Income"') legend(order(1 "Men" 2 "Women")) ///
	title("Bulgaria 2020:" "Labor income by age and gender (average)")	
	restore 
	
	
	gen age2=int(age/5)
	gen age10=int(age/10)
	label define age2 0 "0-4y" 1 "5-9y" 2 "10-14y" 3 "15-19y" 4 "20-24y" ///
	5 "25-29y" 6 "30-34y" 7 "35-39y" 8 "40-44y" 9 "45-49y" 10 "50-54y" 11 ///
	"55-59y" 12 "60-64y" 13 "65-69y" 14 "70-74y" 15 "75-79y" 16 "80+"
	label val age2 age2 
	label define age10 0 "0-10y" 1 "10-19y" 2 "20-29y" 3 "30-39y" 4 "40-49y" ///
	5 "50-59y" 6 "60-69y" 7 "70-79y" 8 "80+"
	label val age10 age10 	

	preserve 
	gen total=1 
	collapse (sum) total [fw=weight], by(age10 gender)
	by age10: egen males = sum(total) if gender==0
	by age10: egen females = sum(total) if gender==1
	replace males=males*-1
	
	gsort -age10
	
	label var males "Males"
	label var females "Females"
	graph hbar (sum) males (sum) females, over(age10, descending) ///
	stack legend(order(1 "Men" 2 "Women")) ///
	ylabel(-500000 "500" -400000 "400" -300000 "300" -200000 "200" -100000 "100" 0 ///
	100000 "100" 200000 "200" 300000 "300" 400000 "400" 500000 "500" ///
	, labsize(small)) ///
	ytitle("Thousands", size(small))		///
	title("Bulgaria 2020:" "population pyramid, age group population")
	
	summ total 
	scalar TOTAL = r(sum)
	gen shmale = males/TOTAL
	gen shfeml = females/TOTAL
	
	graph hbar (sum) shmale (sum) shfeml, over(age10, descending) ///
	stack legend(order(1 "Men" 2 "Women")) ///
	ytitle("Percentage", size(small))		///
	ylabel( -0.08 "8" -0.07 "7" -0.06 "6" -0.05 "5" -0.04 "4" ///
	-0.03 "3" -0.02 "2" -0.01 "1"  0 ///
	0.01 "1" 0.02 "2" 0.03 "3" 0.04 "4" ///
	0.05 "5"  0.06 "6" 0.07 "7" 0.08 "8"  ) ///
	title("Bulgaria 2020:" "population pyramid, age group share of total population")
	restore 
	
}

gen ceq_child01 	= 1 if inrange(sage_18,1,15)
replace ceq_child01 = 0 if sage_18==0
label var ceq_child01 "HHD with children ==1"
label define ceq_child01 0 "No children" 1 "With children"
label val ceq_child01 ceq_child01

gen ceq_child01a = ceq_child01+1

bysort hhid: egen s_old = max(old)

replace ceq_child01a = 0 if ceq_child01==0 & s_old==0
replace ceq_child01a = 1 if ceq_child01==0 & s_old==1
replace ceq_child01a = 2 if ceq_child01==1 & s_old==0
replace ceq_child01a = 3 if ceq_child01==1 & s_old==1

label define ceq_child01a 0  "No children & no elderly" 1 "No children w/ elderly" ///
2 "Children & no elderly"  3 "With Children & elderly"
label val ceq_child01a ceq_child01a

gen 	ceq_child02 = 1 if sage_18==1 & ceq_child01==1 
replace ceq_child02 = 2 if sage_18==2 & ceq_child01==1
replace ceq_child02 = 3 if inrange(sage_18,3,10) & ceq_child01==1

/*
	// option for 3, 4 and 5+ childs 
	replace ceq_child02 = 3 if sage_18==3 & ceq_child01==1
	replace ceq_child02 = 4 if sage_18==4 & ceq_child01==1
	replace ceq_child02 = 5 if sage_18>=5 & ceq_child01==1

	// options for 6, 7+ childs 
	replace ceq_child02 = 6 if sage_18==6 & ceq_child01==1
	replace ceq_child02 = 7 if sage_18>=6 & ceq_child01==1  
*/


replace ceq_child02 = 0 if ceq_child02==.

label var ceq_child02 "Number of children in HHD"
label define ceq_child02 0 "No children" 1 "1 children" 2 "2 children" ///
3 "3 or more children" // 4 "4 children" 5 "5 or more children"
**5 "5 children"  6 "6 children"  7 "7 or more children"

label val ceq_child02 ceq_child02	

gen employ1=(pl032==1 & my_labor_in>0 & my_labor_in<.)
bysort hhid: egen s_employ1 = sum(employ1)

gen ceq_child03     = 1 if lonep_hh>0 & lonep_hh<. & ceq_child01==1
replace ceq_child03 = 0 if lonep_hh==0  & ceq_child01==1
replace ceq_child03 = 0 if ceq_child03==1 & s_employ1>1 & s_employ1<.

label var ceq_child03 "HHD with children (lone parent==1)"

label define ceq_child03 0 "Both parents or 2+ breadwinner" 1 "Lone parents" 
label val ceq_child03 ceq_child03	

gen     ceq_child03a = 0 if ceq_child03==0 & ceq_child01==1  // both parents 
replace ceq_child03a = 1 if ceq_child03==1 & ceq_child01==0 //  lone without child 

destring rb220, replace 
bysort hhid: egen srb220 = count(rb220)

destring rb230, replace 
bysort hhid: egen srb230 = count(rb230)

replace ceq_child03a = 2 if ceq_child03==1 & srb220>0  & srb230==0 //  male  w/child 
replace ceq_child03a = 3 if ceq_child03==1 & srb220==0 & srb230>0 //  female w/child 


preserve 
keep if ceq_child03a==. & ceq_child03==1
gsort hhid -age
collapse (first) gender, by(hhid)
gen     ceq_child03b = 2 if gender==0
replace ceq_child03b = 3 if gender==1
tempfile tchild03a
save `tchild03a', replace 
restore 

merge m:1 hhid using `tchild03a', keep(match master)

replace ceq_child03a = ceq_child03b if ceq_child03a==. & ceq_child03==1

drop ceq_child03b

label var ceq_child03a "HHD status parents and children "
label define ceq_child03a 0 "Both parents or 2+ breadwinner" ///
	1 "No children" 2 "Lone male parent" 3 "Lone female parent" 

label val ceq_child03a ceq_child03a	

// 0-2 3-5 6-9 10-13 14-17

gen 	ceq_child04 = 1 if inrange(age,0,2)
replace ceq_child04 = 2 if inrange(age,3,5)
replace ceq_child04 = 3 if inrange(age,6,9)
replace ceq_child04 = 4 if inrange(age,10,13)
replace ceq_child04 = 5 if inrange(age,14,17)

label var ceq_child04 "Children age groups"
label define ceq_child04 1 "Children aged 0-2" 2  "Children aged 3-5" ///
3 "Children aged 6-9" 4  "Children aged 10-13"  5 "Children aged 14-17"
label val ceq_child04 ceq_child04	 

// charts by child / no child 
global title1 = "Headcount poverty (AROP) by household category"
chart01ch  ceq_child01   child1 1
chart01ch  ceq_child01a  child1a 1 small 

// number of childer 
global title1 = "Headcount poverty (AROP) by household category"
chart01ch  ceq_child02   child2  0 small 

// parents 
global title1 = "Headcount poverty (AROP) by household w/child category"
chart01ch  ceq_child03   child3  1 

chart01ch  ceq_child03a  child3a 0 small

// children age 
global title1 = "Headcount poverty (AROP) by children age "
chart01ch  ceq_child04   child4  1 small

// child poverty 
preserve  
global title1 = "Child poverty (AROP)"
keep if child_==1
chart01ch  child_   child00  1 small nolabel 
restore 

gen one=1
chart01ch  one   child00a  1 small

// marg contribution AROP 
marg_contch, def1(ae) pline(pline_mod) fig1(fig1a) wb(temp2) sh(child_pae) ord(2)

// marg contribution 6.85 ppp 2017
gen pline_685 = 6.85*.38042116*(116.33197/107.93615)*365	
marg_contch, def1(pc) pline(pline_685) fig1(fig2a) wb(temp2) sh(child_int) ord(2)

save "${outp}BGR20WBN_childp_Aug9_2023.dta", replace 

use "${oupt}BGR20WBN_childp_Aug9_2023.dta", clear 

// labor status 
table () ceq_child03a if age>=18 [w=weight], stat(fvpercent pl032) nformat(%5.1fc)
collect style header pl032, title(hide)

egen dtr_fncx_pc = rsum(dtr_fnc*_pc)
label var dtr_fncx_pc "Family & child contributory"
egen dtr_fnnx_pc = rsum(dtr_fnn*_pc)
label var dtr_fnnx_pc "Family & child non-mean tested"
egen dtr_fmnx_pc = rsum(dtr_fmn*_pc)
label var dtr_fmnx_pc "Family & child mean-tested"

clonevar ceq_child03c = ceq_child03a
replace ceq_child03c = 4 if ceq_child03c==.
cap label drop ceq_child03c
label copy ceq_child03a ceq_child03c
label define ceq_child03c 4 "No child", add 
tabstat dtr_f*x_pc dtr_disb_pc dtr_oldb_pc dtr_unem_pc dtr_gmis_pc dtr_hais_pc dtr_othr_pc [w=weight]  ///
, stat(sum) save by(ceq_child03c)
tabstatmat fnc  

mata: a=st_matrix("fnc")[1::4,]
mata: b=colsum(a)
mata: st_matrix("fnc1",a:/b:*100)
matlist fnc1

// check family in no child hhd --> it is a misreporting should go to "others"
	// the transfers are in familly ... others 
// ## change this 
/*
mat fnc1[4,1] = 0
mat fnc1[4,2] = 0
mat fnc1[4,3] = 0
*/
cap drop fnc1a*

svmat fnc1, name(fnc1a)
cap drop num1

gen num1 = _n 

label val ceq_child03c ceq_child03c

graph bar (mean) fnc1a1 (mean) fnc1a2 (mean) fnc1a3 (mean) fnc1a4 (mean) fnc1a5  ///
(mean) fnc1a6 (mean) fnc1a7 (mean) fnc1a8 ///		
if num1<5, over(num1, relabel(1 "Both parents" 2 "Male lone parent" ///
3 "Female lone parent" 4 "No children") label(labsize(small))) ///
bar(1, color(black) fcolor("179 0 0") lwidth(vthin)) bar(2, color(black) fcolor("124 17 88") lwidth(vthin))  ///
bar(3, color(black) fcolor("68 33 175") lwidth(vthin)) bar(4, color(black) fcolor("26 83 255")  lwidth(vthin))   ///
bar(5, color(black) fcolor("13 136 230")lwidth(vthin)) bar(6, color(black) fcolor("0 183 199") lwidth(vthin))  ///
bar(7, color(black) fcolor("90 212 90") lwidth(vthin)) bar(8, color(black) fcolor("139 224 78") lwidth(vthin))  ///
ytitle(fdasu) ytitle(, size(small) margin(sides)) ylabel(, labsize(small)) ///
b1title("Household type", size(small))  ///
ytitle("Percent of total direct transfers (%)" , size(small))  ///
legend(size(vsmall) rows(3) order( ///
	1 "Family contributory" ///
	2 "Family non-means tested" ///
	3 "Family mean-tested" ///
	4 "Disability" ///
	5 "Old age" ///
	6 "Unemployment" ///
	7 "Social Assistance" ///
	8 "Heath allowance" ) ) graphregion(color(white)) bgcolor(white)
	
graph export "${outp}fig_B1.png", as(png) replace width(800) height(600)			

// by household size 

tabstat dtr_f*x_pc dtr_disb_pc dtr_oldb_pc dtr_unem_pc dtr_gmis_pc dtr_hais_pc dtr_othr_pc [w=weight]  ///
, stat(sum) save by(ceq_child02)
tabstatmat fnc  

mata: a=st_matrix("fnc")[1::4,]
mata: b=colsum(a)
mata: st_matrix("fnc2",a:/b:*100)
matlist fnc2

cap drop fnc2a*

// check family in no child hhd --> it is a misreporting should go to "others"
	// the transfers are in familly ... others 
// ## change this 
/*
mat fnc2[1,1] = 0
mat fnc2[1,2] = 0
mat fnc2[1,3] = 0
*/

svmat fnc2, name(fnc2a)
cap drop num1 
gen num1 = _n 

// ["#b30000", "#7c1158", "#4421af", "#1a53ff", "#0d88e6", "#00b7c7", "#5ad45a", "#8be04e", "#ebdc78"]

	//set scheme cblind1

	graph bar (mean) fnc2a1 (mean) fnc2a2 (mean) fnc2a3 (mean) fnc2a4 (mean) fnc2a5  ///
	(mean) fnc2a6 (mean) fnc2a7 (mean) fnc2a8 ///		
	if num1<5, over(num1, relabel(1 "No children" 2 "1 child" ///
	3 "2 children" 4 "3+children") label(labsize(small))) ///
	bar(1, color(black) fcolor("179 0 0") lwidth(vthin)) bar(2, color(black) fcolor("124 17 88") lwidth(vthin))  ///
	bar(3, color(black) fcolor("68 33 175") lwidth(vthin)) bar(4, color(black) fcolor("26 83 255")  lwidth(vthin))   ///
	bar(5, color(black) fcolor("13 136 230")lwidth(vthin)) bar(6, color(black) fcolor("0 183 199") lwidth(vthin))  ///
	bar(7, color(black) fcolor("90 212 90") lwidth(vthin)) bar(8, color(black) fcolor("139 224 78") lwidth(vthin))  ///
	/*blabel(bar, size(small) format(%4.0f)) */ ///
	ytitle(fdasu) ytitle(, size(small) margin(sides)) ylabel(, labsize(small)) ///
	b1title("Household type", size(small))  ///
	ytitle("Percent of total direct transfers (%)" , size(small))  ///
	legend(size(vsmall) rows(3) order( ///
	1 "Family contributory" ///
	2 "Family non-means tested" ///
	3 "Family mean-tested" ///
	4 "Disability" ///
	5 "Old age" ///
	6 "Unemployment" ///
	7 "Social Assistance" ///
	8 "Heath allowance" ) ) graphregion(color(white)) bgcolor(white)		

graph export "${outp}fig_B2.png", as(png) replace width(800) height(600)

foreach var of varlist dtr*pc {
	egen s`var' = sum(`var')
	gen sh`var' = (`var'/ s`var')*100	
	local var1: variable label `var'
	label variable sh`var' "`var1'"	
}	

drop dtr*pc sdtr*pc
drop shdtr_fncb_pc  shdtr_fnco_pc  shdtr_fmn1_pc  shdtr_fmno_pc  shdtr_fnnt_pc /// 
shdtr_fncs_pc  shdtr_fmne_pc  shdtr_fmnc_pc  shdtr_fnnb_pc  shdtr_fnnw_pc shdtr_fnno_pc

label var shdtr_disb_pc "Disability"
label var shdtr_unem_pc "Unemployment"
label var shdtr_hais_pc "Heath allowance"
label var shdtr_oldb_pc "Old-age nc pension"
label var shdtr_gmis_pc "Social asistance"
label var shdtr_othr_pc "Other"

descr shdtr*pc  // , simple 

replace ceq_child03a = 4 if ceq_child03a==.

label define ceq_child03a 4 "No child", add 

list ceq_child03a shdtr*pc

/*graph bar (asis) shdtr*pc, over(ceq_child03a) stack */

/*
	graph bar (mean) ed2a1 (mean) ed2a2 (mean) ed2a3 (mean) ed2a4 if num<6, over(num, /// 
	label(labsize(small))) blabel(bar, size(small) format(%4.0f))  ///
	ytitle(fdasu) ytitle(, size(small)) ///
	b1title("Quintile of per capita market income", size(small))  ///
	ytitle("Percent of school-age population (%)")  ///
	legend(size(vsmall) rows(2) order( ///
	1 "Primary" ///
	2 "Lower secondary"  ///
	3 "Upper secondary"  ///
	4 "Tertiary" )) graphregion(color(white)) bgcolor(white)
*/




